<?php

$LANG = array(
    'organization' => 'Empresa',
    'name' => 'Nome',
    'website' => 'Website',
    'work_phone' => 'Telefone',
    'address' => 'Endereço',
    'address1' => 'Rua',
    'address2' => 'Complemento',
    'city' => 'Cidade',
    'state' => 'Estado',
    'postal_code' => 'CEP',
    'country_id' => 'País',
    'contacts' => 'Contatos',
    'first_name' => 'Nome',
    'last_name' => 'Sobrenome',
    'phone' => 'Telefone',
    'email' => 'Email',
    'additional_info' => 'Informações Adicionais',
    'payment_terms' => 'Condição de Pagamento',
    'currency_id' => 'Moeda',
    'size_id' => 'Tamanho da Empresa',
    'industry_id' => 'Indústria',
    'private_notes' => 'Notas Privadas',
    'invoice' => 'Fatura',
    'client' => 'Cliente',
    'invoice_date' => 'Data da Fatura',
    'due_date' => 'Data de Vencimento',
    'invoice_number' => 'Número da Fatura',
    'invoice_number_short' => 'Fatura #',
    'po_number' => 'Nº Ordem de Serviço',
    'po_number_short' => 'OS #',
    'frequency_id' => 'Qual Frequencia',
    'discount' => 'Desconto',
    'taxes' => 'Impostos',
    'tax' => 'Imposto',
    'item' => 'Item',
    'description' => 'Descrição',
    'unit_cost' => 'Preço Unitário',
    'quantity' => 'Quantidade',
    'line_total' => 'Total da Linha',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Pago até Hoje',
    'balance_due' => 'Saldo Devedor',
    'invoice_design_id' => 'Design',
    'terms' => 'Condições',
    'your_invoice' => 'Sua Fatura',
    'remove_contact' => 'Remover contato',
    'add_contact' => 'Adicionar contato',
    'create_new_client' => 'Criar novo cliente',
    'edit_client_details' => 'Editar detalhes do cliente',
    'enable' => 'Habilitar',
    'learn_more' => 'Saiba mais',
    'manage_rates' => 'Gerenciar taxas',
    'note_to_client' => 'Nota para o Cliente',
    'invoice_terms' => 'Condições da Fatura',
    'save_as_default_terms' => 'Salvar como condições padrão',
    'download_pdf' => 'Baixar PDF',
    'pay_now' => 'Pagar Agora',
    'save_invoice' => 'Salvar Fatura',
    'clone_invoice' => 'Clonar Fatura',
    'archive_invoice' => 'Arquivar Fatura',
    'delete_invoice' => 'Excluir Fatura',
    'email_invoice' => 'Enviar Fatura por Email',
    'enter_payment' => 'Informar Pagamento',
    'tax_rates' => 'Taxas de Impostos',
    'rate' => 'Taxa',
    'settings' => 'Configurações',
    'enable_invoice_tax' => 'Permitir especificar um <b>imposto da fatura</b>',
    'enable_line_item_tax' => 'Permitir especificar <b>impostos de itens</b>',
    'dashboard' => 'Painel',
    'dashboard_totals_in_all_currencies_help' => 'Nota: adicione um :link chamado ":name" para exibir os totais com base em uma única moeda.',
    'clients' => 'Clientes',
    'invoices' => 'Faturas',
    'payments' => 'Pagamentos',
    'credits' => 'Créditos',
    'history' => 'Histórico',
    'search' => 'Pesquisar',
    'sign_up' => 'Cadastro',
    'guest' => 'Convidado',
    'company_details' => 'Detalhes da Empresa',
    'online_payments' => 'Pagamentos Online',
    'notifications' => 'Notificações',
    'import_export' => 'Importar | Exportar',
    'done' => 'Concluído',
    'save' => 'Salvar',
    'create' => 'Criar',
    'upload' => 'Upload',
    'import' => 'Importar',
    'download' => 'Download',
    'cancel' => 'Cancelar',
    'close' => 'Fechar',
    'provide_email' => 'Por favor forneça um endereço de email válido',
    'powered_by' => 'Desenvolvido por',
    'no_items' => 'Sem itens',
    'recurring_invoices' => 'Faturas Recorrentes',
    'recurring_help' => '<p>Enviar as mesmas faturas semanalmente, bimestralmente, mensalmente, trimestralmente ou anualmente para os clientes.</p>
<p>Utilize :MONTH, :QUARTER ou :YEAR para datas dinâmicas. Cálculos básicos são aplicáveis, como por exemplo :MONTH-1.</p>
<p>Exemplos de variáveis dinâmicas de faturas:</p>
<ul>
<li>"Mensalidade da academia para o mês de :MONTH" >> "Mensalidade da academia para o mês de Julho"</li>
<li>"Assinatura anual de :YEAR+1" >> "Assinatura anual de 2015"</li>
<li>"Pagamento de retentor para :QUARTER+1" >> "Pagamento de retentor para 3T"</li>
</ul>',
    'recurring_quotes' => 'Orçamentos Recorrentes',
    'in_total_revenue' => 'em faturamento total',
    'billed_client' => 'cliente cobrado',
    'billed_clients' => 'clientes cobrados',
    'active_client' => 'cliente ativo',
    'active_clients' => 'clientes ativos',
    'invoices_past_due' => 'Faturas Vencidas',
    'upcoming_invoices' => 'Próximas Faturas',
    'average_invoice' => 'Média por Fatura',
    'archive' => 'Arquivar',
    'delete' => 'Excluir',
    'archive_client' => 'Arquivar Cliente',
    'delete_client' => 'Excluir Cliente',
    'archive_payment' => 'Arquivar Pagamento',
    'delete_payment' => 'Excluir Pagamento',
    'archive_credit' => 'Arquivar Crédito',
    'delete_credit' => 'Excluir Crédito',
    'show_archived_deleted' => 'Exibir arquivados/excluídos',
    'filter' => 'Filtrar',
    'new_client' => 'Novo Cliente',
    'new_invoice' => 'Nova Fatura',
    'new_payment' => 'Adicionar Pagamento',
    'new_credit' => 'Adicionar Crédito',
    'contact' => 'Contato',
    'date_created' => 'Data de Criação',
    'last_login' => 'Último Login',
    'balance' => 'Saldo',
    'action' => 'Ação',
    'status' => 'Status',
    'invoice_total' => 'Total da Fatura',
    'frequency' => 'Frequência',
    'range' => 'Período',
    'start_date' => 'Data Inicial',
    'end_date' => 'Data Final',
    'transaction_reference' => 'Referência da Transação',
    'method' => 'Método',
    'payment_amount' => 'Quantia de Pagamento',
    'payment_date' => 'Data do Pagamento',
    'credit_amount' => 'Quantia de Crédito',
    'credit_balance' => 'Saldo do Crédito',
    'credit_date' => 'Data do Crédito',
    'empty_table' => 'Sem dados disponíveis na tabela',
    'select' => 'Selecionar',
    'edit_client' => 'Editar Cliente',
    'edit_invoice' => 'Editar Fatura',
    'create_invoice' => 'Criar Fatura',
    'enter_credit' => 'Informar Crédito',
    'last_logged_in' => 'Último acesso em',
    'details' => 'Detalhes',
    'standing' => 'Situação',
    'credit' => 'Crédito',
    'activity' => 'Atividade',
    'date' => 'Data',
    'message' => 'Mensagem',
    'adjustment' => 'Ajuste',
    'are_you_sure' => 'Você tem certeza?',
    'payment_type_id' => 'Tipo de Pagamento',
    'amount' => 'Quantia',
    'work_email' => 'Email',
    'language_id' => 'Idioma',
    'timezone_id' => 'Fuso Horário',
    'date_format_id' => 'Formato da Data',
    'datetime_format_id' => 'Formato da Data/Hora',
    'users' => 'Usuários',
    'localization' => 'Localização',
    'remove_logo' => 'Remover logo',
    'logo_help' => 'Suportados: JPEG, GIF and PNG',
    'payment_gateway' => 'Gateway de Pagamento',
    'gateway_id' => 'Gateway',
    'email_notifications' => 'Notificações por Email',
    'email_sent' => 'Notificar-me por email quando a fatura for <b>enviada</b>',
    'email_viewed' => 'Notificar-me por email quando a fatura for <b>visualizada</b>',
    'email_paid' => 'Notificar-me por email quando a fatura for <b>paga</b>',
    'site_updates' => 'Atualizações do Site',
    'custom_messages' => 'Mensagens Personalizadas',
    'default_email_footer' => 'Definir <b>assinatura de email</b> padrão',
    'select_file' => 'Selecione um arquivo',
    'first_row_headers' => 'Usar a primeira linha como cabeçalhos',
    'column' => 'Coluna',
    'sample' => 'Amostra',
    'import_to' => 'Importar para',
    'client_will_create' => 'cliente será criado',
    'clients_will_create' => 'clientes serão criados',
    'email_settings' => 'Configurações de Email',
    'client_view_styling' => 'Estilo de Visão do Cliente',
    'pdf_email_attachment' => 'Anexar PDF',
    'custom_css' => 'CSS Personalizado',
    'import_clients' => 'Importar Dados do Cliente',
    'csv_file' => 'Arquivo CSV',
    'export_clients' => 'Exportar Dados do Cliente',
    'created_client' => 'Cliente criado com sucesso',
    'created_clients' => ':count cliente(s) criado(s) com sucesso',
    'updated_settings' => 'Configurações atualizadas com sucesso',
    'removed_logo' => 'Logotipo removido com sucesso',
    'sent_message' => 'Mensagem enviada com sucesso',
    'invoice_error' => 'Assegure-se de selecionar um cliente e corrigir quaisquer erros',
    'limit_clients' => 'Desculpe, isto irá exceder o limite de :count clientes',
    'payment_error' => 'Ocorreu um erro ao processar seu pagamento. Por favor tente novamente mais tarde.',
    'registration_required' => 'Favor cadastre-se para enviar uma fatura por email',
    'confirmation_required' => 'Por favor confirme seu endereço de email, :link para re-enviar o email de confirmação.',
    'updated_client' => 'Cliente atualizado com sucesso',
    'archived_client' => 'Cliente arquivado com sucesso',
    'archived_clients' => ':count clientes arquivados com sucesso',
    'deleted_client' => 'Cliente excluído com sucesso',
    'deleted_clients' => ':count clientes excluídos com sucesso',
    'updated_invoice' => 'Fatura atualizada com sucesso',
    'created_invoice' => 'Fatura criada com sucesso',
    'cloned_invoice' => 'Fatura clonada com sucesso',
    'emailed_invoice' => 'Fatura enviada por email com sucesso',
    'and_created_client' => 'e criou o cliente',
    'archived_invoice' => 'Fatura arquivada com sucesso',
    'archived_invoices' => ':count faturas arquivadas com sucesso',
    'deleted_invoice' => 'Fatura excluída com sucesso',
    'deleted_invoices' => ':count faturas excluídas com sucesso',
    'created_payment' => 'Pagamento criado com sucesso',
    'created_payments' => ':count pagamento(s) criado(s) com sucesso',
    'archived_payment' => 'Pagamento arquivado com sucesso',
    'archived_payments' => ':count pagamentos arquivados com sucesso',
    'deleted_payment' => 'Pagamento excluído com sucesso',
    'deleted_payments' => ':count pagamentos excluídos com sucesso',
    'applied_payment' => 'Pagamentos aplicados com sucesso',
    'created_credit' => 'Crédito criado com sucesso',
    'archived_credit' => 'Crédito arquivado com sucesso',
    'archived_credits' => ':count créditos arquivados com sucesso',
    'deleted_credit' => 'Crédito excluído com sucesso',
    'deleted_credits' => ':count créditos excluídos com sucesso',
    'imported_file' => 'Arquivo importado com sucesso',
    'updated_vendor' => 'Fornecedor atualizado com sucesso',
    'created_vendor' => 'Fornecedor criado com sucesso',
    'archived_vendor' => 'Fornecedor arquivado com sucesso',
    'archived_vendors' => ':count fornecedores arquivados com sucesso',
    'deleted_vendor' => 'Fornecedor excluído com sucesso',
    'deleted_vendors' => ':count fornecedores excluídos com sucesso',
    'confirmation_subject' => 'Confirmação de Conta do Invoice Ninja',
    'confirmation_header' => 'Confirmação de Conta',
    'confirmation_message' => 'Favor acessar o link abaixo para confirmar a sua conta.',
    'invoice_subject' => 'Nova fatura :number de :account',
    'invoice_message' => 'Para visualizar a sua fatura de :amount, clique no link abaixo.',
    'payment_subject' => 'Pagamento Recebido',
    'payment_message' => 'Obrigado pelo seu pagamento de :amount',
    'email_salutation' => 'Caro(a) :name,',
    'email_signature' => 'Atenciosamente,',
    'email_from' => 'Equipe InvoiceNinja',
    'invoice_link_message' => 'Para visualizar a fatura clique no link abaixo:',
    'notification_invoice_paid_subject' => 'Fatura :invoice foi paga por :client',
    'notification_invoice_sent_subject' => 'Fatura :invoice foi enviada por :client',
    'notification_invoice_viewed_subject' => 'Fatura :invoice foi visualizada por :client',
    'notification_invoice_paid' => 'Um pagamento de :amount foi realizado pelo cliente :client para a fatura :invoice.',
    'notification_invoice_sent' => 'Ao cliente :client foi enviada por email a fatura :invoice no valor de :amount.',
    'notification_invoice_viewed' => 'O cliente :client visualizou a fatura :invoice no valor de :amount.',
    'reset_password' => 'Você pode redefinir a sua senha clicando no seguinte link:',
    'secure_payment' => 'Pagamento Seguro',
    'card_number' => 'Número do Cartão',
    'expiration_month' => 'Mês de Expiração',
    'expiration_year' => 'Ano de Expiração',
    'cvv' => 'CVV',
    'logout' => 'Sair',
    'sign_up_to_save' => 'Cadastre-se para salvar o seu trabalho',
    'agree_to_terms' => 'Eu concordo com as :terms',
    'terms_of_service' => 'Condições do Serviço',
    'email_taken' => 'O endereço de email já está registrado',
    'working' => 'Trabalhando',
    'success' => 'Sucesso',
    'success_message' => 'Você se registrou com sucesso! Por favor acesse o link no email de confirmação para verificar o seu endereço de email.',
    'erase_data' => 'Sua conta não está cadastrada, isso apagará permanentemente seus dados.',
    'password' => 'Senha',
    'pro_plan_product' => 'Plano Pro',
    'pro_plan_success' => 'Obrigado por escolher o Plano Pro do Invoice Ninja! <p/>&nbsp;<br/>
<b>Próximos Passos</b><p/>Uma fatura pagável foi enviada para o email endereço associado com sua conta. Para desbloquear todas as incríveis funcionalidades Pro, por favor siga as instruções na fatura para pagar por um ano de faturamento Pro.<p/>
Não consegue achar a fatura? Precisa de mais ajuda? Ficaremos feliz em ajudar
-- envie-nos um email em contact@invoiceninja.com',
    'unsaved_changes' => 'Você possui alterações não salvas',
    'custom_fields' => 'Campos Personalizados',
    'company_fields' => 'Campos da Empresa',
    'client_fields' => 'Campos de Cientes',
    'field_label' => 'Rótulo do Campo',
    'field_value' => 'Valor do Campo',
    'edit' => 'Editar',
    'set_name' => 'Definir o nome da sua empresa',
    'view_as_recipient' => 'Visualizar como destinatário',
    'product_library' => 'Biblioteca de Produtos',
    'product' => 'Produto',
    'products' => 'Produtos',
    'fill_products' => 'Auto-preencher produtos',
    'fill_products_help' => 'Ao selecionar um produto sua <b>descrição e preço</b> serão automaticamente preenchidos',
    'update_products' => 'Atualização automática dos produtos',
    'update_products_help' => 'Atualizar uma fatura irá automaticamente<b>atualizar a biblioteca de produtos</b>',
    'create_product' => 'Adicionar Produto',
    'edit_product' => 'Editar Produto',
    'archive_product' => 'Arquivar Produto',
    'updated_product' => 'Produto atualizado com sucesso',
    'created_product' => 'Produto criado com sucesso',
    'archived_product' => 'Produto arquivado com sucesso',
    'pro_plan_custom_fields' => ':link para habilitar campos personalizados adquirindo o Plano Pro',
    'advanced_settings' => 'Configurações Avançadas',
    'pro_plan_advanced_settings' => ':link para habilitar as configurações avançadas adquirindo o Plano Pro',
    'invoice_design' => 'Design da Fatura',
    'specify_colors' => 'Especifique cores',
    'specify_colors_label' => 'Selecione as cores usadas na sua fatura',
    'chart_builder' => 'Contrutor de Gráficos',
    'ninja_email_footer' => 'Criado por :site | Crie. Envie. Seja Pago.',
    'go_pro' => 'Adquira o Plano Pro',
    'quote' => 'Orçamento',
    'quotes' => 'Orçamentos',
    'quote_number' => 'Número do Orçamento',
    'quote_number_short' => 'Orçamento #',
    'quote_date' => 'Data do Orçamento',
    'quote_total' => 'Total do Orçamento',
    'your_quote' => 'Seu Orçamento',
    'total' => 'Total',
    'clone' => 'Clonar',
    'new_quote' => 'Novo Orçamento',
    'create_quote' => 'Criar Orçamento',
    'edit_quote' => 'Editar Orçamento',
    'archive_quote' => 'Arquivar Orçamento',
    'delete_quote' => 'Excluir Orçamento',
    'save_quote' => 'Salvar Oçamento',
    'email_quote' => 'Enviar Orçamento por Email',
    'clone_quote' => 'Clonar para Orçamento',
    'convert_to_invoice' => 'Converter em Fatura',
    'view_invoice' => 'Visualizar fatura',
    'view_client' => 'Visualizar Cliente',
    'view_quote' => 'Visualizar Orçamento',
    'updated_quote' => 'Orçamento atualizado com sucesso',
    'created_quote' => 'Orçamento criado com sucesso',
    'cloned_quote' => 'Orçamento clonado com sucesso',
    'emailed_quote' => 'Orçamento enviado por email com sucesso',
    'archived_quote' => 'Orçamento aquivado com sucesso',
    'archived_quotes' => ':count orçamentos arquivados com sucesso',
    'deleted_quote' => 'Orçamento excluído com sucesso',
    'deleted_quotes' => ':count orçamentos excluídos com sucesso',
    'converted_to_invoice' => 'Orçamento convertido em fatura com sucesso',
    'quote_subject' => 'Novo orçamento :number de :account',
    'quote_message' => 'Para visualizar seu orçamento de :amount, clique no link abaixo.',
    'quote_link_message' => 'Para visualizar o orçamento clique no link abaixo',
    'notification_quote_sent_subject' => 'Orçamento :invoice enviado para :client',
    'notification_quote_viewed_subject' => 'Orçamento :invoice visualizado por :client',
    'notification_quote_sent' => 'O cliente :client recebeu o Orçamento :invoice de:amount.',
    'notification_quote_viewed' => 'O cliente :client visualizou o Orçamento :invoice de :amount.',
    'session_expired' => 'Sua sessão expirou.',
    'invoice_fields' => 'Campos da Fatura',
    'invoice_options' => 'Opções da Fatura',
    'hide_paid_to_date' => 'Ocultar Pago até Hoje',
    'hide_paid_to_date_help' => 'Apenas mostrar "Pago até a Data" em suas faturas uma vez que o pagamento for recebido.',
    'charge_taxes' => 'Cobrar impostos',
    'user_management' => 'Gerenciamento de Usuários',
    'add_user' => 'Adicionar Usuários',
    'send_invite' => 'Enviar Convite',
    'sent_invite' => 'Convite enviado com sucesso',
    'updated_user' => 'Usuário atualizado com sucesso',
    'invitation_message' => 'Você foi convidado por :invitor. ',
    'register_to_add_user' => 'Cadastre-se para adicionar um usuário',
    'user_state' => 'Estado',
    'edit_user' => 'Editar Usuário',
    'delete_user' => 'Excluir Usuário',
    'active' => 'Ativo',
    'pending' => 'Pendente',
    'deleted_user' => 'Usuário excluído com sucesso',
    'confirm_email_invoice' => 'Tem certeza que quer enviar esta fatura por email?',
    'confirm_email_quote' => 'Tem certeza que quer enviar este orçamento por email?',
    'confirm_recurring_email_invoice' => 'Tem certeza que quer enviar esta fatura por email?',
    'confirm_recurring_email_invoice_not_sent' => 'Tem certeza de que deseja iniciar a recorrência?',
    'cancel_account' => 'Excluir Conta',
    'cancel_account_message' => 'Aviso: Isso excluirá permanentemente sua conta, não há como desfazer esta ação.',
    'go_back' => 'Voltar',
    'data_visualizations' => 'Visualização de Dados',
    'sample_data' => 'Amostra de dados exibida',
    'hide' => 'Ocultar',
    'new_version_available' => 'Uma nova versão de :releases_link está disponível. Sua versão é v:user_version, a última versão é v:latest_version',
    'invoice_settings' => 'Configurações de Faturas',
    'invoice_number_prefix' => 'Prefixo Numérico de Faturas',
    'invoice_number_counter' => 'Contador Numérico de Faturas',
    'quote_number_prefix' => 'Prefixo Numérico de Orçamentos',
    'quote_number_counter' => 'Contador Numérico de Orçamentos',
    'share_invoice_counter' => 'Compartilhar contador das faturas',
    'invoice_issued_to' => 'Fatura emitida para',
    'invalid_counter' => 'Para evitar conflitos defina prefíxos de numeração para Faturas e Orçamentos',
    'mark_sent' => 'Marcar como Enviada',
    'gateway_help_1' => ':link para cadastrar-se em Authorize.net.',
    'gateway_help_2' => ':link para cadastrar-se em Authorize.net.',
    'gateway_help_17' => ':link para adquirir sua "PayPal API signature".',
    'gateway_help_27' => ':link registrar-se no 2Checkout.com. Para garantir o rastreamento dos pagamentos configure o  :complete_link como URL de redirecionamento em Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link para criar uma conta no WePay.',
    'more_designs' => 'Mais designs',
    'more_designs_title' => 'Designs adicionais de faturas',
    'more_designs_cloud_header' => 'Adquira o Plano Pro para mais designs',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Comprar',
    'bought_designs' => 'Design adicionais de faturas incluídos com sucesso',
    'sent' => 'Enviado',
    'vat_number' => 'Inscrição Municipal',
    'timesheets' => 'Planilhas de Tempo',
    'payment_title' => 'Informe seu Endereço de Cobrança e as informações de Cartão de Crédito',
    'payment_cvv' => '* Este é o número de 3-4 dígitos no verso do seu cartão',
    'payment_footer1' => '*O endereço de cobrança deve ser igual o endereço associado ao cartão de crédito.',
    'payment_footer2' => '*Por favor clique em "PAGAR AGORA" apenas uma vez - a operação pode levar até 1 minuto para processar.',
    'id_number' => 'CNPJ',
    'white_label_link' => 'White label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Licença "white label" habilitada com sucesso',
    'white_labeled' => 'White labeled',
    'restore' => 'Restaurar',
    'restore_invoice' => 'Restaurar Fatura',
    'restore_quote' => 'Restaurar Orçamento',
    'restore_client' => 'Restaurar Cliente',
    'restore_credit' => 'Restaurar Crédito',
    'restore_payment' => 'Restaurar Pagamento',
    'restored_invoice' => 'Fatura restaurada com sucesso',
    'restored_quote' => 'Orçamento restaurado com sucesso',
    'restored_client' => 'Cliente restaurado com sucesso',
    'restored_payment' => 'Pagamento restaurado com sucesso',
    'restored_credit' => 'Crédito restaurado com sucesso',
    'reason_for_canceling' => 'Ajude-nos a melhorar nosso site dizendo-nos a razão de estar saindo.',
    'discount_percent' => 'Porcento',
    'discount_amount' => 'Quantia',
    'invoice_history' => 'Histórico de Faturas',
    'quote_history' => 'Histórico de Orçamentos',
    'current_version' => 'Versão Atual',
    'select_version' => 'Selecionar versão',
    'view_history' => 'Visualizar Histórico',
    'edit_payment' => 'Editar Pagamento',
    'updated_payment' => 'Pagamento atualizado com sucesso',
    'deleted' => 'Excluído',
    'restore_user' => 'Restaurar Usuário',
    'restored_user' => 'Usuário restaurado com sucesso',
    'show_deleted_users' => 'Exibir usuários excluídos',
    'email_templates' => 'Modelos de Email',
    'invoice_email' => 'Email de Fatura',
    'payment_email' => 'Email de Pagamento',
    'quote_email' => 'Email de Orçamento',
    'reset_all' => 'Redefinir Tudo',
    'approve' => 'Aprovar',
    'token_billing_type_id' => 'Token de Cobrança',
    'token_billing_help' => 'Armazene informações de pagamento com WePay, Stripe, Braintree ou GoCardless.',
    'token_billing_1' => 'Desabilitado',
    'token_billing_2' => 'Campo Opt-in - está mostrado mas não selecionado',
    'token_billing_3' => 'Campo Opt-out - está mostrado e selecionado',
    'token_billing_4' => 'Sempre',
    'token_billing_checkbox' => 'Guardar detalhes do cartão de crédito',
    'view_in_gateway' => 'Ver em :gateway',
    'use_card_on_file' => 'Utilizar Cartão em Arquivo',
    'edit_payment_details' => 'Editar detalhes do pagamento',
    'token_billing' => 'Salvar detalhes do cartão',
    'token_billing_secure' => 'Dados armazenados com seguração por :link',
    'support' => 'Suporte',
    'contact_information' => 'Informações de Contato',
    '256_encryption' => 'Criptografia de 256-Bits',
    'amount_due' => 'Quantia devida',
    'billing_address' => 'Endereço de Cobrança',
    'billing_method' => 'Método de Cobrança',
    'order_overview' => 'Resumo do Pedido',
    'match_address' => '*O endereço de cobrança deve ser igual o endereço associado ao cartão de crédito.',
    'click_once' => '*Favor clicar em "PAGAR AGORA" apenas uma vez - a operação pode levar até 1 minuto para processar.',
    'invoice_footer' => 'Rodapé da Fatura',
    'save_as_default_footer' => 'Salvar como rodapé padrão',
    'token_management' => 'Gerenciamento de Token',
    'tokens' => 'Tokens',
    'add_token' => 'Adicionar Token',
    'show_deleted_tokens' => 'Exibir tokens excluídos',
    'deleted_token' => 'Token excluído com sucesso',
    'created_token' => 'Token criado com sucesso',
    'updated_token' => 'Token atualizado com sucesso',
    'edit_token' => 'Editar Token',
    'delete_token' => 'Excluir Token',
    'token' => 'Token',
    'add_gateway' => 'Adicionar Gateway',
    'delete_gateway' => 'Excluir Gateway',
    'edit_gateway' => 'Editar Gateway',
    'updated_gateway' => 'Gateway atualizado com sucesso',
    'created_gateway' => 'Gateway criado com sucesso',
    'deleted_gateway' => 'Gateway excluído com sucesso',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Cartão de Crédito',
    'change_password' => 'Altera senha',
    'current_password' => 'Senha atual',
    'new_password' => 'Nova senha',
    'confirm_password' => 'Confirmar senha',
    'password_error_incorrect' => 'A senha atual está incorreta.',
    'password_error_invalid' => 'A nova senha é inválida.',
    'updated_password' => 'Senha atualizada com sucesso',
    'api_tokens' => 'Tokens de API',
    'users_and_tokens' => 'Usuários & Tokens',
    'account_login' => 'Login na Conta',
    'recover_password' => 'Recupere sua senha',
    'forgot_password' => 'Esqueceu sua senha?',
    'email_address' => 'Endereço de email',
    'lets_go' => 'Vamos',
    'password_recovery' => 'Recuperação de Senha',
    'send_email' => 'Enviar Email',
    'set_password' => 'Definir Senha',
    'converted' => 'Convertido',
    'email_approved' => 'Enviar-me um email quando um orçamento for <b>aprovado</b>',
    'notification_quote_approved_subject' => 'Orçamento :invoice foi aprovado por :client',
    'notification_quote_approved' => 'O cliente :client aprovou o orçamento :invoice de :amount.',
    'resend_confirmation' => 'Reenviar email de confirmação',
    'confirmation_resent' => 'O email de confirmação foi reenviado',
    'gateway_help_42' => ':link para registrar-se no BitPay.<br/>Nota: use uma "Chave API Legada", não "Token API".',
    'payment_type_credit_card' => 'Cartão de Crédito',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Base de Conhecimento',
    'partial' => 'Depósito / Parcial',
    'partial_remaining' => ':partial de :balance',
    'more_fields' => 'Mais Campos',
    'less_fields' => 'Menos Campos',
    'client_name' => 'Nome do Cliente',
    'pdf_settings' => 'Configurações do PDF',
    'product_settings' => 'Configurações de Produtos',
    'auto_wrap' => 'Quebrar Linhas automaticamente',
    'duplicate_post' => 'Aviso: a pagina anterior foi submetida duas vezes. A segunda submissão foi ignorada.',
    'view_documentation' => 'Ver Documentação',
    'app_title' => 'Faturamento Open-Source Online Gratuito',
    'app_description' => 'Invoice Ninja é uma solução open-source, gratuita para faturamento e cobrança de clientes. Com Invoice Ninja, você pode facilmente construir e enviar belas faturas de qualquer dispositivo com acesso à web. Seus clientes podem imprimir suas faturas, baixá-las como PDF, e até mesmo pagá-las online dentro do sistema.',
    'rows' => 'linhas',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomínio',
    'provide_name_or_email' => 'Por favor informe um nome ou email',
    'charts_and_reports' => 'Gráficos & Relatórios',
    'chart' => 'Gráfico',
    'report' => 'Relatório',
    'group_by' => 'Agrupado por',
    'paid' => 'Pago',
    'enable_report' => 'Relatório',
    'enable_chart' => 'Gráfico',
    'totals' => 'Totais',
    'run' => 'Executar',
    'export' => 'Exportar',
    'documentation' => 'Documentação',
    'zapier' => 'Zapier',
    'recurring' => 'Recorrente',
    'last_invoice_sent' => 'Última cobrança enviada em :date',
    'processed_updates' => 'Atualização concluída com sucesso',
    'tasks' => 'Tarefas',
    'new_task' => 'Nova Tarefa',
    'start_time' => 'Horário de Início',
    'created_task' => 'Tarefa criada com sucesso',
    'updated_task' => 'Tarefa atualizada com sucesso',
    'edit_task' => 'Editar Tarefa',
    'clone_task' => 'Copiar Tarefa',
    'archive_task' => 'Arquivar Tarefa',
    'restore_task' => 'Restaurar Tarefa',
    'delete_task' => 'Excluir Tarefa',
    'stop_task' => 'Parar Tarefa',
    'time' => 'Hora',
    'start' => 'Iniciar',
    'stop' => 'Parar',
    'now' => 'Agora',
    'timer' => 'Timer',
    'manual' => 'Manual',
    'date_and_time' => 'Data e Hora',
    'second' => 'Segundo',
    'seconds' => 'Segundos',
    'minute' => 'Minuto',
    'minutes' => 'Minutos',
    'hour' => 'Hora',
    'hours' => 'Horas',
    'task_details' => 'Detalhes da Tarefa',
    'duration' => 'Duração',
    'time_log' => 'Log de Tempo',
    'end_time' => 'Horário Final',
    'end' => 'Fim',
    'invoiced' => 'Faturado',
    'logged' => 'Logado',
    'running' => 'Executando',
    'task_error_multiple_clients' => 'As tarefas não podem pertencer a clientes diferentes',
    'task_error_running' => 'Favor interromper as tarefas em execução primeiro',
    'task_error_invoiced' => 'Tarefas já foram faturadas',
    'restored_task' => 'Tarefa restaurada com sucesso',
    'archived_task' => 'Tarefa arquivada com sucesso',
    'archived_tasks' => ':count tarefas arquivadas com sucesso',
    'deleted_task' => 'Tarefa excluída com sucesso',
    'deleted_tasks' => ':count tarefas excluídas com sucesso',
    'create_task' => 'Criar Tarefa',
    'stopped_task' => 'Tarefa interrompida com sucesso',
    'invoice_task' => 'Faturar Tarefa',
    'invoice_labels' => 'Rótulos das Faturas',
    'prefix' => 'Prefixo',
    'counter' => 'Contador',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link para registrar-se em Dwolla.',
    'partial_value' => 'Precisa ser maior que zero e menor que o total',
    'more_actions' => 'Mais Ações',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Atualize Agora!',
    'pro_plan_feature1' => 'Crie Clientes Ilimitados',
    'pro_plan_feature2' => 'Acesso a 10 Belos Designs de Faturas',
    'pro_plan_feature3' => 'URLs personalizadas - "SeuNome.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Remover "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Acesso Multi-Usuário & Rastreio de Atividades',
    'pro_plan_feature6' => 'Crie Orçamentos & Faturas Pro-forma',
    'pro_plan_feature7' => 'Personalize Títulos e Numerações de Campos de Faturas',
    'pro_plan_feature8' => 'Opção para anexar PDFs aos Emails de Clientes',
    'resume' => 'Retomar',
    'break_duration' => 'Interromper',
    'edit_details' => 'Editar Detalhes',
    'work' => 'Trabalho',
    'timezone_unset' => 'Por favor, clique aqui :link para definir seu fuso horário',
    'click_here' => 'clique aqui',
    'email_receipt' => 'Enviar recibo de pagamento ao cliente por email',
    'created_payment_emailed_client' => 'Pagamento criado e email enviado ao cliente com sucesso',
    'add_company' => 'Adicionar Empresa',
    'untitled' => 'Sem Título',
    'new_company' => 'Nova Empresa',
    'associated_accounts' => 'Contas vinculadas com sucesso',
    'unlinked_account' => 'Contas desvinculadas com sucesso',
    'login' => 'Login',
    'or' => 'ou',
    'email_error' => 'Houve um problema ao enviar o email',
    'confirm_recurring_timing' => 'Nota: emails são enviados no início da hora.',
    'confirm_recurring_timing_not_sent' => 'Nota: faturas são criadas no início da hora.',
    'payment_terms_help' => 'Define a <b>data de vencimento padrão da fatura</b>',
    'unlink_account' => 'Desvincular Conta',
    'unlink' => 'Desvincular',
    'show_address' => 'Exibir Endereço',
    'show_address_help' => 'Exige que o cliente forneça seu endereço de cobrança',
    'update_address' => 'Atualizar Endereço',
    'update_address_help' => 'Atualizar o endereço do cliente com os dados fornecidos',
    'times' => 'Vezes',
    'set_now' => 'Definir para agora',
    'dark_mode' => 'Modo Escuro',
    'dark_mode_help' => 'Usar um fundo escuro para as barras laterais',
    'add_to_invoice' => 'Adicionar na fatura :invoice',
    'create_new_invoice' => 'Criar nova fatura',
    'task_errors' => 'Por favor corrija quaisquer tempos sobrepostos',
    'from' => 'De',
    'to' => 'Para',
    'font_size' => 'Tamanho da Fonte',
    'primary_color' => 'Cor Primária',
    'secondary_color' => 'Cor Secundaria',
    'customize_design' => 'Personalizar Design',
    'content' => 'Conteúdo',
    'styles' => 'Estilos',
    'defaults' => 'Padrões',
    'margins' => 'Margens',
    'header' => 'Cabeçalho',
    'footer' => 'Rodapé',
    'custom' => 'Personalizado',
    'invoice_to' => 'Fatura para',
    'invoice_no' => 'Fatura N°',
    'quote_no' => 'Orçamento N°',
    'recent_payments' => 'Pagamentos Recentes',
    'outstanding' => 'Em Aberto',
    'manage_companies' => 'Gerenciar Empresas',
    'total_revenue' => 'Faturamento Total',
    'current_user' => 'Usuário atual',
    'new_recurring_invoice' => 'Nova Fatura Recorrente',
    'recurring_invoice' => 'Fatura Recorrente',
    'new_recurring_quote' => 'Novo Orçamento Recorrente',
    'recurring_quote' => 'Orçamento Recorrente',
    'recurring_too_soon' => 'É cedo demais para criar a próxima fatura recorrente, está agendado para :date',
    'created_by_invoice' => 'Criada pela :invoice',
    'primary_user' => 'Usuário Primário',
    'help' => 'Ajuda',
    'customize_help' => '<p>Nós usamos :pdfmake_link para definir declaradamente os designs de faturas. O PDFMake :playground_link provê uma ótima maneira de ver a biblioteca em ação.</p>
<p>Se você precisar de ajuda para entender algo poste uma questão em nosso :forum_link com o design que você está usando.</p>',
    'playground' => 'rascunho',
    'support_forum' => 'fórum de suporte',
    'invoice_due_date' => 'Data de Vencimento',
    'quote_due_date' => 'Valido Até',
    'valid_until' => 'Válido Até',
    'reset_terms' => 'Redefinir condições',
    'reset_footer' => 'Redefinir rodapé',
    'invoice_sent' => ':count fatura enviada',
    'invoices_sent' => ':count faturas enviadas',
    'status_draft' => 'Rascunho',
    'status_sent' => 'Enviado',
    'status_viewed' => 'Visualizado',
    'status_partial' => 'Parcial',
    'status_paid' => 'Pago',
    'status_unpaid' => 'Não Pago',
    'status_all' => 'Todos',
    'show_line_item_tax' => 'Exibir <b>impostos do item na linha</b>',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copie o código abaixo em uma página de seu website.',
    'iframe_url_help2' => 'Você pode testar a funcionalidade clicando em  \'Ver como destinatário\' em uma fatura.',
    'auto_bill' => 'Cobrança Automática',
    'military_time' => 'Formato de Tempo 24h',
    'last_sent' => 'Último Envio',
    'reminder_emails' => 'Emails de Lembrete',
    'quote_reminder_emails' => 'Lembretes de E-mail de Orçamentos',
    'templates_and_reminders' => 'Modelos e Lembretes',
    'subject' => 'Assunto',
    'body' => 'Corpo',
    'first_reminder' => 'Primeiro Lembrete',
    'second_reminder' => 'Segundo Lembrete',
    'third_reminder' => 'Terceiro Lembrete',
    'num_days_reminder' => 'Dias após o vencimento',
    'reminder_subject' => 'Lembrete: Fatura :invoice de :account',
    'reset' => 'Redefinir',
    'invoice_not_found' => 'A fatura solicitada não está disponível',
    'referral_program' => 'Programa de Indicações',
    'referral_code' => 'URL de Indicação',
    'last_sent_on' => 'Último envio em :date',
    'page_expire' => 'Esta página irá expirar em breve, :click_here para continuar trabalhando',
    'upcoming_quotes' => 'Próximos Orçamentos',
    'expired_quotes' => 'Orçamentos Expirados',
    'sign_up_using' => 'Registre-se com',
    'invalid_credentials' => 'Estas credenciais não foram encontradas em nossos registros',
    'show_all_options' => 'Exibir todas as opções',
    'user_details' => 'Detalhes do Usuário',
    'oneclick_login' => 'Conta Conectada',
    'disable' => 'Desabilitar',
    'invoice_quote_number' => 'Números de Fatura e Orçamento',
    'invoice_charges' => 'Sobretaxas da Fatura',
    'notification_invoice_bounced' => 'Não conseguimos entregar a Fatura :invoice para :contact.',
    'notification_invoice_bounced_subject' => 'Não foi possível entregar a Fatura :invoice',
    'notification_quote_bounced' => 'Não conseguimos entregar o Orçamento :invoice para :contact.',
    'notification_quote_bounced_subject' => 'Não foi possível entregar o Orçamento :invoice',
    'custom_invoice_link' => 'Link Personalizado da Fatura',
    'total_invoiced' => 'Total Faturado',
    'open_balance' => 'Saldo Inicial do Período',
    'verify_email' => 'Por favor visite o link no email de confirmação para verificar seu endereço de email.',
    'basic_settings' => 'Configurações Básicas',
    'pro' => 'Pro',
    'gateways' => 'Gateways de Pagamento',
    'next_send_on' => 'Próximo Envio: :date',
    'no_longer_running' => 'Esta fatura não está agendada para execução',
    'general_settings' => 'Configurações Gerais',
    'customize' => 'Personalizar',
    'oneclick_login_help' => 'Vincule uma conta para logar sem uma senha.',
    'referral_code_help' => 'Ganhe dinheiro compartilhando nosso app online',
    'enable_with_stripe' => 'Habilite | Requer Stripe',
    'tax_settings' => 'Configurações de Impostos',
    'create_tax_rate' => 'Adicionar Taxa do Imposto',
    'updated_tax_rate' => 'Taxa de imposto atualizada com sucesso',
    'created_tax_rate' => 'Taxa de imposto criada com sucesso',
    'edit_tax_rate' => 'Editar Taxa do Imposto',
    'archive_tax_rate' => 'Arquivar Taxa de Imposto',
    'archived_tax_rate' => 'Taxa de imposto arquivada com sucesso',
    'default_tax_rate_id' => 'Taxa de Imposto Padrão',
    'tax_rate' => 'Taxa do Imposto',
    'recurring_hour' => 'Hora Recorrente',
    'pattern' => 'Padrão',
    'pattern_help_title' => 'Ajuda de Padrões',
    'pattern_help_1' => 'Crie números personalizados utilizando padrões.',
    'pattern_help_2' => 'Variáveis disponíveis:',
    'pattern_help_3' => 'Por exemplo, :example seria convertido para :value',
    'see_options' => 'Veja as opções',
    'invoice_counter' => 'Contador de Faturas',
    'quote_counter' => 'Contador de Orçamentos',
    'type' => 'Tipo',
    'activity_1' => ':user criou o cliente :client',
    'activity_2' => ':user arquivou o cliente :client',
    'activity_3' => ':user excluiu o cliente :client',
    'activity_4' => ':user criou a fatura :invoice',
    'activity_5' => ':user atualizou a fatura :invoice',
    'activity_6' => ':user enviou a fatura :invoice para :client do :contact',
    'activity_7' => ':contact viu a fatura :invoice para o :client',
    'activity_8' => ':user arquivou a fatura :invoice',
    'activity_9' => ':user excluiu a fatura :invoice',
    'activity_10' => ':contact efetuou o pagamento :payment de :payment_amount da fatura :invoice do cliente :client',
    'activity_11' => ':user atualizou o pagamento :payment',
    'activity_12' => ':user arquivou o pagamento :payment',
    'activity_13' => ':user excluiu o pagamento :payment',
    'activity_14' => ':user adicionou crédito :credit',
    'activity_15' => ':user atualizou crédito :credit',
    'activity_16' => ':user arquivou o crédito de :credit',
    'activity_17' => ':user excluiu crédito :credit',
    'activity_18' => ':user criou o orçamento :quote',
    'activity_19' => ':user atualizou o orçamento :quote',
    'activity_20' => ':user enviou o orçamento :quote do cliente :client para o contato :contact',
    'activity_21' => ':contact visualizou o orçamento :quote',
    'activity_22' => ':user arquivou o orçamento :quote',
    'activity_23' => ':user excluiu o orçamento :quote',
    'activity_24' => ':user restaurou o orçamento :quote',
    'activity_25' => ':user restaurou a fatura :invoice',
    'activity_26' => ':user restaurou o cliente :client',
    'activity_27' => ':user restaurou o pagamento :payment',
    'activity_28' => ':user restaurou o crédito :credit',
    'activity_29' => ':contact aprovou o orçamento :quote para o cliente :client',
    'activity_30' => ':user criou o fornecedor :vendor',
    'activity_31' => ':user arquivou o fornecedor :vendor',
    'activity_32' => ':user excluiu :vendor',
    'activity_33' => ':user restaurou o fornecedor :vendor',
    'activity_34' => ':user criou a despesa :expense',
    'activity_35' => ':user arquivou a despesa :expense',
    'activity_36' => ':user excluiu a despesa :expense',
    'activity_37' => ':user restaurou a despesa :expense',
    'activity_42' => ':user criou a tarefa :task',
    'activity_43' => ':user atualizou a tarefa :task',
    'activity_44' => ':user arquivou a tarefa :task',
    'activity_45' => ':user excluiu a tarefa :task',
    'activity_46' => ':user restaurou a tarefa :task',
    'activity_47' => ':user atualizou a despesa :expense',
    'activity_48' => ':user atualizou o ticket :ticket',
    'activity_49' => ':user fechou o ticket :ticket',
    'activity_50' => ':user uniu o ticket :ticket',
    'activity_51' => ':user dividiu o ticket :ticket',
    'activity_52' => ':contact abriu o ticket :ticket',
    'activity_53' => ':contact reabriu o ticket :ticket',
    'activity_54' => ':user reabriu o ticket :ticket',
    'activity_55' => ':contact respondeu o ticket :ticket',
    'activity_56' => ':user visualizou o ticket :ticket',

    'payment' => 'Pagamento',
    'system' => 'Sistema',
    'signature' => 'Assinatura do Email',
    'default_messages' => 'Mensagens Padrões',
    'quote_terms' => 'Condições do Orçamento',
    'default_quote_terms' => 'Condições Padrão dos Orçamentos',
    'default_invoice_terms' => 'Condições padrão da Fatura',
    'default_invoice_footer' => 'Rodapé Padrão de Faturas',
    'quote_footer' => 'Rodapé do Orçamento',
    'free' => 'Gratuito',
    'quote_is_approved' => 'Aprovada com sucesso',
    'apply_credit' => 'Aplicar Crédito',
    'system_settings' => 'Configurações do Sistema',
    'archive_token' => 'Arquivar Token',
    'archived_token' => 'Token arquivado com sucesso',
    'archive_user' => 'Arquivar Usuário',
    'archived_user' => 'Usuário arquivado com sucesso',
    'archive_account_gateway' => 'Excluir Gateway',
    'archived_account_gateway' => 'Gateway arquivado com sucesso',
    'archive_recurring_invoice' => 'Arquivar Fatura Recorrente',
    'archived_recurring_invoice' => 'Fatura Recorrente arquivada com sucesso',
    'delete_recurring_invoice' => 'Excluir Fatura Recorrente',
    'deleted_recurring_invoice' => 'Fatura recorrente excluída com sucesso',
    'restore_recurring_invoice' => 'Restaurar Fatura Recorrente',
    'restored_recurring_invoice' => 'Fatura Recorrente restaurada com sucesso',
    'archive_recurring_quote' => 'Arquivar Orçamento Recorrente',
    'archived_recurring_quote' => 'Orçamento recorrente arquivado com sucesso',
    'delete_recurring_quote' => 'Excluir Orçamento Recorrente',
    'deleted_recurring_quote' => 'Orçamento recorrente excluído com sucesso',
    'restore_recurring_quote' => 'Restaurar Orçamento Recorrente',
    'restored_recurring_quote' => 'Orçamento recorrente restaurado com sucesso',
    'archived' => 'Arquivado',
    'untitled_account' => 'Empresa Sem Nome',
    'before' => 'Antes',
    'after' => 'Depois',
    'reset_terms_help' => 'Redefinir para as condições padrão da conta',
    'reset_footer_help' => 'Redefinir para o rodapé padrão da conta',
    'export_data' => 'Exportar Dados',
    'user' => 'Usuário',
    'country' => 'País',
    'include' => 'Incluir',
    'logo_too_large' => 'Sua logo possui :size, para uma melhor performance do PDF sugerimos o envio de uma imagem menor que 200KB',
    'import_freshbooks' => 'Importar de FreshBooks',
    'import_data' => 'Importar Dados',
    'source' => 'Origem',
    'csv' => 'CSV',
    'client_file' => 'Arquivo de Clientes',
    'invoice_file' => 'Arquivo de Faturas',
    'task_file' => 'Arquivo de Tarefas',
    'no_mapper' => 'Sem mapeamento válido para o arquivo',
    'invalid_csv_header' => 'Cabeçalho do CSV inválido',
    'client_portal' => 'Portal do Cliente',
    'admin' => 'Admin',
    'disabled' => 'Desabilitado',
    'show_archived_users' => 'Exibir usuários arquivados',
    'notes' => 'Notas',
    'invoice_will_create' => 'fatura será criada',
    'invoices_will_create' => 'faturas serão criadas',
    'failed_to_import' => 'A importação dos seguintes registros falhou, ou eles já existem ou possuem campos obrigatórios faltando',
    'publishable_key' => 'Chave Publicável',
    'secret_key' => 'Chave Secreta',
    'missing_publishable_key' => 'Defina o sua chave publicável do Stripe para um processo de checkout melhorado',
    'email_design' => 'Design do Email',
    'due_by' => 'Vencido em :date',
    'enable_email_markup' => 'Habilitar Marcação',
    'enable_email_markup_help' => 'Tornar mais fácil para os seus clientes efetuarem seus pagamentos acrescentando marcações schema.org a seus emails.',
    'template_help_title' => 'Ajuda de Modelos',
    'template_help_1' => 'Variáveis disponíveis:',
    'email_design_id' => 'Estilo do Email',
    'email_design_help' => 'Faça seus emails parecerem mais profissionais com layouts HTML.',
    'plain' => 'Plano',
    'light' => 'Claro',
    'dark' => 'Escuro',
    'industry_help' => 'Usado para fornecer comparações contra as médias das empresas de tamanho e indústria similar.',
    'subdomain_help' => 'Definir o subdomínio ou mostrar a fatura em seu próprio website',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Especifique um prefixo ou usar um padrão personalizado para definir dinamicamente o número da fatura.',
    'quote_number_help' => 'Especifique um prefixo ou usar um padrão personalizado para definir dinamicamente o número do orçamento.',
    'custom_client_fields_helps' => 'Adicionar um campo durante a criação de um cliente e opcionalmente mostrar o rótulo e valor no PDF.',
    'custom_account_fields_helps' => 'Adicionar um rótulo e um valor para a seção detalhes da empresa do PDF.',
    'custom_invoice_fields_helps' => 'Adicionar um campo durante a criação de uma fatura e opcionalmente mostrar o rótulo e valor no PDF.',
    'custom_invoice_charges_helps' => 'Adicionar um campo durante a criação de uma fatura e incluir a cobrança no subtotal da fatura.',
    'token_expired' => 'Token de validação expirado. Por favor tente novamente!',
    'invoice_link' => 'Link da Fatura',
    'button_confirmation_message' => 'Clique para confirmar seu endereço de email.',
    'confirm' => 'Confirmar',
    'email_preferences' => 'Preferências de Emails',
    'created_invoices' => 'Criadas com sucesso :count fatura(s)',
    'next_invoice_number' => 'O próximo número de fatura será :number.',
    'next_quote_number' => 'O próximo número de orçamento será :number.',
    'days_before' => 'dias antes de',
    'days_after' => 'dias depois de',
    'field_due_date' => 'data de vencimento',
    'field_invoice_date' => 'data da fatura',
    'schedule' => 'Agendamento',
    'email_designs' => 'Designs de Email',
    'assigned_when_sent' => 'Atribuído quando enviado',
    'white_label_purchase_link' => 'Comprar uma licença white label',
    'expense' => 'Despesa',
    'expenses' => 'Despesas',
    'new_expense' => 'Informar Despesa',
    'enter_expense' => 'Incluir Despesa',
    'vendors' => 'Fornecedores',
    'new_vendor' => 'Novo Fornecedor',
    'payment_terms_net' => 'Prazo',
    'vendor' => 'Fornecedor',
    'edit_vendor' => 'Editar Fornecedor',
    'archive_vendor' => 'Arquivar Fornecedor',
    'delete_vendor' => 'Excluir Fornecedor',
    'view_vendor' => 'Visualizar Fornecedor',
    'deleted_expense' => 'Despesa excluída com sucesso',
    'archived_expense' => 'Despesa arquivada com sucesso',
    'deleted_expenses' => 'Despesas excluídas com sucesso',
    'archived_expenses' => 'Despesas arquivadas com sucesso',
    'expense_amount' => 'Quantia de Despesas',
    'expense_balance' => 'Saldo de Despesas',
    'expense_date' => 'Data da Despesa',
    'expense_should_be_invoiced' => 'Esta despesa deverá ser faturada?',
    'public_notes' => 'Notas Públicas',
    'invoice_amount' => 'Quantia da Fatura',
    'exchange_rate' => 'Taxa de Câmbio',
    'yes' => 'Sim',
    'no' => 'Não',
    'should_be_invoiced' => 'Deverá ser Faturada',
    'view_expense' => 'Visualizar despesa # :expense',
    'edit_expense' => 'Editar Despesa',
    'archive_expense' => 'Arquivar Despesa',
    'delete_expense' => 'Excluir Despesa',
    'view_expense_num' => 'Despesa # :expense',
    'updated_expense' => 'Despesa atualizada com sucesso',
    'created_expense' => 'Despesa criada com sucesso',
    'enter_expense' => 'Incluir Despesa',
    'view' => 'Visualizar',
    'restore_expense' => 'Restaurar Despesa',
    'invoice_expense' => 'Faturar Despesa',
    'expense_error_multiple_clients' => 'Despesas não podem pertencer a clientes diferentes',
    'expense_error_invoiced' => 'A Despesa já foi faturada',
    'convert_currency' => 'Converter moeda',
    'num_days' => 'Número de Dias',
    'create_payment_term' => 'Criar Condição de Pagamento',
    'edit_payment_terms' => 'Editar Condição de Pagamento',
    'edit_payment_term' => 'Editar Condição de Pagamento',
    'archive_payment_term' => 'Arquivar Condição de Pagamento',
    'recurring_due_dates' => 'Data de Vencimento das Faturas Recorrentes',
    'recurring_due_date_help' => '<p>Definir automaticamente a data de vencimento da fatura.</p>
        <p>Faturas em um ciclo mensal ou anual com vencimento anterior ou na data em que são criadas serão faturadas para o próximo mês. Faturas com vencimento no dia 29 ou 30 nos meses que não tem esse dia terão vencimento no último dia do mês..</p>
        <p>Faturas em um clclo semanal com vencimento no dia da semana em que foi criada terão vencimento para a próxima semana.</p>
        <p>Por exemplo:</p>
        <ul>
          <li>Hoje é dia 15, vencimento no primeiro dia do mês. O Vencimento será no primeiro dia do próximo mês.</li>
          <li>Hoje é dia 15, vencimento no último dia do mês. O Vencimento será no último dia do mês corrente</li>
          <li>Hoje é dia 15, vencimento no dia 15. O vencimento será no dia 15 do <strong>próximo</strong> mês.</li>
          <li>Hoje é Sexta-Feira, vencimento na primeira sexta-feira seguinte. O vencimento será na próxima sexta-feira, não hoje.</li>
        </ul>',
    'due' => 'Vencimento',
    'next_due_on' => 'Próximo Vencimento: :date',
    'use_client_terms' => 'Usar condições do cliente',
    'day_of_month' => ':ordinal dia do mês ',
    'last_day_of_month' => 'Último dia do mês',
    'day_of_week_after' => ':ordinal :day depois',
    'sunday' => 'Domingo',
    'monday' => 'Segunda-Feira',
    'tuesday' => 'Terça-Feira',
    'wednesday' => 'Quarta-Feira',
    'thursday' => 'Quinta-Feira',
    'friday' => 'Sexta-Feira',
    'saturday' => 'Sábado',
    'header_font_id' => 'Fonte do Cabeçalho',
    'body_font_id' => 'Fonte do Corpo',
    'color_font_help' => 'Nota: A cor e fonte primárias também são utilizadas no portal do cliente e designs personalizados de emails.',
    'live_preview' => 'Pré-visualização em Tempo Real',
    'invalid_mail_config' => 'Não foi possível enviar email, por favor verifique se as configurações de email estão corretas.',
    'invoice_message_button' => 'Para visualizar sua fatura de :amount, clique no botão abaixo.',
    'quote_message_button' => 'Para visualizar seu orçamento de :amount, clique no botão abaixo.',
    'payment_message_button' => 'Obrigado pelo seu pagamento de :amount.',
    'payment_type_direct_debit' => 'Débito Direto',
    'bank_accounts' => 'Cartões de Crédito & Bancos',
    'add_bank_account' => 'Adicionar Conta Bancária',
    'setup_account' => 'Configurar Conta',
    'import_expenses' => 'Importar Despesas',
    'bank_id' => 'Banco',
    'integration_type' => 'Tipo de Integração',
    'updated_bank_account' => 'Conta bancária atualizada com sucesso',
    'edit_bank_account' => 'Editar Conta Bancária',
    'archive_bank_account' => 'Arquivar Conta Bancária',
    'archived_bank_account' => 'Conta bancária arquivada com sucesso',
    'created_bank_account' => 'Conta bancária criada com sucesso',
    'validate_bank_account' => 'Validar Conta Bancária',
    'bank_password_help' => 'Nota: sua senha é transmitida de forma segura e nunca armazenada em nossos servidores.',
    'bank_password_warning' => 'Aviso: sua senha poderá ser transmitida em texto claro, considere habilitar HTTPS.',
    'username' => 'Usuário',
    'account_number' => 'Número de Conta',
    'account_name' => 'Nome da Conta',
    'bank_account_error' => 'Falha ao recuperar detalhes da conta, favor verificar suas credenciais.',
    'status_approved' => 'Aprovado',
    'quote_settings' => 'Configurações de Orçamentos',
    'auto_convert_quote' => 'Auto Conversão',
    'auto_convert_quote_help' => 'Converter automaticamente um orçamento quando for aprovado pelo cliente.',
    'validate' => 'Validar',
    'info' => 'Info',
    'imported_expenses' => ':count_vendors fornecedor(es) e :count_expenses despesa(s) criados com sucesso',
    'iframe_url_help3' => 'Nota: se você planeja aceitar detalhes de cartões de crédito recomendamos fortemente habilitar HTTPS no seu site',
    'expense_error_multiple_currencies' => 'As despesas não podem ter moedas diferentes.',
    'expense_error_mismatch_currencies' => 'A moeda do cliente não coincide com a moeda da despesa.',
    'trello_roadmap' => 'Roadmap do Trello',
    'header_footer' => 'Cabeçalho/Rodapé',
    'first_page' => 'Primeira página',
    'all_pages' => 'Todas as páginas',
    'last_page' => 'Última página',
    'all_pages_header' => 'Exibir Cabeçalho em',
    'all_pages_footer' => 'Exibir Rodapé em',
    'invoice_currency' => 'Moeda da Fatura',
    'enable_https' => 'Recomendamos fortemente a utilização de HTTPS para aceitar detalhes do cartão de crédito online.',
    'quote_issued_to' => 'Orçamento emitido para',
    'show_currency_code' => 'Código da Moeda',
    'free_year_message' => 'Sua conta foi atualizada para o Plano Pro por um ano, sem custo.',
    'trial_message' => 'Sua conta receberá duas semanas para testar nosso plano pro gratuitamente.',
    'trial_footer' => 'Seu período de teste do plano pro durará mais :count dias, :link para adquirir agora.',
    'trial_footer_last_day' => 'Hoje é o último dia do seu teste gratuito do plano pro, :link para adquirir agora.',
    'trial_call_to_action' => 'Iniciar Período de Testes',
    'trial_success' => 'Teste de duas semanas no Plano PRO habilitado com sucesso',
    'overdue' => 'Vencido',


    'white_label_text' => 'Compre uma licença white-label por UM ANO por $:price para remover a marca do Invoice Ninja da fatura e do portal do cliente.',
    'user_email_footer' => 'Para ajustar suas configurações de notificações de email por favor acesse :link',
    'reset_password_footer' => 'Se você não solicitou esta redefinição de senha por favor envie um email para o nosso suporte: :email',
    'limit_users' => 'Desculpe, isto irá exceder o limite de :limit usuários',
    'more_designs_self_host_header' => 'Obtenha mais 6 designs de faturas por apenas $:price',
    'old_browser' => 'Por favor use um :link',
    'newer_browser' => 'navegador mais novo',
    'white_label_custom_css' => ':link por $:price para permitir personalização de estilos e apoiar o nosso projecto.',
    'bank_accounts_help' => 'Conecte uma conta bancária para importar automaticamente despesas e criar fornecedores. Suporta American Express e :link.',
    'us_banks' => '+400 bancos nos EUA',

    'pro_plan_remove_logo' => ':link para remover a logo do Invoice Ninja adquirindo o Plano Pro',
    'pro_plan_remove_logo_link' => 'Clique aqui',
    'invitation_status_sent' => 'Enviado',
    'invitation_status_opened' => 'Aberto',
    'invitation_status_viewed' => 'Visualizado',
    'email_error_inactive_client' => 'Emails não podem ser enviados para clientes inativos',
    'email_error_inactive_contact' => 'Emails não podem ser enviados para contatos inativos',
    'email_error_inactive_invoice' => 'Emails não podem ser enviados para faturas inativas',
    'email_error_inactive_proposal' => 'Emails não podem ser enviados para propostas inativas',
    'email_error_user_unregistered' => 'Favor registrar sua conta para enviar emails',
    'email_error_user_unconfirmed' => 'Favor confirmar sua conta para enviar emails',
    'email_error_invalid_contact_email' => 'Email do contato inválido',

    'navigation' => 'Navegação',
    'list_invoices' => 'Listar Faturas',
    'list_clients' => 'Listar Clientes',
    'list_quotes' => 'Listar Orçamentos',
    'list_tasks' => 'Listar Tarefas',
    'list_expenses' => 'Listar Despesas',
    'list_recurring_invoices' => 'Listar Faturas Recorrentes',
    'list_payments' => 'Listar Pagamentos',
    'list_credits' => 'Listar Créditos',
    'tax_name' => 'Nome do Imposto',
    'report_settings' => 'Configuração de Relatórios',
    'search_hotkey' => 'atalho é /',

    'new_user' => 'Novo Usuário',
    'new_product' => 'Novo Produto',
    'new_tax_rate' => 'Nova Taxa de Imposto',
    'invoiced_amount' => 'Quantia Faturada',
    'invoice_item_fields' => 'Campos de Itens da Fatura',
    'custom_invoice_item_fields_help' => 'Adicionar um campo ao criar um ítem de fatura e mostrar o rótulo e valor no PDF.',
    'recurring_invoice_number' => 'Número Recorrente',
    'recurring_invoice_number_prefix_help' => 'Especifique um prefixo para ser adicionado ao número da fatura para faturas recorrentes.',

    // Client Passwords
    'enable_portal_password' => 'Proteger Faturas com Senha',
    'enable_portal_password_help' => 'Permite definir uma senha para cada contato. Se uma senha for definida, o contato deverá informar uma senha antes de visualizar faturas.',
    'send_portal_password' => 'Gerar Automaticamente',
    'send_portal_password_help' => 'Se nenhuma senha for definida, uma será gerada e enviada com a primeira fatura.',

    'expired' => 'Expirado',
    'invalid_card_number' => 'O número do cartão de crédito não é válido.',
    'invalid_expiry' => 'A data de expiração não é válida.',
    'invalid_cvv' => 'O código CVV não é válido.',
    'cost' => 'Custo',
    'create_invoice_for_sample' => 'Nota: crie sua primeira fatura para ver um preview aqui.',

    // User Permissions
    'owner' => 'Proprietário',
    'administrator' => 'Administrador',
    'administrator_help' => 'Permite ao usuário gerenciar usuários, mudar configurações e modificar todos os registros',
    'user_create_all' => 'Criar clientes, faturas, etc.',
    'user_view_all' => 'Visualizar todos os clientes, faturas, etc.',
    'user_edit_all' => 'Editar todos os clientes, faturas, etc.',
    'gateway_help_20' => ':link para cadastrar-se no Sage Pay.',
    'gateway_help_21' => ':link para cadastrar-se no Sage Pay.',
    'partial_due' => 'Vencimento Parcial',
    'restore_vendor' => 'Restaurar Fornecedor',
    'restored_vendor' => 'Fornecedor restaurado com sucesso',
    'restored_expense' => 'Despesa restaurada com sucesso',
    'permissions' => 'Permissões',
    'create_all_help' => 'Permite ao usuário criar e modificar registros',
    'view_all_help' => 'Permite ao usuário visualizar registros que ele não criou',
    'edit_all_help' => 'Permite ao usuário modificar registros que ele não criou',
    'view_payment' => 'Visualizar Pagamento',

    'january' => 'Janeiro',
    'february' => 'Fevereiro',
    'march' => 'Março',
    'april' => 'Abril',
    'may' => 'Maio',
    'june' => 'Junho',
    'july' => 'Julho',
    'august' => 'Agosto',
    'september' => 'Setembro',
    'october' => 'Outubro',
    'november' => 'Novembro',
    'december' => 'Dezembro',

    // Documents
    'documents_header' => 'Documentos:',
    'email_documents_header' => 'Documentos:',
    'email_documents_example_1' => 'Recibos de Widgets.pdf',
    'email_documents_example_2' => 'Entregável Final.zip',
    'quote_documents' => 'Documentos de Orçamentos',
    'invoice_documents' => 'Documentos de Faturas',
    'expense_documents' => 'Documentos de Despesas',
    'invoice_embed_documents' => 'Embutir Documentos',
    'invoice_embed_documents_help' => 'Incluir imagens anexas na fatura.',
    'document_email_attachment' => 'Anexar Documentos',
    'ubl_email_attachment' => 'Anexar UBL',
    'download_documents' => 'Baixar Documentos (:size)',
    'documents_from_expenses' => 'De Despesas:',
    'dropzone_default_message' => 'Solte arquivos ou clique para fazer upload',
    'dropzone_default_message_disabled' => 'Uploads desabilitados',
    'dropzone_fallback_message' => 'Seu navegador não suporte upload de arquivos arraste & solte.',
    'dropzone_fallback_text' => 'Por favor utilize o formulário de fallback abaixo para enviar seus arquivos como nos velhos tempos.',
    'dropzone_file_too_big' => 'O arquivo é grande demais ({{filesize}}MiB). Tam. Máximo de arquivo: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Você não pode fazer upload de arquivos desse tipo.',
    'dropzone_response_error' => 'Servidor respondeu com código {{statusCode}}.',
    'dropzone_cancel_upload' => 'Cancelar envio',
    'dropzone_cancel_upload_confirmation' => 'Você tem certeza que deseja cancelar este envio?',
    'dropzone_remove_file' => 'Remover arquivo',
    'documents' => 'Documentos',
    'document_date' => 'Data do Documento',
    'document_size' => 'Tamanho',

    'enable_client_portal' => 'Portal do Cliente',
    'enable_client_portal_help' => 'Exibe/esconde o portal do cliente.',
    'enable_client_portal_dashboard' => 'Painel',
    'enable_client_portal_dashboard_help' => 'Exibe/esconde o painel no portal do cliente.',

    // Plans
    'account_management' => 'Gerenciamento da Conta',
    'plan_status' => 'Status do Plano',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Alterar Plano',
    'pending_change_to' => 'Muda para',
    'plan_changes_to' => ':plan em :date',
    'plan_term_changes_to' => ':plan (:term) em :date',
    'cancel_plan_change' => 'Cancelar Mudança',
    'plan' => 'Plano',
    'expires' => 'Expira',
    'renews' => 'Renova',
    'plan_expired' => 'Plano :plan Expirado',
    'trial_expired' => 'Teste do Plano :plan Terminado',
    'never' => 'Nunca',
    'plan_free' => 'Gratuito',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Empresarial',
    'plan_white_label' => 'Auto-Hospedado (White labeled)',
    'plan_free_self_hosted' => 'Auto-Hospedado (Gratuito)',
    'plan_trial' => 'Teste',
    'plan_term' => 'Condição',
    'plan_term_monthly' => 'Mensal',
    'plan_term_yearly' => 'Anual',
    'plan_term_month' => 'Mês',
    'plan_term_year' => 'Ano',
    'plan_price_monthly' => '$:price/Mês',
    'plan_price_yearly' => '$:price/Ano',
    'updated_plan' => 'Configurações de plano atualizadas',
    'plan_paid' => 'Condições Iniciadas',
    'plan_started' => 'Plano Iniciado',
    'plan_expires' => 'Expiração do Plano',

    'white_label_button' => 'White Label',

    'pro_plan_year_description' => 'Inscrição de um ano no Plano Pro do Invoice Ninja',
    'pro_plan_month_description' => 'Inscrição de um mês no Plano Pro do Invoice Ninja',
    'enterprise_plan_product' => 'Plano Empresarial',
    'enterprise_plan_year_description' => 'Inscrição de um ano no Plano Pro do Invoice Ninja',
    'enterprise_plan_month_description' => 'Inscrição de um mês no Plano Pro do Invoice Ninja',
    'plan_credit_product' => 'Crédito',
    'plan_credit_description' => 'Crédito por tempo não utilizado',
    'plan_pending_monthly' => 'Vai trocar por mensal em :date',
    'plan_refunded' => 'Um reembolso foi solicitado.',

    'live_preview' => 'Pré-visualização em Tempo Real',
    'page_size' => 'Tamanho da Página',
    'live_preview_disabled' => 'Visualização ao vivo foi desabilitada para suportar a fonte selecionada',
    'invoice_number_padding' => 'Espaçamento',
    'preview' => 'Preview',
    'list_vendors' => 'Listar Fornecedores',
    'add_users_not_supported' => 'Atualize para o Plano Empresarial para incluir usuários adicionais em sua conta.',
    'enterprise_plan_features' => 'O plano Empresarial inclui o suporte a múltiplos usuários e arquivos anexos, :link para ver a lista completa de funcionalidades.',
    'return_to_app' => 'Voltar ao App',


    // Payment updates
    'refund_payment' => 'Reembolsar Pagamento',
    'refund_max' => 'Máx:',
    'refund' => 'Reembolsar',
    'are_you_sure_refund' => 'Reembolsar pagamentos selecionados?',
    'status_pending' => 'Pendente',
    'status_completed' => 'Completo',
    'status_failed' => 'Falhou',
    'status_partially_refunded' => 'Parcialmente Reembolsado',
    'status_partially_refunded_amount' => ':amount Reembolsado',
    'status_refunded' => 'Reembolsado',
    'status_voided' => 'Cancelado',
    'refunded_payment' => 'Pagamento Reembolsado',
    'activity_39' => ':user cancelou um pagamento de :payment_amount em :payment',
    'activity_40' => ':user reembolsou :adjustment de um pagamento :payment_amount em :payment',
    'card_expiration' => 'Venc:&nbsp:expires',

    'card_creditcardother' => 'Desconhecido',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Aceitar transferência bancária dos Estados Unidos',
    'stripe_ach_help' => 'Suporte a ACH também precisar estar habilitado em :link.',
    'ach_disabled' => 'Outro gateway já está configurado para débito direto.',

    'plaid' => 'Plaid',
    'client_id' => 'Cód Cliente',
    'secret' => 'Segredo',
    'public_key' => 'Chave Pública',
    'plaid_optional' => '(opcional)',
    'plaid_environment_help' => 'Quando uma chave de teste do Stripe é dada, o ambiente de desenvolvimento do Plaid (tartan) será utilizado.',
    'other_providers' => 'Outros Provedores',
    'country_not_supported' => 'Este país não é suportado.',
    'invalid_routing_number' => 'O número de roteamento é inválido.',
    'invalid_account_number' => 'O número da conta é inválido.',
    'account_number_mismatch' => 'Os números de conta não combinam.',
    'missing_account_holder_type' => 'Selecione se é uma conta individual ou empresarial.',
    'missing_account_holder_name' => 'Por favor informe o nome do proprietário da conta.',
    'routing_number' => 'Número de Roteamento',
    'confirm_account_number' => 'Confirmar Número da Conta',
    'individual_account' => 'Conta Individual',
    'company_account' => 'Conta Empresarial',
    'account_holder_name' => 'Nome do Proprietário da Conta',
    'add_account' => 'Adicionar Conta',
    'payment_methods' => 'Formas de Pagamentos',
    'complete_verification' => 'Completar Verificação',
    'verification_amount1' => 'Quantia 1',
    'verification_amount2' => 'Quantia 2',
    'payment_method_verified' => 'Verificação completa com sucesso',
    'verification_failed' => 'Verificação Falhou',
    'remove_payment_method' => 'Remover Forma de Pagamento',
    'confirm_remove_payment_method' => 'Tem certeza que deseja remover esta forma de pagamento?',
    'remove' => 'Remover',
    'payment_method_removed' => 'Forma de pagamento removida.',
    'bank_account_verification_help' => 'Nós fizemos dois depósitos na sua conta com a descrição "VERIFICATION". Esses depósitos podem levar 1-2 dias úteis para aparecer no seu extrato. Por favor informe as quantias abaixo.',
    'bank_account_verification_next_steps' => 'Nós fizemos dois depósitos na sua conta com a descrição "VERIFICATION". Esses depósitos podem levar 1-2 dias úteis para aparecer no seu extrato.
Quando tiver as quantias, volte a esta página de formas de pagamento e clique "Completar Verificação" próximo à conta.',
    'unknown_bank' => 'Banco Desconhecido',
    'ach_verification_delay_help' => 'Você poderá utilizar esta conta após a completar a verificação. A verificação normalmente leva 1-2 dias úteis.',
    'add_credit_card' => 'Adicionar Cartão de Crédito',
    'payment_method_added' => 'Forma de pagamento adicionada.',
    'use_for_auto_bill' => 'Usar para Cobrança Automática',
    'used_for_auto_bill' => 'Forma de Pagamento Automática',
    'payment_method_set_as_default' => 'Definir forma de pagamento automática.',
    'activity_41' => 'Pagamento :payment_amount (:payment) falhou',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Você deve :link.',
    'stripe_webhook_help_link_text' => 'adicionar esta URL como um endpoint no Stripe',
    'gocardless_webhook_help_link_text' => 'adicione esta URL como um endpoint no GoCardless',
    'payment_method_error' => 'Houve um erro ao adicionar sua forma de pagamento. Por favor tente novamente mais tarde.',
    'notification_invoice_payment_failed_subject' => 'Pagamento falhou para a Fatura :invoice',
    'notification_invoice_payment_failed' => 'Um pagamento feito pelo cliente :client para a Fatura :invoice falhou. O pagamento foi marcado como falho e :amount foi adicionado ao saldo do cliente.',
    'link_with_plaid' => 'Vincular Conta Instantaneamente com Plaid',
    'link_manually' => 'Vincular Manualmente',
    'secured_by_plaid' => 'Segurado por Plaid',
    'plaid_linked_status' => 'Sua conta bancária no :bank',
    'add_payment_method' => 'Adicionar Forma de Pagamento',
    'account_holder_type' => 'Tipo do Proprietário da Conta',
    'ach_authorization' => 'Eu autorizo :company a usar minha conta bancária para futuros pagamentos e, se necessário, creditar eletronicamente minha conta para corrigir débitos errados. Eu entendo que eu poderei cancelar essa autorização a qualquer momento removendo a forma de pagamento ou contatando  :email.',
    'ach_authorization_required' => 'Você deve concordar com transações ACH.',
    'off' => 'Desligado',
    'opt_in' => 'Autorizar',
    'opt_out' => 'Desautorizar',
    'always' => 'Sempre',
    'opted_out' => 'Desautorizado',
    'opted_in' => 'Autorizou',
    'manage_auto_bill' => 'Gerenciar Cobrança Automática',
    'enabled' => 'Habilitado',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Habilitar pagamentos do PayPal através do BrainTree',
    'braintree_paypal_disabled_help' => 'O gateway PayPal está processando pagamentos do PayPal',
    'braintree_paypal_help' => 'Você deve também :link.',
    'braintree_paypal_help_link_text' => 'vincular o PayPal à sua conta do BrainTree',
    'token_billing_braintree_paypal' => 'Salvar detalhes do pagamento',
    'add_paypal_account' => 'Adicionar Conta do PayPal',


    'no_payment_method_specified' => 'Nenhuma forma de pagamento especificada',
    'chart_type' => 'Tipo de Gráfico',
    'format' => 'Formato',
    'import_ofx' => 'Importar OFX',
    'ofx_file' => 'Arquivo OFX',
    'ofx_parse_failed' => 'Falha ao interpretar o arquivo OFX',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Registrar com WePay',
    'use_another_provider' => 'Utilizar outro provedor',
    'company_name' => 'Nome da Empresa',
    'wepay_company_name_help' => 'Isso vai aparecer na fatura do cartão de crédito do cliente.',
    'wepay_description_help' => 'O objetivo desta conta.',
    'wepay_tos_agree' => 'Concordo com o :link.',
    'wepay_tos_link_text' => 'Termos de Serviço do WePay',
    'resend_confirmation_email' => 'Reenviar Email de Confirmação',
    'manage_account' => 'Gerenciar Conta',
    'action_required' => 'Ação Requerida',
    'finish_setup' => 'Finalizar Configuração',
    'created_wepay_confirmation_required' => 'Por favor verifique seu email e confirme seu endereço de email com o WePay',
    'switch_to_wepay' => 'Mudar para WePay',
    'switch' => 'Mudar',
    'restore_account_gateway' => 'Restaurar Gateway',
    'restored_account_gateway' => 'Gateway restaurado com sucesso',
    'united_states' => 'Estados Unidos',
    'canada' => 'Canadá',
    'accept_debit_cards' => 'Aceitar Cartão de Débito',
    'debit_cards' => 'Cartões de Débito',

    'warn_start_date_changed' => 'A próxima fatura será enviada na nova data de início.',
    'warn_start_date_changed_not_sent' => 'A próxima fatura será criada na nova data de início.',
    'original_start_date' => 'Data de início original',
    'new_start_date' => 'Nova data de início',
    'security' => 'Segurança',
    'see_whats_new' => 'Veja as novidades na v:version',
    'wait_for_upload' => 'Aguarde a conclusão do upload do documento.',
    'upgrade_for_permissions' => 'Upgrade para o plano Empresarial para habilitar permissões.',
    'enable_second_tax_rate' => 'Habilitar a especificação de uma <b>segunda taxa de imposto</b>',
    'payment_file' => 'Arquivo de Pagamento',
    'expense_file' => 'Arquivo de Despesa',
    'product_file' => 'Arquivo de Produto',
    'import_products' => 'Importar Produtos',
    'products_will_create' => 'produtos serão criados',
    'product_key' => 'Produto',
    'created_products' => 'Sucesso ao criar/atualizar :count produto(s)',
    'export_help' => 'Use JSON se você planeja importar os dados para o Invoice Ninja.<br/> O Arquivo inclui clientes, produtos, faturas, orçamentos e pagamentos.',
    'selfhost_export_help' => '<br/>Nós recomendamos utilizar mysqldump para criar um backup completo.',
    'JSON_file' => 'Arquivo JSON',

    'view_dashboard' => 'Ver Painel',
    'client_session_expired' => 'Sessão Expirada',
    'client_session_expired_message' => 'Sua sessão expirou. Por favor, clique novamente no link enviado para seu email.',

    'auto_bill_notification' => 'A Fatura será cobrada automaticamente por :payment_method em :due_date',
    'auto_bill_payment_method_bank_transfer' => 'conta bancária',
    'auto_bill_payment_method_credit_card' => 'cartão de crédito',
    'auto_bill_payment_method_paypal' => 'Conta PayPal',
    'auto_bill_notification_placeholder' => 'Essa fatura será cobrada automaticamente para o seu cartão de crédito na data de vencimento.',
    'payment_settings' => 'Configurações de Pagamento',

    'on_send_date' => 'Na data de envio',
    'on_due_date' => 'Na data de vencimento',
    'auto_bill_ach_date_help' => 'ACH sempre fará a cobrança automaticamente na data de vencimento.',
    'warn_change_auto_bill' => 'Pelas regras NACHA, mudanças nessa fatura podem impedir a cobrança automática por ACH.',

    'bank_account' => 'Conta Bancária',
    'payment_processed_through_wepay' => 'Pagamentos ACH serão processados usando WePay.',
    'wepay_payment_tos_agree' => 'Eu concordo com os :terms e :privacy_policy do WePay.',
    'privacy_policy' => 'Política de Privacidade',
    'wepay_payment_tos_agree_required' => 'Você deve concordar com os Termos de Serviço e Política de Privacidade do WePay.',
    'ach_email_prompt' => 'Por favor digite seu endereço de email:',
    'verification_pending' => 'Verificação Pendente',

    'update_font_cache' => 'Por favor, force a atualização da página para atualizar o cache de fontes.',
    'more_options' => 'Mais opções',
    'credit_card' => 'Cartão de Crédito',
    'bank_transfer' => 'Transferência Bancária',
    'no_transaction_reference' => 'Nós não recebemos uma referência da transação de pagamento do gateway.',
    'use_bank_on_file' => 'Usar Banco em Arquivo',
    'auto_bill_email_message' => 'Essa fatura será cobrada automaticamente pelo método de pagamento em arquivo na data de vencimento.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => ':date adicionado',
    'failed_remove_payment_method' => 'Falha ao remover a forma de pagamento',
    'gateway_exists' => 'Esse gateway já existe',
    'manual_entry' => 'Entrada manual',
    'start_of_week' => 'Primeiro dia da Semana',

    // Frequencies
    'freq_inactive' => 'Inativo',
    'freq_daily' => 'Diariamente',
    'freq_weekly' => 'Semanalmente',
    'freq_biweekly' => 'Duas vezes por semana',
    'freq_two_weeks' => '2 semanas',
    'freq_four_weeks' => '4 semanas',
    'freq_monthly' => 'Mensalmente',
    'freq_three_months' => '3 meses',
    'freq_four_months' => '4 meses',
    'freq_six_months' => '6 meses',
    'freq_annually' => 'Anualmente',
    'freq_two_years' => '2 anos',

    // Payment types
    'payment_type_Apply Credit' => 'Aplicar Crédito',
    'payment_type_Bank Transfer' => 'Transferência Bancária',
    'payment_type_Cash' => 'Dinheiro',
    'payment_type_Debit' => 'Débito',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Cartão Visa',
    'payment_type_MasterCard' => 'Cartão MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Cartão Discover',
    'payment_type_Diners Card' => 'Cartão Diners',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Outro Cartão de Crédito',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Cheque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'Débito Direto SEPA',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidade & Jurídico',
    'industry_Advertising' => 'Publicidade',
    'industry_Aerospace' => 'Aeroespacial',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automotivo',
    'industry_Banking & Finance' => 'Bancário & Finanças',
    'industry_Biotechnology' => 'Biotecnologia',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Serviços Empresariais',
    'industry_Commodities & Chemicals' => 'Commodities & Químicos',
    'industry_Communications' => 'Comunicações',
    'industry_Computers & Hightech' => 'Computadores e Tecnologia',
    'industry_Defense' => 'Defesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Entretenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Saúde & Ciências da Vida',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Manufatura',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Mídia',
    'industry_Nonprofit & Higher Ed' => 'Sem Fins Lucrativos e Educação',
    'industry_Pharmaceuticals' => 'Farmacêuticos',
    'industry_Professional Services & Consulting' => 'Serviços Profissionais e Consultoria',
    'industry_Real Estate' => 'Imóveis',
    'industry_Restaurant & Catering' => 'Restaurantes e Bufês',
    'industry_Retail & Wholesale' => 'Atacado e Varejo',
    'industry_Sports' => 'Esportes',
    'industry_Transportation' => 'Transportes',
    'industry_Travel & Luxury' => 'Viagens e Luxo',
    'industry_Other' => 'Outros',
    'industry_Photography' => 'Fotografia',

    // Countries
    'country_Afghanistan' => 'Afeganistão',
    'country_Albania' => 'Albânia',
    'country_Antarctica' => 'Antártida',
    'country_Algeria' => 'Argélia',
    'country_American Samoa' => 'Samoa Americana',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antígua e Barbuda',
    'country_Azerbaijan' => 'Azerbaijão',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Austrália',
    'country_Austria' => 'Áustria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Barém',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armênia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Bélgica',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Butão',
    'country_Bolivia, Plurinational State of' => 'Bolívia',
    'country_Bosnia and Herzegovina' => 'Bósnia e Herzegovina',
    'country_Botswana' => 'Botsuana',
    'country_Bouvet Island' => 'Ilha Bouvet',
    'country_Brazil' => 'Brasil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'Território Oceânico das Índias Britânicas',
    'country_Solomon Islands' => 'Ilhas Salomão',
    'country_Virgin Islands, British' => 'Ilhas Virgens Britânicas',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgária',
    'country_Myanmar' => 'Mianmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Bielorrússia',
    'country_Cambodia' => 'Camboja',
    'country_Cameroon' => 'Camarões',
    'country_Canada' => 'Canadá',
    'country_Cape Verde' => 'Cabo Verde',
    'country_Cayman Islands' => 'Ilhas Cayman',
    'country_Central African Republic' => 'República Centro-Africana',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chade',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Província da China',
    'country_Christmas Island' => 'Ilha Christmas',
    'country_Cocos (Keeling) Islands' => 'Ilhas Cocos (Keeling)',
    'country_Colombia' => 'Colômbia',
    'country_Comoros' => 'Comores',
    'country_Mayotte' => ' Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'República Democrática do Congo',
    'country_Cook Islands' => 'Ilhas Cook',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croácia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Chipre',
    'country_Czech Republic' => 'República Tcheca',
    'country_Benin' => 'Benim',
    'country_Denmark' => 'Dinamarca',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'República Dominicana',
    'country_Ecuador' => 'Equador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Guiné Equatorial',
    'country_Ethiopia' => 'Etiópia',
    'country_Eritrea' => 'Eritréia',
    'country_Estonia' => 'Estônia',
    'country_Faroe Islands' => 'Ilhas Faroe',
    'country_Falkland Islands (Malvinas)' => 'Ilhas Falkland (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'Ilhas Geórgia do Sul e Sandwich do Sul',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finlândia',
    'country_Åland Islands' => 'Ilhas Aland',
    'country_France' => 'França',
    'country_French Guiana' => 'Guiana Francesa',
    'country_French Polynesia' => 'Polinésia Francesa',
    'country_French Southern Territories' => 'Territórios Franceses do Sul',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabão',
    'country_Georgia' => 'Geórgia',
    'country_Gambia' => 'Gâmbia',
    'country_Palestinian Territory, Occupied' => 'Território Palestino Ocupado',
    'country_Germany' => 'Alemanha',
    'country_Ghana' => 'Gana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => ' Kiribati',
    'country_Greece' => 'Grécia',
    'country_Greenland' => 'Groenlândia',
    'country_Grenada' => 'Granada',
    'country_Guadeloupe' => 'Guadalupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guiné',
    'country_Guyana' => 'Guiana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Ilha Heard e Ilhas McDonald',
    'country_Holy See (Vatican City State)' => 'Vaticano (Cidade do)',
    'country_Honduras' => ' Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungria',
    'country_Iceland' => 'Islândia',
    'country_India' => 'Índia',
    'country_Indonesia' => 'Indonésia',
    'country_Iran, Islamic Republic of' => 'República Islâmica do Irã',
    'country_Iraq' => 'Iraque',
    'country_Ireland' => 'Irlanda',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Itália',
    'country_Côte d\'Ivoire' => 'Costa do Marfim',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japão',
    'country_Kazakhstan' => 'Cazaquistão',
    'country_Jordan' => 'Jordânia',
    'country_Kenya' => 'Quênia',
    'country_Korea, Democratic People\'s Republic of' => 'Coréia do Norte',
    'country_Korea, Republic of' => 'Coréia do Sul',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Quirguistão',
    'country_Lao People\'s Democratic Republic' => 'Laos',
    'country_Lebanon' => 'Líbano',
    'country_Lesotho' => 'Lesoto',
    'country_Latvia' => 'Letônia',
    'country_Liberia' => 'Libéria',
    'country_Libya' => 'Líbia',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lituânia',
    'country_Luxembourg' => 'Luxemburgo',
    'country_Macao' => 'Macau',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => ' Malawi',
    'country_Malaysia' => 'Malásia',
    'country_Maldives' => 'Maldivas',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinica',
    'country_Mauritania' => 'Mauritânia',
    'country_Mauritius' => 'Maurício',
    'country_Mexico' => 'México',
    'country_Monaco' => 'Mônaco',
    'country_Mongolia' => 'Mongólia',
    'country_Moldova, Republic of' => 'Moldávia',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Marrocos',
    'country_Mozambique' => 'Moçambique',
    'country_Oman' => 'Omã',
    'country_Namibia' => 'Namíbia',
    'country_Nauru' => ' Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Holanda',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'São Martinho (países baixos)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Países Baixos Caribenhos',
    'country_New Caledonia' => 'Nova Caledônia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'Nova Zelândia',
    'country_Nicaragua' => 'Nicarágua',
    'country_Niger' => 'Níger',
    'country_Nigeria' => 'Nigéria',
    'country_Niue' => ' Niue',
    'country_Norfolk Island' => 'Ilhas Norfolk',
    'country_Norway' => 'Noruega',
    'country_Northern Mariana Islands' => 'Ilhas Mariana do Norte',
    'country_United States Minor Outlying Islands' => 'Ilhas Menores Distantes dos Estados Unidos',
    'country_Micronesia, Federated States of' => 'Micronésia, Estados Federados da',
    'country_Marshall Islands' => 'Ilhas Marshall',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Paquistão',
    'country_Panama' => 'Panamá',
    'country_Papua New Guinea' => 'Papua Nova Guiné',
    'country_Paraguay' => 'Paraguai',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Filipinas',
    'country_Pitcairn' => 'Ilhas Pitcairn',
    'country_Poland' => 'Polônia',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guiné-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Porto Rico',
    'country_Qatar' => 'Catar',
    'country_Réunion' => 'Reunião',
    'country_Romania' => 'Romênia',
    'country_Russian Federation' => 'Rússia',
    'country_Rwanda' => 'Ruanda',
    'country_Saint Barthélemy' => 'São Bartolomeu',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Santa Helena, Ascensão e Tristão da Cunha',
    'country_Saint Kitts and Nevis' => 'São Cristovão-Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Santa Lúcia',
    'country_Saint Martin (French part)' => 'São Martinho (parte francesa)',
    'country_Saint Pierre and Miquelon' => 'Saint-Pierre e Miquelon',
    'country_Saint Vincent and the Grenadines' => 'São Vicente e Granadinas',
    'country_San Marino' => 'São Marino',
    'country_Sao Tome and Principe' => 'São Tome e Príncipe',
    'country_Saudi Arabia' => 'Arábia Saudita',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Sérvia',
    'country_Seychelles' => 'Seicheles',
    'country_Sierra Leone' => 'Serra Leoa',
    'country_Singapore' => 'Cingapura',
    'country_Slovakia' => 'Eslováquia',
    'country_Viet Nam' => 'Vietnã',
    'country_Slovenia' => 'Eslovênia',
    'country_Somalia' => 'Somália',
    'country_South Africa' => 'África do Sul',
    'country_Zimbabwe' => 'Zimbábue',
    'country_Spain' => 'Espanha',
    'country_South Sudan' => 'Sudão do Sul',
    'country_Sudan' => 'Sudão',
    'country_Western Sahara' => 'Saara Ocidental',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard e Jan Mayen',
    'country_Swaziland' => 'Suazilândia',
    'country_Sweden' => 'Suécia',
    'country_Switzerland' => 'Suíça',
    'country_Syrian Arab Republic' => 'Síria',
    'country_Tajikistan' => 'Tajiquistão',
    'country_Thailand' => 'Tailândia',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad e Tobago',
    'country_United Arab Emirates' => 'Emirados Árabes Unidos',
    'country_Tunisia' => 'Tunísia',
    'country_Turkey' => 'Turquia',
    'country_Turkmenistan' => 'Turcomenistão',
    'country_Turks and Caicos Islands' => 'Ilhas Turks e Caicos',
    'country_Tuvalu' => ' Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ucrânia',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedônia, antiga República Iugoslava',
    'country_Egypt' => 'Egito',
    'country_United Kingdom' => 'Reino Unido',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => ' Jersey',
    'country_Isle of Man' => 'Ilha de Man',
    'country_Tanzania, United Republic of' => 'Tanzânia',
    'country_United States' => 'Estados Unidos',
    'country_Virgin Islands, U.S.' => 'Ilhas Virgens Americanas',
    'country_Burkina Faso' => ' Burkina Faso',
    'country_Uruguay' => 'Uruguai',
    'country_Uzbekistan' => 'Uzbequistão',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela',
    'country_Wallis and Futuna' => 'Wallis e Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Iêmen',
    'country_Zambia' => 'Zâmbia',

    // Languages
    'lang_Brazilian Portuguese' => 'Português do Brasil',
    'lang_Croatian' => 'Croata',
    'lang_Czech' => 'Tcheco',
    'lang_Danish' => 'Dinamarquês',
    'lang_Dutch' => 'Holandês',
    'lang_English' => 'Inglês',
    'lang_French' => 'Francês',
    'lang_French - Canada' => 'Francês - Canadá',
    'lang_German' => 'Alemão',
    'lang_Italian' => 'Italiano',
    'lang_Japanese' => 'Japonês',
    'lang_Lithuanian' => 'Lituano',
    'lang_Norwegian' => 'Norueguês',
    'lang_Polish' => 'Polonês',
    'lang_Spanish' => 'Espanhol',
    'lang_Spanish - Spain' => 'Espanhol - Espanha',
    'lang_Swedish' => 'Sueco',
    'lang_Albanian' => 'Albanês',
    'lang_Greek' => 'Grego',
    'lang_English - United Kingdom' => 'Inglês - Reino Unido',
    'lang_English - Australia' => 'Inglês - Austrália',
    'lang_Slovenian' => 'Esloveno',
    'lang_Finnish' => 'Finlandês',
    'lang_Romanian' => 'Romeno',
    'lang_Turkish - Turkey' => 'Turco - Turquia',
    'lang_Portuguese - Brazilian' => 'Português - Brasil',
    'lang_Portuguese - Portugal' => 'Português - Portugal',
    'lang_Thai' => 'Tailandês',
    'lang_Macedonian' => 'Macedônia',
    'lang_Chinese - Taiwan' => 'Chinês - Taiwan',
    'lang_Serbian' => 'Sérvia',
    'lang_Bulgarian' => 'Búlgaro ',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidade & Jurídico',
    'industry_Advertising' => 'Publicidade',
    'industry_Aerospace' => 'Aeroespacial',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automotivo',
    'industry_Banking & Finance' => 'Bancário & Finanças',
    'industry_Biotechnology' => 'Biotecnologia',
    'industry_Broadcasting' => 'Broadcasting',
    'industry_Business Services' => 'Serviços Empresariais',
    'industry_Commodities & Chemicals' => 'Commodities & Químicos',
    'industry_Communications' => 'Comunicações',
    'industry_Computers & Hightech' => 'Computadores e Tecnologia',
    'industry_Defense' => 'Defesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Entretenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Saúde & Ciências da Vida',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Manufatura',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Mídia',
    'industry_Nonprofit & Higher Ed' => 'Sem Fins Lucrativos e Educação',
    'industry_Pharmaceuticals' => 'Farmacêuticos',
    'industry_Professional Services & Consulting' => 'Serviços Profissionais e Consultoria',
    'industry_Real Estate' => 'Imóveis',
    'industry_Retail & Wholesale' => 'Atacado e Varejo',
    'industry_Sports' => 'Esportes',
    'industry_Transportation' => 'Transportes',
    'industry_Travel & Luxury' => 'Viagens e Luxo',
    'industry_Other' => 'Outros',
    'industry_Photography' => 'Fotografia',

    'view_client_portal' => 'Visualizar portal do cliente',
    'view_portal' => 'Visualizar portal',
    'vendor_contacts' => 'Contatos do Fornecedor',
    'all' => 'Todos',
    'selected' => 'Selecionados',
    'category' => 'Categoria',
    'categories' => 'Categorias',
    'new_expense_category' => 'Nova Categoria de Despesas',
    'edit_category' => 'Editar Categoria',
    'archive_expense_category' => 'Arquivar Categoria',
    'expense_categories' => 'Categorias de Despesas',
    'list_expense_categories' => 'Exibir Categorias de Despesas',
    'updated_expense_category' => 'Categoria de despesas atualizada com sucesso',
    'created_expense_category' => 'Categoria de despesas criada com sucesso',
    'archived_expense_category' => 'Categoria de despesas arquivada com sucesso',
    'archived_expense_categories' => ':count categorias de despesas arquivadas com sucesso',
    'restore_expense_category' => 'Restaurar categoria de despesas',
    'restored_expense_category' => 'Categoria de despesas restaurada com sucesso',
    'apply_taxes' => 'Aplicar impostos',
    'min_to_max_users' => 'De :min a :max usuários',
    'max_users_reached' => 'A quantidade máxima de usuários foi atingida.',
    'buy_now_buttons' => 'Botões Compre Já',
    'landing_page' => 'Página de Chegada',
    'payment_type' => 'Tipo de Pagamento',
    'form' => 'Formulário',
    'link' => 'Link',
    'fields' => 'Campos',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Nota: o cliente e a fatura são criados mesmo que a transação não seja completada.',
    'buy_now_buttons_disabled' => 'Este recurso exige que um produto seja criado e um gateway de pagamento seja configurado.',
    'enable_buy_now_buttons_help' => 'Ativar suporte aos botões Compre Já',
    'changes_take_effect_immediately' => 'Nota: alterações farão efeito imediatamente',
    'wepay_account_description' => 'Gateway de pagamentos para o Invoice Ninja',
    'payment_error_code' => 'Ocorreu um erro ao processar o pagamento [:code]. Por favor tente novamente mais tarde.',
    'standard_fees_apply' => 'Taxas: 2,9%/1,2% [Cartão de Crédito/Transferência Bancária] + US$ 0,30 por cobrança bem sucedida.',
    'limit_import_rows' => 'Os dados devem ser importados em lotes de :count registros ou menos',
    'error_title' => 'Algo deu errado',
    'error_contact_text' => 'Se você desejar ajudar por favor nos envie um email em :mailaddress',
    'no_undo' => 'Aviso: esta operação não pode ser desfeita.',
    'no_contact_selected' => 'Selecione um contato',
    'no_client_selected' => 'Selecione um cliente',

    'gateway_config_error' => 'Talvez ajude definir novas senhas ou gerar novas chaves de API',
    'payment_type_on_file' => ':type em arquivo',
    'invoice_for_client' => 'Fatura :invoice para :client',
    'intent_not_found' => 'Desculpe, não tenho certeza do que está pedindo.',
    'intent_not_supported' => 'Desculpe, não consigo fazer isso.',
    'client_not_found' => 'Não consegui encontrar o cliente.',
    'not_allowed' => 'Desculpe, você não possui as permissões necessárias',
    'bot_emailed_invoice' => 'Sua fatura foi enviada.',
    'bot_emailed_notify_viewed' => 'Mandarei-o um email quando for visualizado.',
    'bot_emailed_notify_paid' => 'Mandarei-o um email quando for pago.',
    'add_product_to_invoice' => 'Adicionar 1 :product',
    'not_authorized' => 'Você não está autorizado',
    'bot_get_email' => 'Olá! (wave) <br/>Obrigado por testar o robô Invoice Ninja. <br/>Você precisa criar uma conta gratuita para usar este robô. <br/>Diga-me sua conta de email para começarmos.',
    'bot_get_code' => 'Obrigado! Eu enviei para você um email com seu código de segurança.',
    'bot_welcome' => 'É isso, sua conta foi verificada. <br/>',
    'email_not_found' => 'Não pude encontrar uma conta disponível para :email',
    'invalid_code' => 'O código está incorreto',
    'security_code_email_subject' => 'Código de segurança do Invoice Ninja Bot',
    'security_code_email_line1' => 'Este é o seu código de segurança do Invoice Ninja Bot.',
    'security_code_email_line2' => 'Nota: ele irá expirar em 10 minutos.',
    'bot_help_message' => 'Eu atualmente suporto: <br/>• Criar/atualizar/enviar uma fatura <br/>• Listar produtos <br/>Por exemplo:<br/><i>Faturar 2 tickets para Bob, defina a data de vencimento para a próxima quinta-feira e o desconto para 10 porcento</i>',
    'list_products' => 'Listar Produtos',

    'include_item_taxes_inline' => 'Incluir <b>linhas de taxas por item no total de linhas</b>',
    'created_quotes' => ':count orçamento(s) criado(s) com sucesso',
    'limited_gateways' => 'Nota: nós suportamos um gateway de cartão de crédito por empresa.',

    'warning' => 'Aviso',
    'self-update' => 'Atualizar',
    'update_invoiceninja_title' => 'Atualizar o Invoice Ninja',
    'update_invoiceninja_warning' => 'Antes de começar a atualizar o Invoice Ninja crie um backup de seu banco de dados e arquivos!',
    'update_invoiceninja_available' => 'Uma nova versão do Invoice Ninja está disponível.',
    'update_invoiceninja_unavailable' => 'Nenhuma nova versão está disponível.',
    'update_invoiceninja_instructions' => 'Por favor instale uma nova versão <strong>:version</strong> clicando no botão<em>Atualizar agora</em> abaixo. Após isso você será redirecionado para o dashboard.',
    'update_invoiceninja_update_start' => 'Atualizar agora',
    'update_invoiceninja_download_start' => 'Baixar :version',
    'create_new' => 'Criar Novo',

    'toggle_navigation' => 'Chavear Navegação',
    'toggle_history' => 'Chavear Histórico',
    'unassigned' => 'Não Designado',
    'task' => 'Tarefa',
    'contact_name' => 'Nome do Contato',
    'city_state_postal' => 'Cidade/Estado/CEP',
    'custom_field' => 'Campo Personalizado',
    'account_fields' => 'Campos da Empresa',
    'facebook_and_twitter' => 'Facebook e Twitter',
    'facebook_and_twitter_help' => 'Siga nossos feeds para suportar nosso projeto',
    'reseller_text' => 'Nota: uma licença white-label é destinada para uso pessoal, por favor envie um email para :email se você pretende revender o app.',
    'unnamed_client' => 'Cliente sem nome',

    'day' => 'Dia',
    'week' => 'Semana',
    'month' => 'Mês',
    'inactive_logout' => 'Você foi deslogado por inatividade',
    'reports' => 'Relatórios',
    'total_profit' => 'Lucro Total',
    'total_expenses' => 'Despesa Total',
    'quote_to' => 'Orçar para',

    // Limits
    'limit' => 'Limite',
    'min_limit' => 'Mín: :min',
    'max_limit' => 'Máx: :max',
    'no_limit' => 'Sem Limites',
    'set_limits' => 'Definir os limites de :gateway_type',
    'enable_min' => 'Habilitar mín',
    'enable_max' => 'Habilitar máx',
    'min' => 'Min',
    'max' => 'Máx',
    'limits_not_met' => 'Esta fatura não atende aos limites para este tipo de pagamento',

    'date_range' => 'Período',
    'raw' => 'Bruto',
    'raw_html' => 'HTML Bruto',
    'update' => 'Atualizar',
    'invoice_fields_help' => 'Arraste e solte campos para mudar sua ordem e local',
    'new_category' => 'Nova Categoria',
    'restore_product' => 'Restaurar Produto',
    'blank' => 'Vazio',
    'invoice_save_error' => 'Houve um erro ao salvar sua fatura',
    'enable_recurring' => 'Habilitar Recorrência',
    'disable_recurring' => 'Desabilitar Recorrência',
    'text' => 'Texto',
    'expense_will_create' => 'despesa será criada',
    'expenses_will_create' => 'despesas serão criadas',
    'created_expenses' => ':count despesa(s) criada(s) com sucesso',

    'translate_app' => 'Ajude a melhorar nossas traduções com :link',
    'expense_category' => 'Categoria de Despesa',

    'go_ninja_pro' => 'Seja Ninja Pro!',
    'go_enterprise' => 'Seja Enterprise!',
    'upgrade_for_features' => 'Faça Upgrade para mais funcionalidades',
    'pay_annually_discount' => 'Pague anualmente por 10 meses + 2 gratuitos!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'SuaMarca.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Personalize cada aspecto de sua fatura!',
    'enterprise_upgrade_feature1' => 'Defina permissões pra múltiplos usuários',
    'enterprise_upgrade_feature2' => 'Anexe arquivos de 3°s em faturas e despesas',
    'much_more' => 'Muito Mais!',
    'all_pro_fetaures' => 'Mais todas as funcionalidades Pro!',

    'currency_symbol' => 'Símbolo',
    'currency_code' => 'Código',

    'buy_license' => 'Comprar Licença',
    'apply_license' => 'Aplicar Licença',
    'submit' => 'Enviar',
    'white_label_license_key' => 'Chave de Licença',
    'invalid_white_label_license' => 'A licença white-label não é válida',
    'created_by' => 'Criado por :name',
    'modules' => 'Módulos',
    'financial_year_start' => 'Primeiro mês do ano',
    'authentication' => 'Autenticação',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Assinatura',
    'show_accept_invoice_terms' => 'Checkbox para Condições de Fatura',
    'show_accept_invoice_terms_help' => 'Exigir que o cliente confirme que aceita as condições da fatura.',
    'show_accept_quote_terms' => 'Checkbox de Condições do Orçamento',
    'show_accept_quote_terms_help' => 'Exigir que cliente confirme que aceita as Condições do Orçamento',
    'require_invoice_signature' => 'Assinatura de Fatura',
    'require_invoice_signature_help' => 'Exigir que o cliente providencie sua assinatura',
    'require_quote_signature' => 'Assinatura de Orçamento',
    'require_quote_signature_help' => 'Exigir que o cliente providencie sua assinatura.',
    'i_agree' => 'Eu Aceito os Termos',
    'sign_here' => 'Por favor assine aqui:',
    'authorization' => 'Autorização',
    'signed' => 'Assinado',

    // BlueVine
    'bluevine_promo' => 'Obtenha linhas de crédito flexívelis e fatoração de faturas com BlueVine.',
    'bluevine_modal_label' => 'Registre-se no BlueVine',
    'bluevine_modal_text' => '<h3>Investimento rápido em seu negócio. Sem papelada.</h3>
<ul><li>Linhas de crédito flexíveis e fatoração de faturas.</li></ul>',
    'bluevine_create_account' => 'Crie uma conta',
    'quote_types' => 'Obtenha um orçamento para',
    'invoice_factoring' => 'Fatoração de Faturas',
    'line_of_credit' => 'Linha de Crédito',
    'fico_score' => 'Sua nota FICO',
    'business_inception' => 'Data de Concepção do Negócio',
    'average_bank_balance' => 'Saldo médio da conta bancária',
    'annual_revenue' => 'Faturamento Anual',
    'desired_credit_limit_factoring' => 'Limite de fatoração de faturas desejado',
    'desired_credit_limit_loc' => 'Limite da linha de crédito desejada',
    'desired_credit_limit' => 'Liimte de crédito desejado',
    'bluevine_credit_line_type_required' => 'Você precisa escolher ao menos um',
    'bluevine_field_required' => 'O campo é obrigatório',
    'bluevine_unexpected_error' => 'Um erro inesperado ocorreu.',
    'bluevine_no_conditional_offer' => 'Mais informações são requeridas antes de obter um orçamento. Clique em continuar abaixo.',
    'bluevine_invoice_factoring' => 'Fatoração de Faturas',
    'bluevine_conditional_offer' => 'Oferta Condicional',
    'bluevine_credit_line_amount' => 'Linha de Crédito',
    'bluevine_advance_rate' => 'Taxa de Avanço',
    'bluevine_weekly_discount_rate' => 'Taxa de Descontos Semanais',
    'bluevine_minimum_fee_rate' => 'Taxa Mínima',
    'bluevine_line_of_credit' => 'Linha de Crédito',
    'bluevine_interest_rate' => 'Taxa de Juros',
    'bluevine_weekly_draw_rate' => 'Taxa de Sorteio Demanal',
    'bluevine_continue' => 'Continuar para BlueVine',
    'bluevine_completed' => 'Registro no BlueVine completo',

    'vendor_name' => 'Fabricante',
    'entity_state' => 'Estado',
    'client_created_at' => 'Data de Criação',
    'postmark_error' => 'Houve um problema ao enviar o email através do marcador: :link',
    'project' => 'Projeto',
    'projects' => 'Projetos',
    'new_project' => 'Novo Projeto',
    'edit_project' => 'Editar Projeto',
    'archive_project' => 'Arquivar Projeto',
    'list_projects' => 'Listar Projetos',
    'updated_project' => 'Projeto atualizado com sucesso',
    'created_project' => 'Projeto criado com sucesso',
    'archived_project' => 'Projeto arquivado com sucesso',
    'archived_projects' => ':count projetos arquivados com sucesso',
    'restore_project' => 'Restaurar Projeto',
    'restored_project' => 'Projeto restaurado com sucesso',
    'delete_project' => 'Excluir Projeto',
    'deleted_project' => 'Projeto excluído com sucesso',
    'deleted_projects' => ':count projetos excluídos com sucesso',
    'delete_expense_category' => 'Excluir Categoria',
    'deleted_expense_category' => 'Categoria excluída com sucesso',
    'delete_product' => 'Excluir Produto',
    'deleted_product' => 'Produto excluído com sucesso',
    'deleted_products' => ':count produtos excluídos com sucesso',
    'restored_product' => 'Produto restaurado com sucesso',
    'update_credit' => 'Atualizar Crédito',
    'updated_credit' => 'Crédito atualizado com sucesso',
    'edit_credit' => 'Editar Crédito',
    'realtime_preview' => 'Pré-visualização em Tempo Real',
    'realtime_preview_help' => 'Atualização em tempo real da visualização do PDF na página da fatura ao editar a fatura. <br/>Desative isso para melhorar o desempenho ao editar as faturas.',
    'live_preview_help' => 'Mostrar uma pré-visualização ao vivo na página de fatura.',
    'force_pdfjs_help' => 'Substituir o visualizador de PDF nativo em :chrome_link e :firefox_link. <br/>Habilite isto se seu navegador estiver baixando automaticamente o PDF.',
    'force_pdfjs' => 'Prevenir Download',
    'redirect_url' => 'Redirecionar URL',
    'redirect_url_help' => 'Opcionalmente especifique uma URL para redirecionamento após um pagamento ser reconhecido.',
    'save_draft' => 'Salvar Rascunho',
    'refunded_credit_payment' => 'Pagamento via crédito reembolsado',
    'keyboard_shortcuts' => 'Atalhos de Teclado',
    'toggle_menu' => 'Chavear Menu',
    'new_...' => 'Novo ...',
    'list_...' => 'Listar ...',
    'created_at' => 'Data de Criação',
    'contact_us' => 'Contate-nos',
    'user_guide' => 'Guia do Usuário',
    'promo_message' => 'Atualize antes de :expires e receba :amount de desconto em seu primeiro ano em nossos pacotes Pro ou Enterprise.',
    'discount_message' => ':amount de desconto expiram em :expires',
    'mark_paid' => 'Marcar como Pago',
    'marked_sent_invoice' => 'Fatura marcada como enviada com sucesso',
    'marked_sent_invoices' => 'Faturas marcadas como enviadas com sucesso',
    'invoice_name' => 'Fatura',
    'product_will_create' => 'produto será criado',
    'contact_us_response' => 'Obrigado por sua mensagem! Tentaremos responder assim que possível.',
    'last_7_days' => 'Últimos 7 Dias',
    'last_30_days' => 'Últimos 30 Dias',
    'this_month' => 'Este Mês',
    'last_month' => 'Último Mês',
    'current_quarter' => 'Quadrimestre Atual',
    'last_quarter' => 'Último Quadrimestre',
    'last_year' => 'Último Ano',
    'custom_range' => 'Período Personalizado',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Requer',
    'license_expiring' => 'Nota: Sua licença irá expirar em :count dias, :link para renová-la.',
    'security_confirmation' => 'Seu endereço de email foi confirmado.',
    'white_label_expired' => 'Seu licença white-label expirou, por favor considere renová-la para contribuir com o nosso projeto.',
    'renew_license' => 'Renovar Licença',
    'iphone_app_message' => 'Considere baixar nosso :link',
    'iphone_app' => 'Aplicativo de iPhone',
    'android_app' => 'Aplicativo de Android',
    'logged_in' => 'Logado',
    'switch_to_primary' => 'Mude para sua empresa principal (:name) para gerenciar seu plano.',
    'inclusive' => 'Inclusivo',
    'exclusive' => 'Exclusivo',
    'postal_city_state' => 'CEP/Cidade/Estado',
    'phantomjs_help' => 'Em certos casos o aplicativo usa :link_phantom para gerar o PDF, instalar :link_docs e gerá-lo localmente.',
    'phantomjs_local' => 'Utilizado PhantomJS local',
    'client_number' => 'Número do Cliente',
    'client_number_help' => 'Especifique um prefixo ou utilize um padrão personalizado para definir o número do cliente dinamicamente.',
    'next_client_number' => 'O próximo número de cliente é :number.',
    'generated_numbers' => 'Números Gerados',
    'notes_reminder1' => 'Primeiro Lembrete',
    'notes_reminder2' => 'Segundo Lembrete',
    'notes_reminder3' => 'Terceiro Lembrete',
    'notes_reminder4' => 'Lembrete',
    'bcc_email' => 'Email CCO',
    'tax_quote' => 'Orçamento de Imposto',
    'tax_invoice' => 'Fatura de Imposto',
    'emailed_invoices' => 'Faturas enviadas por email com sucesso',
    'emailed_quotes' => 'Orçamentos enviados por email com sucesso',
    'website_url' => 'URL do Website',
    'domain' => 'Domínio',
    'domain_help' => 'Utilizado no Portal do Cliente e no envio de emails.',
    'domain_help_website' => 'Utilizado no envio de emails.',
    'import_invoices' => 'Importar Faturas',
    'new_report' => 'Novo Relatório',
    'edit_report' => 'Editar Relatório',
    'columns' => 'Colunas',
    'filters' => 'Filtros',
    'sort_by' => 'Ordenar Por',
    'draft' => 'Rascunho',
    'unpaid' => 'Não Pago',
    'aging' => 'Envelhecimento',
    'age' => 'Idade',
    'days' => 'Dias',
    'age_group_0' => '0 - 30 Dias',
    'age_group_30' => '30 - 60 Dias',
    'age_group_60' => '60 - 90 Dias',
    'age_group_90' => '90 - 120 Dias',
    'age_group_120' => '120+ Dias',
    'invoice_details' => 'Detalhes da Fatura',
    'qty' => 'Quantidade',
    'profit_and_loss' => 'Lucro e Prejuízo',
    'revenue' => 'Faturamento',
    'profit' => 'Lucro',
    'group_when_sorted' => 'Ordenação em Grupo',
    'group_dates_by' => 'Ordenar Datas Por',
    'year' => 'Ano',
    'view_statement' => 'Ver Compras',
    'statement' => 'Declaração',
    'statement_date' => 'Data da Declaração',
    'mark_active' => 'Marcar como Ativo',
    'send_automatically' => 'Enviar Automaticamente',
    'initial_email' => 'Email Inicial',
    'invoice_not_emailed' => 'Esta fatura não foi enviada por email.',
    'quote_not_emailed' => 'Este orçamento não foi enviado por email.',
    'sent_by' => 'Enviado por :user',
    'recipients' => 'Destinatários',
    'save_as_default' => 'Salvar como padrão',
    'start_of_week_help' => 'Utilizado por seletores de <b>data</b>',
    'financial_year_start_help' => 'Utilizado por seletores de <b>período de data</b>',
    'reports_help' => 'Shift + Clicar para ordenar por múltiplas colunas, Ctrl + Clicar para limpar o agrupamento.',
    'this_year' => 'Este Ano',

    // Updated login screen
    'ninja_tagline' => 'Crie. Envie. Seja Pago.',
    'login_or_existing' => 'Ou logar com uma conta conectada.',
    'sign_up_now' => 'Registrar Agora',
    'not_a_member_yet' => 'Ainda não é um membro?',
    'login_create_an_account' => 'Criar uma Conta!',

    // New Client Portal styling
    'invoice_from' => 'Faturas De:',
    'email_alias_message' => 'Nós exigimos que cada empresa tenha um email único. <br/>Considere utilizar um apelido. Ex: email+label@exemplo.com',
    'full_name' => 'Nome Completo',
    'month_year' => 'MÊS/ANO',
    'valid_thru' => 'Válido\naté',

    'product_fields' => 'Campos de Produtos',
    'custom_product_fields_help' => 'Adicionar um campo ao criar um produto ou fatura e mostrar o rótulo e valor no PDF.',
    'freq_two_months' => 'Dois meses',
    'freq_yearly' => 'Anualmente',
    'profile' => 'Perfil',
    'payment_type_help' => 'Define o <b>tipo de pagamento manual</b> padrão.',
    'industry_Construction' => 'Construção',
    'your_statement' => 'Sua Declaração',
    'statement_issued_to' => 'Declaração emitida para',
    'statement_to' => 'Declaração para',
    'customize_options' => 'Personalizar opções',
    'created_payment_term' => 'Condições de pagamento criadas com sucesso',
    'updated_payment_term' => 'Condições de pagamento atualizadas com sucesso',
    'archived_payment_term' => 'Condições de pagamento arquivadas com sucesso',
    'resend_invite' => 'Reenviar Convite',
    'credit_created_by' => 'Crédito criado pelo pagamento :transaction_reference',
    'created_payment_and_credit' => 'Crédito e pagamento criados com sucesso',
    'created_payment_and_credit_emailed_client' => 'Crédito e pagamentos criados com sucesso, e email enviado ao cliente',
    'create_project' => 'Criar projeto',
    'create_vendor' => 'Criar fornecedor',
    'create_expense_category' => 'Criar categoria',
    'pro_plan_reports' => ':link para habilitar relatórios ao juntar-se ao Plano Pro',
    'mark_ready' => 'Marcar como Pronto',

    'limits' => 'Limites',
    'fees' => 'Taxas',
    'fee' => 'Taxa',
    'set_limits_fees' => 'Defina os Limites/Taxas de :gateway_type',
    'fees_tax_help' => 'Habilitar imposto por item e definir as taxas de impostos.',
    'fees_sample' => 'A taxa para uma fatura de :amount seria de :total.',
    'discount_sample' => 'O desconto para uma fatura de :amount seria de :total.',
    'no_fees' => 'Sem Taxas',
    'gateway_fees_disclaimer' => 'Aviso: nem todos os estados e gateways de pagamento permitem adicionar taxas, favor verifique a legislação local previamente.',
    'percent' => 'Porcento',
    'location' => 'Local',
    'line_item' => 'Item de linha',
    'surcharge' => 'Sobretaxa',
    'location_first_surcharge' => 'Habilitado - Primeira sobretaxa',
    'location_second_surcharge' => 'Habilitado - Segunda sobretaxa',
    'location_line_item' => 'Habilitado - Item de linha',
    'online_payment_surcharge' => 'Sobretaxa de Pagamento Online',
    'gateway_fees' => 'Taxas de Gateway',
    'fees_disabled' => 'Taxas estão desabilitadas',
    'gateway_fees_help' => 'Adicionar automaticamente um desconto/sobretaxa de pagamento online.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'Se houver faturas em aberto com taxas elas precisam ser atualizadas manualmente.',
    'fees_surcharge_help' => 'Personalizar sobretaxa :link.',
    'label_and_taxes' => 'Rótulos e impostos',
    'billable' => 'Faturável',
    'logo_warning_too_large' => 'O arquivo de imagem é grande demais',
    'logo_warning_fileinfo' => 'Aviso: para o suporte a GIFs a extensão fileinfo de PHP precisa estar habilitada.',
    'logo_warning_invalid' => 'Houve um problema ao ler o arquivo da imagem, por favor tente um formato diferente.',

    'error_refresh_page' => 'Ocorreu um erro, por favor atualize a página e tente novamente.',
    'data' => 'Dados',
    'imported_settings' => 'Configurações importadas com sucesso',
    'reset_counter' => 'Reiniciar Contador',
    'next_reset' => 'Próximo Reset',
    'reset_counter_help' => 'Reiniciar os contadores de faturas e orçamentos automaticamente.',
    'auto_bill_failed' => 'Auto-faturamento para fatura :invoice_number falhou',
    'online_payment_discount' => 'Desconto de Pagamento Online',
    'created_new_company' => 'Nova empresa criada com sucesso',
    'fees_disabled_for_gateway' => 'Taxas estão desabilitadas para este gateway.',
    'logout_and_delete' => 'Deslogar/Excluir Conta',
    'tax_rate_type_help' => 'Taxas inclusivas ajustam o custo da linha quando selecionadas. <br/>Apenas taxas exclusivas podem ser utilizadas como padrão.',
    'invoice_footer_help' => 'Utiize $pageNumber e $pageCount para mostrar a informação da página.',
    'credit_note' => 'Nota de Crédito',
    'credit_issued_to' => 'Crédito emitido para',
    'credit_to' => 'Crédito para',
    'your_credit' => 'Seu Crédito',
    'credit_number' => 'Número do Crédito',
    'create_credit_note' => 'Nota de Cartão de Crédito',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Erro: a tabela de gateways possui IDs incorretos.',
    'purge_data' => 'Limpar Dados',
    'delete_data' => 'Excluir Dados',
    'purge_data_help' => 'Excluir todos os dados permanentemente mas manter a conta e configurações.',
    'cancel_account_help' => 'Excluir permanentemente a conta com todos os dados e configurações',
    'purge_successful' => 'Dados da empresa limpos com sucesso',
    'forbidden' => 'Proibido',
    'purge_data_message' => 'Aviso: Isto irá apagar seus dados permanentemente, não há como defazer esta ação.',
    'contact_phone' => 'Telefone de Contato',
    'contact_email' => 'Email de Contato',
    'reply_to_email' => 'Email para Resposta',
    'reply_to_email_help' => 'Especifique o email de resposta para clientes de emails.',
    'bcc_email_help' => 'Incluir este endereço de forma privada para os clientes de emails.',
    'import_complete' => 'Sua importação foi concluída com sucesso.',
    'confirm_account_to_import' => 'Por favor confirme sua conta para importar dados.',
    'import_started' => 'Sua importação foi iniciada, enviaremos um email quando estiver completo.',
    'listening' => 'Ouvindo...',
    'microphone_help' => 'Diga "nova fatura para [cliente]" ou "exibir pagamentos arquivados do [cliente]"',
    'voice_commands' => 'Comandos de Voz',
    'sample_commands' => 'Comandos de exemplo',
    'voice_commands_feedback' => 'Estamos trabalhando ativamente para melhorar esta funcionalidade, se houver um comando que quiser que suportemos, mande-nos um email em :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Pedido com Dinheiro',
    'archived_products' => ':count produtos arquivados com sucesso',
    'recommend_on' => 'Recomendamos <b>habilitar</b> esta configuração.',
    'recommend_off' => 'Recomendamos <b>desabilitar</b> esta configuração.',
    'notes_auto_billed' => 'Auto-cobrado',
    'surcharge_label' => 'Rótulo da Sobretaxa',
    'contact_fields' => 'Campos do Contato',
    'custom_contact_fields_help' => 'Adicionar um campo na criação do contato e opcionalmente mostrar um rótulo e valor no PDF.',
    'datatable_info' => 'Exibindo :start de :end no total de :total registros',
    'credit_total' => 'Total do Crédito',
    'mark_billable' => 'Marcar como faturável',
    'billed' => 'Faturado',
    'company_variables' => 'Variáveis da Empresa',
    'client_variables' => 'Variáveis do Cliente',
    'invoice_variables' => 'Variáveis da Fatura',
    'navigation_variables' => 'Variáveis de Navegação',
    'custom_variables' => 'Variáveis Personalizadas',
    'invalid_file' => 'Tipo de arquivo inválido',
    'add_documents_to_invoice' => 'Adicionar documentos à fatura',
    'mark_expense_paid' => 'Marcar como pago',
    'white_label_license_error' => 'Falha ao validar a licença, verifique storage/logs/laravel-error.log para mais detalhes.',
    'plan_price' => 'Preço do Plano',
    'wrong_confirmation' => 'Código de confirmação incorreto',
    'oauth_taken' => 'Esta conta já está registrada',
    'emailed_payment' => 'Pagamento enviado por email com sucesso',
    'email_payment' => 'Pagamento por Email',
    'invoiceplane_import' => 'Utilize :link para migrar seus dados do InvoicePlane.',
    'duplicate_expense_warning' => 'Aviso: Este :link pode ser uma duplicata',
    'expense_link' => 'despesa',
    'resume_task' => 'Continuar Tarefa',
    'resumed_task' => 'Tarefa continuada com sucesso',
    'quote_design' => 'Design do Orçamento',
    'default_design' => 'Design Padrão',
    'custom_design1' => 'Design Personalizado 1',
    'custom_design2' => 'Design Personalizado 2',
    'custom_design3' => 'Design Personalizado 3',
    'empty' => 'Vazio',
    'load_design' => 'Carregar Design',
    'accepted_card_logos' => 'Logos de Cartões Aceitos',
    'phantomjs_local_and_cloud' => 'Utilizando PhantomJS local, revertendo para phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Chave do Analytics',
    'analytics_key_help' => 'Rastrear pagamentos com :link',
    'start_date_required' => 'A data de início é obrigatória',
    'application_settings' => 'Configurações da Aplicação',
    'database_connection' => 'Conexão do Banco de Dados',
    'driver' => 'Driver',
    'host' => 'Servidor',
    'database' => 'Banco de Dados',
    'test_connection' => 'Testar conexão',
    'from_name' => 'Nome do Remetente',
    'from_address' => 'Email do Remetente',
    'port' => 'Porta',
    'encryption' => 'Encriptação',
    'mailgun_domain' => 'Domínio do Mailgun',
    'mailgun_private_key' => 'Chave Privada do Mailgun',
    'send_test_email' => 'Enviar email de teste',
    'select_label' => 'Selecione o Rótulo',
    'label' => 'Rótulo',
    'service' => 'Serviço',
    'update_payment_details' => 'Atualizar detalhes do pagamento',
    'updated_payment_details' => 'Detalhes do pagamento atualizados com sucesso',
    'update_credit_card' => 'Atualizar Cartão de Crédito',
    'recurring_expenses' => 'Despesas Recorrentes',
    'recurring_expense' => 'Despesa Recorrente',
    'new_recurring_expense' => 'Nova Despesa Recorrente',
    'edit_recurring_expense' => 'Editar Despesa Recorrente',
    'archive_recurring_expense' => 'Arquivar Despesa Recorrente',
    'list_recurring_expense' => 'Listar Despesas Recorrentes',
    'updated_recurring_expense' => 'Despesa recorrente atualizada com sucesso',
    'created_recurring_expense' => 'Despesa recorrente criada com sucesso',
    'archived_recurring_expense' => 'Despesa recorrente arquivada com sucesso',
    'restore_recurring_expense' => 'Restaurar Despesa Recorrente',
    'restored_recurring_expense' => 'Despesa recorrente restaurada com sucesso',
    'delete_recurring_expense' => 'Excluir Despesa Recorrente',
    'deleted_recurring_expense' => 'Projeto excluído com sucesso',
    'view_recurring_expense' => 'Visualizar Despesa Recorrente',
    'taxes_and_fees' => 'Impostos e taxas',
    'import_failed' => 'Falha na Importação',
    'recurring_prefix' => 'Prefixo da Recorrência',
    'options' => 'Opções',
    'credit_number_help' => 'Especifique um prefixo ou use um padrão personalizado para definir dinamicamente o número de crédito para faturas negativas.',
    'next_credit_number' => 'O próximo número de crédito é :number.',
    'padding_help' => 'O número de zeros à esquerda do número.',
    'import_warning_invalid_date' => 'Aviso: o formato da data aparenta ser inválido.',
    'product_notes' => 'Notas do Produto',
    'app_version' => 'Versão do App',
    'ofx_version' => 'Versão do OFX',
    'gateway_help_23' => ':link para pegar suas chaves API do Stripe.',
    'error_app_key_set_to_default' => 'Erro: APP_KEY está definido com valor padrão, para atualizá-lo faça backup de seu banco de dados e então execute <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Cobrar Multa por Atraso',
    'late_fee_amount' => 'Quantia da Multa',
    'late_fee_percent' => 'Percentual de Multa',
    'late_fee_added' => 'Multa por atraso adicionada em :date',
    'download_invoice' => 'Baixar Fatura',
    'download_quote' => 'Baixar Orçamento',
    'invoices_are_attached' => 'Os PDFs da sua fatura estão em anexo.',
    'downloaded_invoice' => 'Um email será enviado com o PDF da fatura',
    'downloaded_quote' => 'Um email será enviado com o PDF do orçamento',
    'downloaded_invoices' => 'Um email será enviado com os PDFs da fatura',
    'downloaded_quotes' => 'Um email será enviado com os PDFs do orçamento',
    'clone_expense' => 'Copiar Despesa',
    'default_documents' => 'Documentos Padrão',
    'send_email_to_client' => 'Enviar email para o cliente',
    'refund_subject' => 'Reembolso Processado',
    'refund_body' => 'Você processou um reembolso de :amount para a fatura :invoice_number.',

    'currency_us_dollar' => 'Dólar americano',
    'currency_british_pound' => 'Libra britânica',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'Rand Sul Africano',
    'currency_danish_krone' => 'Coroa dinamarquesa',
    'currency_israeli_shekel' => 'Shekel israelita',
    'currency_swedish_krona' => 'Coroa sueca',
    'currency_kenyan_shilling' => 'Xelim do Quênia',
    'currency_canadian_dollar' => 'Dólar canadense',
    'currency_philippine_peso' => 'Peso filipino',
    'currency_indian_rupee' => 'Rúpia indiana',
    'currency_australian_dollar' => 'Dólar australiano',
    'currency_singapore_dollar' => 'Dólar de Singapura',
    'currency_norske_kroner' => 'Coroa norueguesa',
    'currency_new_zealand_dollar' => 'Dólar Neozelandês',
    'currency_vietnamese_dong' => 'Dong vietnamita',
    'currency_swiss_franc' => 'Franco suíço',
    'currency_guatemalan_quetzal' => 'Quetzal guatemalteco',
    'currency_malaysian_ringgit' => 'Ringgit da Malásia',
    'currency_brazilian_real' => 'Real Brasileiro',
    'currency_thai_baht' => 'Baht tailandês',
    'currency_nigerian_naira' => 'Naira da Nigéria',
    'currency_argentine_peso' => 'Peso Argentino',
    'currency_bangladeshi_taka' => 'Taka de Bangladesh',
    'currency_united_arab_emirates_dirham' => 'Dirham dos Emirados Árabes Unidos',
    'currency_hong_kong_dollar' => 'Dólar de Hong Kong',
    'currency_indonesian_rupiah' => 'Rúpia indonésia',
    'currency_mexican_peso' => 'Peso Mexicano',
    'currency_egyptian_pound' => 'Libra Egípcia',
    'currency_colombian_peso' => 'Peso colombiano',
    'currency_west_african_franc' => 'Franco da África Ocidental',
    'currency_chinese_renminbi' => 'Renminbi chinês',
    'currency_rwandan_franc' => 'Franco ruandês',
    'currency_tanzanian_shilling' => 'Xelim da Tanzânia',
    'currency_netherlands_antillean_guilder' => 'Guilder das Antilhas Holandesas',
    'currency_trinidad_and_tobago_dollar' => 'Dólar de Trinidad e Tobago',
    'currency_east_caribbean_dollar' => 'Dólar do Caribe Oriental',
    'currency_ghanaian_cedi' => 'Cedi ganês',
    'currency_bulgarian_lev' => 'Lev búlgaro',
    'currency_aruban_florin' => 'Florim de Aruba',
    'currency_turkish_lira' => 'Lira turca',
    'currency_romanian_new_leu' => 'Novo Leu Romeno',
    'currency_croatian_kuna' => 'Kuna Croata',
    'currency_saudi_riyal' => 'Rial saudita',
    'currency_japanese_yen' => 'Yen japonês',
    'currency_maldivian_rufiyaa' => 'Rufiyaa das Maldivas',
    'currency_costa_rican_colon' => 'Colón Costarriquenho',
    'currency_pakistani_rupee' => 'Rúpia paquistanesa',
    'currency_polish_zloty' => 'Zloty polonês',
    'currency_sri_lankan_rupee' => 'Rúpia do Sri Lanka',
    'currency_czech_koruna' => 'Coroa Tcheca',
    'currency_uruguayan_peso' => 'Peso uruguaio',
    'currency_namibian_dollar' => 'Dólar namibiano',
    'currency_tunisian_dinar' => 'Dinar tunisiano',
    'currency_russian_ruble' => 'Rublo Russo',
    'currency_mozambican_metical' => 'Metical moçambicano',
    'currency_omani_rial' => 'Rial omanense',
    'currency_ukrainian_hryvnia' => 'Grívnia ucraniana',
    'currency_macanese_pataca' => 'Pataca Macaense',
    'currency_taiwan_new_dollar' => 'Dólar de Taiwan',
    'currency_dominican_peso' => 'Peso Dominicano',
    'currency_chilean_peso' => 'Peso Chileno',
    'currency_icelandic_krona' => 'Coroa Islandesa',
    'currency_papua_new_guinean_kina' => 'Kina Papuásia',
    'currency_jordanian_dinar' => 'Dinar jordaniano',
    'currency_myanmar_kyat' => 'Quiate',
    'currency_peruvian_sol' => 'Novo Sol Peruano',
    'currency_botswana_pula' => 'Pula Botsuanesa',
    'currency_hungarian_forint' => 'Florim Húngaro',
    'currency_ugandan_shilling' => 'Xelim Ugandês',
    'currency_barbadian_dollar' => 'Dólar Barbadense',
    'currency_brunei_dollar' => 'Dólar Bruneano',
    'currency_georgian_lari' => 'Lari Georgiano',
    'currency_qatari_riyal' => 'Rial Catariano',
    'currency_honduran_lempira' => 'Lempira Hondurenha',
    'currency_surinamese_dollar' => 'Dólar Surinamês',
    'currency_bahraini_dinar' => 'Dinar Bareinita',
    'currency_venezuelan_bolivars' => 'Bolívar Venezuelano',
    'currency_south_korean_won' => 'Won Sul-Coreano',
    'currency_moroccan_dirham' => 'Dirham Marroquino',
    'currency_jamaican_dollar' => 'Dólar Jamaicano',
    'currency_angolan_kwanza' => 'Kwanza Angolano',
    'currency_haitian_gourde' => 'Gourde Haitiano',
    'currency_zambian_kwacha' => 'Kwacha Zambiano',
    'currency_nepalese_rupee' => 'Rúpia Nepalesa',
    'currency_cfp_franc' => 'Franco CFP',
    'currency_mauritian_rupee' => 'Rúpia Mauriciana',
    'currency_cape_verdean_escudo' => 'Escudo Cabo-Verdiano',
    'currency_kuwaiti_dinar' => 'Dinar Kuwaitiano',
    'currency_algerian_dinar' => 'Dinar Argelino',
    'currency_macedonian_denar' => 'Dinar Macedônio',
    'currency_fijian_dollar' => 'Dólar Fijiano',
    'currency_bolivian_boliviano' => 'Boliviano da Bolívia',
    'currency_albanian_lek' => 'Lek Albanês',
    'currency_serbian_dinar' => 'Dinar Sérvio',
    'currency_lebanese_pound' => 'Libra Libanesa',
    'currency_armenian_dram' => 'Dram Armênio',
    'currency_azerbaijan_manat' => 'Manat Azerbaijano',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Marco Conversível da Bósnia e Herzegovina',
    'currency_belarusian_ruble' => 'Rublo Bielorusso',
    'currency_moldovan_leu' => 'Leu Moldávio',
    'currency_kazakhstani_tenge' => 'Tenge Cazaque',
    'currency_gibraltar_pound' => 'Libra de Gibraltar',

    'review_app_help' => 'Esperamos que esteja aproveitando o app. <br/>Se você considerar :link agradeceríamos bastante!',
    'writing_a_review' => 'Escrevendo uma avaliação',

    'use_english_version' => 'Assegure-se de usar as versões em Inglês dos arquivos. <br/>Nós utilizamos os cabeçalhos das colunas para referenciar os campos.',
    'tax1' => 'Primeiro Imposto',
    'tax2' => 'Segundo Imposto',
    'fee_help' => 'Taxas de Gateway são os custos cobrados por acessar as redes financeiras que tratam do processamento de pagamentos online.',
    'format_export' => 'Formato de exportação',
    'custom1' => 'Primeiro Personalizado',
    'custom2' => 'Segundo Personalizado',
    'contact_first_name' => 'Primeiro Nome do Contato',
    'contact_last_name' => 'Último Nome do Contato',
    'contact_custom1' => 'Primeiro Personalizado do Contato',
    'contact_custom2' => 'Segundo Personalizado do Contato',
    'currency' => 'Moeda',
    'ofx_help' => 'Para investigar erros verifique os comentários em :ofxhome_link e teste com :ofxget_link.',
    'comments' => 'comentários',

    'item_product' => 'Produto do Item',
    'item_notes' => 'Notas do Item',
    'item_cost' => 'Custo do Item',
    'item_quantity' => 'Quantidade do Item',
    'item_tax_rate' => 'Tarifa do Imposto do Item',
    'item_tax_name' => 'Nome do Imposto do Item',
    'item_tax1' => 'Imposto1 do Item',
    'item_tax2' => 'Imposto2 do Item',

    'delete_company' => 'Excluir Empresa',
    'delete_company_help' => 'Excluir permanentemente a empresa junto com todos seus dados e configurações.',
    'delete_company_message' => 'Aviso: Isto irá excluir permanentemente sua empresa, não há como desfazer esta ação.',

    'applied_discount' => 'O cupom foi aplicado, o preço do plano foi reduzido em :discount%.',
    'applied_free_year' => 'O cupom foi aplicado, sua conta foi atualizada para Pro por um ano.',

    'contact_us_help' => 'Se você está reportando um erro por favor inclua quaisquer logs relevantes de storage/logs/laravel-error.log',
    'include_errors' => 'Incluir Erros',
    'include_errors_help' => 'Incluir :link de storage/logs/laravel-error.log',
    'recent_errors' => 'erros recentes',
    'customer' => 'Cliente',
    'customers' => 'Clientes',
    'created_customer' => 'Cliente criado com sucesso',
    'created_customers' => ':count clientes criados com sucesso',

    'purge_details' => 'Os dados de sua empresa (:account) foram limpos com sucesso.',
    'deleted_company' => 'Empresa excluída com sucesso',
    'deleted_account' => 'Conta cancelada com sucesso',
    'deleted_company_details' => 'Sua empresa (:account) foi excluída com sucesso.',
    'deleted_account_details' => 'Sua conta (:account) foi excluída com sucesso.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'Débito direto SEPA',
    'enable_alipay' => 'Aceitar Alipay',
    'enable_sofort' => 'Aceitar Transferências Bancárias da UE',
    'stripe_alipay_help' => 'Estes gateways também precisam ser ativados em :link.',
    'calendar' => 'Calendário',
    'pro_plan_calendar' => ':link para habilitar o calendário juntando-se ao Plano Pro',

    'what_are_you_working_on' => 'No que você está trabalhando?',
    'time_tracker' => 'Rastreador de Tempo',
    'refresh' => 'Atualizar',
    'filter_sort' => 'Filtrar/Ordenar',
    'no_description' => 'Sem Descrição',
    'time_tracker_login' => 'Login no Rastreador de Tempo',
    'save_or_discard' => 'Salve ou descarte suas mudanças',
    'discard_changes' => 'Descartar Mudanças',
    'tasks_not_enabled' => 'Tarefas não estão habilitadas.',
    'started_task' => 'Tarefa iniciada com sucesso',
    'create_client' => 'Criar Cliente',

    'download_desktop_app' => 'Baixe o app de desktop',
    'download_iphone_app' => 'Baixe o app de iPhone',
    'download_android_app' => 'Baixe o app de Android',
    'time_tracker_mobile_help' => 'Clique duas vezes em uma tarefa para selecioná-la',
    'stopped' => 'Parado',
    'ascending' => 'Ascendente',
    'descending' => 'Descendente',
    'sort_field' => 'Ordenar Por',
    'sort_direction' => 'Direção',
    'discard' => 'Descartar',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Limpar',
    'warn_payment_gateway' => 'Nota: aceitar pagamentos online requer um gateway de pagamento, :link para adicionar um.',
    'task_rate' => 'Taxa de Tarefas',
    'task_rate_help' => 'Define a taxa padrão para tarefas faturadas.',
    'past_due' => 'Vencido',
    'document' => 'Documento',
    'invoice_or_expense' => 'Fatura/Despesa',
    'invoice_pdfs' => 'PDFs de Faturas',
    'enable_sepa' => 'Aceitar SEPA',
    'enable_bitcoin' => 'Aceitar Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'Ao prover seu IBAN e confirmar este pagamento, você autoriza :company e Stripe, nosso provedor de serviços de pagamentos, a enviar instruções a seu banco para debitar de sua conta de acordo com essas instruções. Você tem direito a um estorno de seu banco sob os termos de condições de seu contrato com seu banco. Um estorno precisa ser requisitado dentre de 8 semanas a partir da data que sua conta foi debitada.',
    'recover_license' => 'Recuperar Licença',
    'purchase' => 'Comprar',
    'recover' => 'Recuperar',
    'apply' => 'Aplicar',
    'recover_white_label_header' => 'Recuperar Licença White Label',
    'apply_white_label_header' => 'Aplicar Licença White Label',
    'videos' => 'Vídeos',
    'video' => 'Vídeo',
    'return_to_invoice' => 'Retornar à Fatura',
    'gateway_help_13' => 'Para utilizar ITN deixe o campo Chave PDT em branco.',
    'partial_due_date' => 'Data de Vencimento Parcial',
    'task_fields' => 'Campos de Tarefas',
    'product_fields_help' => 'Arraste e solte campos para mudar sua ordem',
    'custom_value1' => 'Valor Personalizado',
    'custom_value2' => 'Valor Personalizado',
    'enable_two_factor' => 'Autenticação em 2 Fatores',
    'enable_two_factor_help' => 'Use seu telefone para confirmar sua identidade quando estiver logando',
    'two_factor_setup' => 'Configuração de Autenticação em 2 Fatores',
    'two_factor_setup_help' => 'Eccaneie o código de barras com um app compatível com :link',
    'one_time_password' => 'Senha One-Time (OTP)',
    'set_phone_for_two_factor' => 'Defina seu número de celular como um backup para habilitação.',
    'enabled_two_factor' => 'Ativação de Autenticação em 2 Fatores realizada com sucesso.',
    'add_product' => 'Adicionar Produto',
    'email_will_be_sent_on' => 'Nota: o email será enviado em :date.',
    'invoice_product' => 'Faturar Produto',
    'self_host_login' => 'Login em Self-Host',
    'set_self_hoat_url' => 'URL de Self-Host',
    'local_storage_required' => 'Erro: armazenamento local não está disponível.',
    'your_password_reset_link' => 'Seu Link de Redefinição de Senha',
    'subdomain_taken' => 'O subdomínio já está em uso',
    'client_login' => 'Login de Cliente',
    'converted_amount' => 'Quantia Convertida',
    'default' => 'Padrão',
    'shipping_address' => 'Endereço de envio',
    'bllling_address' => 'Endereço de cobrança',
    'billing_address1' => 'Rua de cobrança',
    'billing_address2' => 'Complemento de cobrança',
    'billing_city' => 'Cidade de cobrança',
    'billing_state' => 'Estado/Província de cobrança',
    'billing_postal_code' => 'CEP de cobrança',
    'billing_country' => 'País de cobrança',
    'shipping_address1' => 'Rua de envio',
    'shipping_address2' => 'Complemento de envio',
    'shipping_city' => 'Cidade de envio',
    'shipping_state' => 'Estado/Província de envio',
    'shipping_postal_code' => 'CEP de envio',
    'shipping_country' => 'País de envio',
    'classify' => 'Classificar',
    'show_shipping_address_help' => 'Exige do cliente o provimento de seu endereço de envio',
    'ship_to_billing_address' => 'Enviar para o endereço de cobrança',
    'delivery_note' => 'Nota de Entrega',
    'show_tasks_in_portal' => 'Exibir tarefas no Portal do Cliente',
    'cancel_schedule' => 'Cancelar Agendamento',
    'scheduled_report' => 'Relatório Agendado',
    'scheduled_report_help' => 'Enviar o relatório :report como :format para o email :email',
    'created_scheduled_report' => 'Relatório agendado com sucesso',
    'deleted_scheduled_report' => 'Relatório agendado foi cancelado com sucesso',
    'scheduled_report_attached' => 'Seu relatório agendado de :type está anexo.',
    'scheduled_report_error' => 'Falha ao criar relatório agendado',
    'invalid_one_time_password' => 'Senha one-time inválida',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Aceitar Apple Pay e Pay with Google',
    'requires_subdomain' => 'Este tipo de pagamento requer um :link.',
    'subdomain_is_set' => 'subdomínio está definido',
    'verification_file' => 'Arquivo de Verificação',
    'verification_file_missing' => 'O arquivo de verificação é necessário para aceitar pagamentos.',
    'apple_pay_domain' => 'Utilize <code>:domain</code> como o domínio em :link.',
    'apple_pay_not_supported' => 'Desculpe, Apple/Google Pay não são suportados por seu browser',
    'optional_payment_methods' => 'Formas de Pagamento Opcionais',
    'add_subscription' => 'Adicionar Assinatura',
    'target_url' => 'Alvo',
    'target_url_help' => 'Quando o evento selecionado ocorrer o app irá postar a entidade para a URL de destino.',
    'event' => 'Evento',
    'subscription_event_1' => 'Cliente Criado',
    'subscription_event_2' => 'Fatura Criada',
    'subscription_event_3' => 'Orçamento Criado',
    'subscription_event_4' => 'Pagamento Criado',
    'subscription_event_5' => 'Fornecedor Criado',
    'subscription_event_6' => 'Orçamento Atualizado',
    'subscription_event_7' => 'Orçamento Excluído',
    'subscription_event_8' => 'Fatura Atualizada',
    'subscription_event_9' => 'Fatura Excluída',
    'subscription_event_10' => 'Cliente Atualizado',
    'subscription_event_11' => 'Cliente Excluído',
    'subscription_event_12' => 'Pagamento Excluído',
    'subscription_event_13' => 'Fornecedor Atualizado',
    'subscription_event_14' => 'Fornecedor Excluído',
    'subscription_event_15' => 'Despesa Criada',
    'subscription_event_16' => 'Despesa Atualizada',
    'subscription_event_17' => 'Despesa Excluída',
    'subscription_event_18' => 'Tarefa Criada',
    'subscription_event_19' => 'Tarefa Atualizada',
    'subscription_event_20' => 'Tarefa Excluída',
    'subscription_event_21' => 'Orçamento Aprovado',
    'subscriptions' => 'Assinaturas',
    'updated_subscription' => 'Assinatura atualizada com sucesso',
    'created_subscription' => 'Assinatura criada com sucesso',
    'edit_subscription' => 'Ediar Assinatura',
    'archive_subscription' => 'Arquivar Assinatura',
    'archived_subscription' => 'Assinatura arquivada com sucesso',
    'project_error_multiple_clients' => 'Os projetos não podem pertencer a diferentes clientes',
    'invoice_project' => 'Faturar Projeto',
    'module_recurring_invoice' => 'Faturas Recorrentes',
    'module_credit' => 'Créditos',
    'module_quote' => 'Orçamentos e Propostas',
    'module_task' => 'Tarefas & Projetos',
    'module_expense' => 'Despesas & Fornecedores',
    'module_ticket' => 'Tickets',
    'reminders' => 'Lembretes',
    'send_client_reminders' => 'Envie lembretes via email',
    'can_view_tasks' => 'Tarefas são visíveis no portal',
    'is_not_sent_reminders' => 'Lembretes não são enviados',
    'promotion_footer' => 'Sua promoção irá expirar em breve, :link para atualizar agora.',
    'unable_to_delete_primary' => 'Nota: para excluir esta empresa, primeiro exclua todas as empresas vinculadas.',
    'please_register' => 'Por favor registre sua conta',
    'processing_request' => 'Processando pedido',
    'mcrypt_warning' => 'Aviso: Mcrypt está obsoleto, execute :command para atualizar sua cifra.',
    'edit_times' => 'Editar Tempos',
    'inclusive_taxes_help' => 'Incluir <b>impostos no custo</b>',
    'inclusive_taxes_notice' => 'Esta configuração não pode ser modificada uma vez que uma fatura seja criada.',
    'inclusive_taxes_warning' => 'Aviso: faturas existentes terão que ser re-salvas',
    'copy_shipping' => 'Copiar Envio',
    'copy_billing' => 'Copiar Cobrança',
    'quote_has_expired' => 'O orçamento expirou, por favor contate o vendedor.',
    'empty_table_footer' => 'Exibindo 0 de 0 no total de 0 registros',
    'do_not_trust' => 'Não lembrar deste dispositivo',
    'trust_for_30_days' => 'Confiar por 30 dias',
    'trust_forever' => 'Sempre confiar',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Pronto para fazer',
    'in_progress' => 'Em progresso',
    'add_status' => 'Adicionar status',
    'archive_status' => 'Arquivar Status',
    'new_status' => 'Novo status',
    'convert_products' => 'Converter Produtos',
    'convert_products_help' => 'Converter automaticamente preços de produtos para a moeda do cliente',
    'improve_client_portal_link' => 'Definir um subdomínio para diminuir o link do portal do cliente.',
    'budgeted_hours' => 'Horas Orçadas',
    'progress' => 'Progresso',
    'view_project' => 'Visualizar Projeto',
    'summary' => 'Sumário',
    'endless_reminder' => 'Lembrete contínuo',
    'signature_on_invoice_help' => 'Adicione o seguinte código para exibir a assinatura do seu cliente no PDF.',
    'signature_on_pdf' => 'Exibir em PDF',
    'signature_on_pdf_help' => 'Exibir a assinatura do cliente no PDF da fatura/orçamento.',
    'expired_white_label' => 'A licença white-label expirou',
    'return_to_login' => 'Voltar ao Login',
    'convert_products_tip' => 'Nota: adicione um :link chamado ":name" para ver a taxa de câmbio',
    'amount_greater_than_balance' => 'A quantia é maior que o balanço da fatura, um crédito será criado com a quantia restante.',
    'custom_fields_tip' => 'Utilize <code>Rótulo|Opção1|Opção2</code> para exibir uma caixa de seleção.',
    'client_information' => 'Informação do Cliente',
    'updated_client_details' => 'Detalhes do cliente atualizados com sucesso',
    'auto' => 'Auto',
    'tax_amount' => 'Quantia de Impostos',
    'tax_paid' => 'Impostos pagos',
    'none' => 'Nenhum',
    'proposal_message_button' => 'Para visualizar sua proposta para :amount, clique no botão abaixo.',
    'proposal' => 'Proposta',
    'proposals' => 'Propostas',
    'list_proposals' => 'Listar Propostas',
    'new_proposal' => 'Nova Proposta',
    'edit_proposal' => 'Editar Proposta',
    'archive_proposal' => 'Arquivar Proposta',
    'delete_proposal' => 'Excluir Proposta',
    'created_proposal' => 'Proposta criada com sucesso',
    'updated_proposal' => 'Proposta atualizada com sucesso',
    'archived_proposal' => 'Proposta arquivada com sucesso',
    'deleted_proposal' => 'Proposta arquivada com sucesso',
    'archived_proposals' => ':count propostas arquivadas com sucesso',
    'deleted_proposals' => ':count propostas arquivadas com sucesso',
    'restored_proposal' => 'Proposta restaurada com sucesso',
    'restore_proposal' => 'Restaurar Proposta',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'Novo Snippet',
    'edit_proposal_snippet' => 'Editar Snippet',
    'archive_proposal_snippet' => 'Arquivar Snippet',
    'delete_proposal_snippet' => 'Excluir Snippet',
    'created_proposal_snippet' => 'Snippet criado com sucesso',
    'updated_proposal_snippet' => 'Snippet atualizado com sucesso',
    'archived_proposal_snippet' => 'Snippet arquivado com sucesso',
    'deleted_proposal_snippet' => 'Snippet arquivado com sucesso',
    'archived_proposal_snippets' => ':count Snippets arquivados com sucesso',
    'deleted_proposal_snippets' => ':count Snippets arquivados com sucesso',
    'restored_proposal_snippet' => 'Snippet restaurado com sucesso',
    'restore_proposal_snippet' => 'Restaurar Snippet',
    'template' => 'Modelo',
    'templates' => 'Modelos',
    'proposal_template' => 'Modelo',
    'proposal_templates' => 'Modelos',
    'new_proposal_template' => 'Novo Modelo',
    'edit_proposal_template' => 'Editar Modelo',
    'archive_proposal_template' => 'Arquivar Modelo',
    'delete_proposal_template' => 'Excluir Modelo',
    'created_proposal_template' => 'Modelo criado com sucesso',
    'updated_proposal_template' => 'Modelo atualizado com sucesso',
    'archived_proposal_template' => 'Modelo arquivado com sucesso',
    'deleted_proposal_template' => 'Modelo arquivado com sucesso',
    'archived_proposal_templates' => ':count modelos arquivados com sucesso',
    'deleted_proposal_templates' => ':count modelos arquivados com sucesso',
    'restored_proposal_template' => 'Modelo restaurado com sucesso',
    'restore_proposal_template' => 'Restaurar Modelo',
    'proposal_category' => 'Categoria',
    'proposal_categories' => 'Categorias',
    'new_proposal_category' => 'Nova Categoria',
    'edit_proposal_category' => 'Editar Categoria',
    'archive_proposal_category' => 'Arquivar Categoria',
    'delete_proposal_category' => 'Excluir Categoria',
    'created_proposal_category' => 'Categoria criada com sucesso',
    'updated_proposal_category' => 'Categoria atualizada com sucesso',
    'archived_proposal_category' => 'Categoria arquivada com sucesso',
    'deleted_proposal_category' => 'Categoria arquivada com sucesso',
    'archived_proposal_categories' => ':count categorias arquivadas com sucesso',
    'deleted_proposal_categories' => ':count categorias arquivadas com sucesso',
    'restored_proposal_category' => 'Categoria restaurada com sucesso',
    'restore_proposal_category' => 'Restaurar Categoria',
    'delete_status' => 'Excluir Status',
    'standard' => 'Padrão',
    'icon' => 'Ícone',
    'proposal_not_found' => 'A proposta solicitada não está disponível',
    'create_proposal_category' => 'Criar Categoria',
    'clone_proposal_template' => 'Clonar Modelo',
    'proposal_email' => 'Email de Proposta',
    'proposal_subject' => 'Nova proposta :number de :account',
    'proposal_message' => 'Para visualizar sua proposta para :amount, clique no link abaixo.',
    'emailed_proposal' => 'Proposta enviada por email com sucesso',
    'load_template' => 'Carregar Modelo',
    'no_assets' => 'Sem imagens, arraste para fazer upload',
    'add_image' => 'Adicionar Imagem',
    'select_image' => 'Selecionar Imagem',
    'upgrade_to_upload_images' => 'Atualizar para o plano enterprise para enviar imagens',
    'delete_image' => 'Excluir Imagem',
    'delete_image_help' => 'Aviso: excluir a imagem irá removê-la de todas as propostas.',
    'amount_variable_help' => 'Nota: o campo $amount da fatura usará o campo parcial/depósito se habilitado ou usará o saldo da fatura.',
    'taxes_are_included_help' => 'Nota: Impostos inclusivos foram habilitados.',
    'taxes_are_not_included_help' => 'Nota: Impostos inclusivos não estão habilitados. ',
    'change_requires_purge' => 'Alterar esta configuração requer :link para os dados da conta.',
    'purging' => 'limpando',
    'warning_local_refund' => 'O reembolso será registrado no app mas NÃO será processado pelo gateway de pagamento.',
    'email_address_changed' => 'O endereço de email foi alterado',
    'email_address_changed_message' => 'O endereço de email para sua conta foi alterado de :old_email to :new_email.',
    'test' => 'Teste',
    'beta' => 'Beta',
    'gmp_required' => 'Exportação para ZIP requer a extensão GMP',
    'email_history' => 'Histórico de Emails',
    'loading' => 'Carregando',
    'no_messages_found' => 'Nenhuma mensagem encontrada',
    'processing' => 'Processando',
    'reactivate' => 'Reativar',
    'reactivated_email' => 'Seu endereço de email foi reativado',
    'emails' => 'Emails',
    'opened' => 'Aberto',
    'bounced' => 'Devolvido',
    'total_sent' => 'Total Enviado',
    'total_opened' => 'Total Abertos',
    'total_bounced' => 'Total Devolvidos',
    'total_spam' => 'Total Spams',
    'platforms' => 'Plataformas',
    'email_clients' => 'Clientes de Email',
    'mobile' => 'Móvel',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Grupo',
    'subgroup' => 'Subgrupo',
    'unset' => 'Não definido',
    'received_new_payment' => 'Você recebeu um novo pagamento!',
    'slack_webhook_help' => 'Receber notificações de pagamentos utilizando :link.',
    'slack_incoming_webhooks' => 'Webhooks de entrada do Slack',
    'accept' => 'Aceitar',
    'accepted_terms' => 'Os termos de serviço atuais foram aceitos com sucesso',
    'invalid_url' => 'URL inválida',
    'workflow_settings' => 'Configurações de Fluxo de Trabalho',
    'auto_email_invoice' => 'Email Automático',
    'auto_email_invoice_help' => 'Enviar faturas recorrentes por email automaticamente quando forem criadas.',
    'auto_archive_invoice' => 'Arquivar Automaticamente',
    'auto_archive_invoice_help' => 'Arquivar automaticamente faturas quando forem pagas.',
    'auto_archive_quote' => 'Arquivar Automaticamente',
    'auto_archive_quote_help' => 'Arquivar automaticamente orçamentos quando forem convertidos.',
    'require_approve_quote' => 'Solicitar aprovação de orçamento',
    'require_approve_quote_help' => 'Solicitar aos clientes aprovação de orçamento.',
    'allow_approve_expired_quote' => 'Permitir a aprovação de orçamentos expirados',
    'allow_approve_expired_quote_help' => 'Permitir que clientes aprovem orçamentos expirados.',
    'invoice_workflow' => 'Fluxo de Trabalho de Faturas',
    'quote_workflow' => 'Fluxo de Trabalho de Orçamentos',
    'client_must_be_active' => 'Erro: o cliente precisa estar ativo',
    'purge_client' => 'Limpar Cliente',
    'purged_client' => 'Cliente limpo com sucesso',
    'purge_client_warning' => 'Todos os registros relacionados (faturas, tarefas, despesas, documentos, etc...) também serão excluídos',
    'clone_product' => 'Clonar Produto',
    'item_details' => 'Detalhes do Item',
    'send_item_details_help' => 'Enviar detalhes do item para o gateway de pagamento.',
    'view_proposal' => 'Visualizar Proposta',
    'view_in_portal' => 'Visualizar no Portal',
    'cookie_message' => 'Este website utiliza cookies para garantir que você tenha uma melhor experiência.',
    'got_it' => 'Entendi!',
    'vendor_will_create' => 'fornecedor será criado',
    'vendors_will_create' => 'fornecedores serão criados',
    'created_vendors' => ':count fornecedor(es) criado(s) com sucesso',
    'import_vendors' => 'Importar Fornecedores',
    'company' => 'Empresa',
    'client_field' => 'Campo do Cliente',
    'contact_field' => 'Campo do Contato',
    'product_field' => 'Campo do Produto',
    'task_field' => 'Campo da Tarefa',
    'project_field' => 'Campo do Projeto',
    'expense_field' => 'Campo da Despesa',
    'vendor_field' => 'Campo do Fornecedor',
    'company_field' => 'Campo da Empresa',
    'invoice_field' => 'Campo da Fatura',
    'invoice_surcharge' => 'Sobretaxa de Fatura',
    'custom_task_fields_help' => 'Adicionar um campo na criação de uma tarefa.',
    'custom_project_fields_help' => 'Adicionar um campo na criação de um projeto.',
    'custom_expense_fields_help' => 'Adicionar um campo na criação de uma despesa.',
    'custom_vendor_fields_help' => 'Adicionar um campo na criação de um fornecedor.',
    'messages' => 'Mensagens',
    'unpaid_invoice' => 'Fatura não Paga',
    'paid_invoice' => 'Fatura Paga',
    'unapproved_quote' => 'Orçamento não Aprovado',
    'unapproved_proposal' => 'Proposta não Aprovada',
    'autofills_city_state' => 'Auto-preencher cidade/estado',
    'no_match_found' => 'Nenhum ocorrência encontrada',
    'password_strength' => 'Força da Senha',
    'strength_weak' => 'Fraca',
    'strength_good' => 'Boa',
    'strength_strong' => 'Forte',
    'mark' => 'Marcar',
    'updated_task_status' => 'Status da tarefa atualizado com sucesso',
    'background_image' => 'Imagem de Fundo',
    'background_image_help' => 'Utilize o :link para gerenciar suas imagens, recomendamos utilizar um arquivo pequeno.',
    'proposal_editor' => 'editor de proposta',
    'background' => 'Fundo',
    'guide' => 'Guia',
    'gateway_fee_item' => 'Item de Taxa de Gateway',
    'gateway_fee_description' => 'Sobretaxa de Taxa de Gateway',
    'gateway_fee_discount_description' => 'Desconto de Taxa de Gateway',
    'show_payments' => 'Exibir Pagamentos',
    'show_aging' => 'Exibir Envelhecimento',
    'reference' => 'Referência',
    'amount_paid' => 'Quantia Paga',
    'send_notifications_for' => 'Enviar Notificações Para',
    'all_invoices' => 'Todas as Faturas',
    'my_invoices' => 'Minhas Faturas',
    'payment_reference' => 'Referência de Pagamento',
    'maximum' => 'Máximo',
    'sort' => 'Ordenar',
    'refresh_complete' => 'Refresh Completo',
    'please_enter_your_email' => 'Por favor digite seu email',
    'please_enter_your_password' => 'Por favor digite sua senha',
    'please_enter_your_url' => 'Por favor digite sua URL',
    'please_enter_a_product_key' => 'Por favor digite uma chave de produto',
    'an_error_occurred' => 'Um erro ocorreu',
    'overview' => 'Resumo',
    'copied_to_clipboard' => ':value copiado para a área de transferência',
    'error' => 'Erro',
    'could_not_launch' => 'Não foi possível iniciar',
    'additional' => 'Adicional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email é inválido',
    'items' => 'Itens',
    'partial_deposit' => 'Parcial/Depósito',
    'add_item' => 'Adicionar Item',
    'total_amount' => 'Quantia Total',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Status da Fatura',
    'click_plus_to_add_item' => 'Clique + para adicionar um item',
    'count_selected' => ':count selecionados',
    'dismiss' => 'Dispensar',
    'please_select_a_date' => 'Por favor digite uma data',
    'please_select_a_client' => 'Por favor selecione um cliente',
    'language' => 'Idioma',
    'updated_at' => 'Atualizado',
    'please_enter_an_invoice_number' => 'Por favor digite um número de fatura',
    'please_enter_a_quote_number' => 'Por favor digite um número de orçamento',
    'clients_invoices' => 'Faturas de :client',
    'viewed' => 'Visualizado',
    'approved' => 'Aprovado',
    'invoice_status_1' => 'Rascunho',
    'invoice_status_2' => 'Enviado',
    'invoice_status_3' => 'Visualizado',
    'invoice_status_4' => 'Aprovado',
    'invoice_status_5' => 'Parcial',
    'invoice_status_6' => 'Pago',
    'marked_invoice_as_sent' => 'Fatura marcada como enviada com sucesso',
    'please_enter_a_client_or_contact_name' => 'Por favor digite um cliente ou nome de contato',
    'restart_app_to_apply_change' => 'Reinicie o app para aplicar a mudança',
    'refresh_data' => 'Atualizar Dados',
    'blank_contact' => 'Contato Vazio',
    'no_records_found' => 'Nenhum registro encontrado',
    'industry' => 'Indústria',
    'size' => 'Tamanho',
    'net' => 'Vencimento',
    'show_tasks' => 'Exibir tarefas',
    'email_reminders' => 'Lembretes de Email',
    'reminder1' => 'Primeiro Lembrete',
    'reminder2' => 'Segundo Lembrete',
    'reminder3' => 'Terceiro Lembrete',
    'send' => 'Enviar',
    'auto_billing' => 'Cobrança automática',
    'button' => 'Botão',
    'more' => 'Mais',
    'edit_recurring_invoice' => 'Editar Fatura Recorrente',
    'edit_recurring_quote' => 'Editar Orçamento Recorrente',
    'quote_status' => 'Status do Orçamento',
    'please_select_an_invoice' => 'Por favor escolha uma fatura',
    'filtered_by' => 'Filtrado por',
    'payment_status' => 'Status do Pagamento',
    'payment_status_1' => 'Pendente',
    'payment_status_2' => 'Anulado',
    'payment_status_3' => 'Falhou',
    'payment_status_4' => 'Completado',
    'payment_status_5' => 'Parcialmente Reembolsado',
    'payment_status_6' => 'Reembolsado',
    'send_receipt_to_client' => 'Enviar recibo para o cliente',
    'refunded' => 'Reembolsado',
    'marked_quote_as_sent' => 'Orçamento marcado como enviado com sucesso',
    'custom_module_settings' => 'Configurações Personalizadas de Módulo',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'Novo Ticket',
    'edit_ticket' => 'Editar Ticket',
    'view_ticket' => 'Visualizar Ticket',
    'archive_ticket' => 'Arquivar Ticket',
    'restore_ticket' => 'Restaurar Ticket',
    'delete_ticket' => 'Excluir Ticket',
    'archived_ticket' => 'Ticket arquivado com sucesso',
    'archived_tickets' => 'Tickets arquivados com sucesso',
    'restored_ticket' => 'Ticket restaurado com sucesso',
    'deleted_ticket' => 'Ticket excluído com sucesso',
    'open' => 'Aberto',
    'new' => 'Novo',
    'closed' => 'Fechado',
    'reopened' => 'Reaberto',
    'priority' => 'Prioridade',
    'last_updated' => 'Última Atualização',
    'comment' => 'Comentários',
    'tags' => 'Tags',
    'linked_objects' => 'Objetos Vinculados',
    'low' => 'Baixa',
    'medium' => 'Média',
    'high' => 'Alta',
    'no_due_date' => 'Nenhuma data de vencimento definida',
    'assigned_to' => 'Atribuído para',
    'reply' => 'Responder',
    'awaiting_reply' => 'Aguardando Resposta',
    'ticket_close' => 'Fechar Ticket',
    'ticket_reopen' => 'Reabrir Ticket',
    'ticket_open' => 'Abrir Ticket',
    'ticket_split' => 'Dividir Ticket',
    'ticket_merge' => 'Unir Ticket',
    'ticket_update' => 'Atualizar Ticket',
    'ticket_settings' => 'Configurações do Ticket',
    'updated_ticket' => 'Ticket Atualizado',
    'mark_spam' => 'Marcar como Spam',
    'local_part' => 'Parte Local',
    'local_part_unavailable' => 'Nome tomado',
    'local_part_available' => 'Nome disponível',
    'local_part_invalid' => 'Nome inválido (apenas alfanuméricos, sem espaços)',
    'local_part_help' => 'Personalizar a parte local de sua caixa de email de entrada. Ex: SEU_NOME@support.invoiceninja.com',
    'from_name_help' => 'Nome do remetente é o texto disponibilizado para ser mostrado ao invés do endereço de email. Ex: Centro de Suporte',
    'local_part_placeholder' => 'SEU_NOME',
    'from_name_placeholder' => 'Centro de Suporte',
    'attachments' => 'Anexos',
    'client_upload' => 'Uploads de Cliente',
    'enable_client_upload_help' => 'Permitir que clientes enviem documentos/anexos',
    'max_file_size_help' => 'O tamanho máximo de arquivo (KB) é limitado pelas suas variáveis post_max_size e upload_max_filesize definidos em seu PHP.INI',
    'max_file_size' => 'Tamanho máximo de arquivo',
    'mime_types' => 'Tipos MIME',
    'mime_types_placeholder' => '.pdf , .docx , .jpg',
    'mime_types_help' => 'Lista separada por vírgulas de tipos MIME permitidos, deixe em branco para TODOS',
    'ticket_number_start_help' => 'O número do Ticket precisa ser maior que o número de ticket atual',
    'new_ticket_template_id' => 'Novo Ticket',
    'new_ticket_autoresponder_help' => 'Selecionar um modelo enviará uma resposta automática para um cliente/contato quando um novo Ticket for criado',
    'update_ticket_template_id' => 'Ticket atualizado',
    'update_ticket_autoresponder_help' => 'Selecionar um modelo enviará uma resposta automática para um cliente/contato quando um novo Ticket for atualizado',
    'close_ticket_template_id' => 'Ticket fechado',
    'close_ticket_autoresponder_help' => 'Selecionar um modelo enviará uma resposta automática para um cliente/contato quando um novo Ticket for fechado',
    'default_priority' => 'Prioridade Padrão',
    'alert_new_comment_id' => 'Novo comentário',
    'alert_comment_ticket_help' => 'Selecionar um modelo enviará uma notificação (para um agente) quando um novo comentário for feito.',
    'alert_comment_ticket_email_help' => 'Emails separados por vírgulas para cco após um novo comentário.',
    'new_ticket_notification_list' => 'Notificações adicionais de novo ticket',
    'update_ticket_notification_list' => 'Notificações adicionais de novo comentário',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Atribuição de Ticket',
    'alert_ticket_assign_agent_id_hel' => 'Selecionar um modelo enviará uma notificação (para um agente) quando um ticket for atribuído.',
    'alert_ticket_assign_agent_id_notifications' => 'Notificações adicionais de ticket atribuído',
    'alert_ticket_assign_agent_id_help' => 'Emails separados por vírgulas para cco após atribuição de ticket.',
    'alert_ticket_transfer_email_help' => 'Emails separados por vírgulas para cco após transferência de ticket.',
    'alert_ticket_overdue_agent_id' => 'Atraso de Ticket',
    'alert_ticket_overdue_email' => 'Notificações adicionais de ticket atrasado',
    'alert_ticket_overdue_email_help' => 'Emails separados por vírgulas para cco após atraso de ticket. ',
    'alert_ticket_overdue_agent_id_help' => 'Selecionar um modelo enviará uma notificação (para um agente) quando um ticket atrasar. ',
    'ticket_master' => 'Gestor de Tickets',
    'ticket_master_help' => 'Possui a habilidade de atribuir e transferir Tickets. Atribuído como o agente padrão para todos os Tickets.',
    'default_agent' => 'Agente Padrão',
    'default_agent_help' => 'Se selecionado irá automaticamente ser selecionado para todos os tickets entrantes',
    'show_agent_details' => 'Exibir detalhes do agente nas respostas',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remover avatar',
    'ticket_not_found' => 'Ticket não encontrado',
    'add_template' => 'Adicionar Modelo',
    'ticket_template' => 'Modelo de Ticket',
    'ticket_templates' => 'Modelos de Tickets',
    'updated_ticket_template' => 'Modelo de Ticket Atualizado',
    'created_ticket_template' => 'Modelo de Ticket Criado',
    'archive_ticket_template' => 'Arquivar Modelo',
    'restore_ticket_template' => 'Restaurar Modelo',
    'archived_ticket_template' => 'Modelo arquivado com sucesso',
    'restored_ticket_template' => 'Modelo restaurado com sucesso',
    'close_reason' => 'Conte-nos o motivo de você estar fechando este ticket',
    'reopen_reason' => 'Conte-nos o motivo de você estar reabrindo este ticket',
    'enter_ticket_message' => 'Por favor digite uma mensagem para atualizar o ticket',
    'show_hide_all' => 'Exibir / Esconder tudo',
    'subject_required' => 'Assunto obrigatório',
    'mobile_refresh_warning' => 'Se você está utilizando o app móvel você pode precisar executar um refresh total.',
    'enable_proposals_for_background' => 'Para enviar uma imagem de fundo :link para habilitar o módulo de propostas',
    'ticket_assignment' => 'Ticket :ticket_number foi atribuído para :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number foi atualizado pelo cliente :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number foi criado.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number foi atualizado.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number foi fechado.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number agora está atrasado',
    'merge' => 'Unir',
    'merged' => 'Unidos',
    'agent' => 'Agente',
    'parent_ticket' => 'Ticket Pai',
    'linked_tickets' => 'Tickets Vinculados',
    'merge_prompt' => 'Digite o número do ticket para união',
    'merge_from_to' => 'Ticket #:old_ticket unido ao Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket foi fechado e unido ao Ticket #:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket foi fechado e unido a este ticket',
    'merge_placeholder' => 'Unir ticket #:ticket no seguinte ticket',
    'select_ticket' => 'Selecione um Ticket',
    'new_internal_ticket' => 'Novo ticket interno',
    'internal_ticket' => 'Ticket interno',
    'create_ticket' => 'Criar ticket',
    'allow_inbound_email_tickets_external' => 'Novos Tickets por email (Cliente)',
    'allow_inbound_email_tickets_external_help' => 'Permitir que clientes criem novos Tickets por email',
    'include_in_filter' => 'Incluir no filtro',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Comparar',
    'hosted_login' => 'Login Hospedado',
    'selfhost_login' => 'Login Auto-Hospedado',
    'google_login' => 'Login via Google',
    'thanks_for_patience' => 'Obrigado por sua paciência enquanto trabalhamos para implementar estas funcionalidades.\n\nEsperamos tê-las concluídas nos próximos meses.\n\nAté lá, continuaremos dando suporte ao',
    'legacy_mobile_app' => 'App móvel legado',
    'today' => 'Hoje',
    'current' => 'Atual',
    'previous' => 'Anterior',
    'current_period' => 'Período Atual',
    'comparison_period' => 'Período de Comparação',
    'previous_period' => 'Período Anterior',
    'previous_year' => 'Ano Anterior',
    'compare_to' => 'Comparar com',
    'last_week' => 'Última Semana',
    'clone_to_invoice' => 'Clonar para Fatura',
    'clone_to_quote' => 'Clonar ao Orçamento',
    'convert' => 'Converter',
    'last7_days' => 'Últimos 7 Dias',
    'last30_days' => 'Últimos 30 Dias',
    'custom_js' => 'JS Personalizado',
    'adjust_fee_percent_help' => 'Ajustar o percentual de taxa a contabilizar',
    'show_product_notes' => 'Exibir detalhes do produto',
    'show_product_notes_help' => 'Incluir a <b>descrição e custo</b> na caixa de seleção do produto',
    'important' => 'Importante',
    'thank_you_for_using_our_app' => 'Obrigado por usar nosso app!',
    'if_you_like_it' => 'Se você desejar por favor',
    'to_rate_it' => 'para dar uma nota.',
    'average' => 'Médio',
    'unapproved' => 'Não Aprovado',
    'authenticate_to_change_setting' => 'Por favor autentique-se para modificar esta configuração',
    'locked' => 'Travado',
    'authenticate' => 'Autenticar',
    'please_authenticate' => 'Por favor autentique-se',
    'biometric_authentication' => 'Autenticação Biométrica',
    'auto_start_tasks' => 'Iniciar Tarefas Automaticamente',
    'budgeted' => 'Orçado',
    'please_enter_a_name' => 'Por favor digite um nome',
    'click_plus_to_add_time' => 'Clique + para adicionar tempo',
    'design' => 'Design',
    'password_is_too_short' => 'A senha é muito curta',
    'failed_to_find_record' => 'Falha ao procurar registro',
    'valid_until_days' => 'Válido Até',
    'valid_until_days_help' => 'Define automaticamente o valor <b>Válido até</b> nas cotações para muitos dias no futuro. Deixe em branco para desativar.',
    'usually_pays_in_days' => 'Dias',
    'requires_an_enterprise_plan' => 'Necessita um plano empresarial',
    'take_picture' => 'Tire uma Foto',
    'upload_file' => 'Enviar Arquivo',
    'new_document' => 'Novo Documento',
    'edit_document' => 'Editar Documento',
    'uploaded_document' => 'Documento enviado com sucesso',
    'updated_document' => 'Documento atualizado com sucesso',
    'archived_document' => 'Documento arquivado com sucesso',
    'deleted_document' => 'Documento apagado com sucesso',
    'restored_document' => 'Documento recuperado com sucesso',
    'no_history' => 'Sem Histórico',
    'expense_status_1' => 'Autenticado',
    'expense_status_2' => 'Pendente',
    'expense_status_3' => 'Faturado',
    'no_record_selected' => 'Nenhum registro selecionado',
    'error_unsaved_changes' => 'Por favor, salve ou cancele suas alterações ',
    'thank_you_for_your_purchase' => 'Obrigado por sua compra!',
    'redeem' => 'Resgatar',
    'back' => 'Voltar',
    'past_purchases' => 'Compras Passadas',
    'annual_subscription' => 'Assinatura Anual',
    'pro_plan' => 'Plano Pro',
    'enterprise_plan' => 'Plano Empresarial',
    'count_users' => ':count usuários',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Por favor digite o primeiro nome',
    'please_enter_a_last_name' => 'Por favor digite o sobrenome',
    'please_agree_to_terms_and_privacy' => 'Por favor, aceite os termos de serviço e política de privacidade para criar uma conta.',
    'i_agree_to_the' => 'Aceito os',
    'terms_of_service_link' => 'termos do serviço ',
    'privacy_policy_link' => 'política de privacidade',
    'view_website' => 'Ver o Website',
    'create_account' => 'Criar Conta',
    'email_login' => 'E-mail de Login',
    'late_fees' => 'Taxas atrasadas',
    'payment_number' => 'Pagamento Número',
    'before_due_date' => 'Até a data de vencimento',
    'after_due_date' => 'Depois da data de vencimento',
    'after_invoice_date' => 'Até a data da fatura',
    'filtered_by_user' => 'Filtrado por Usuário',
    'created_user' => 'Usuário criado com sucesso',
    'primary_font' => 'Fonte Primária',
    'secondary_font' => 'Fonte Secundária',
    'number_padding' => 'Preenchimento de número',
    'general' => 'Geral',
    'surcharge_field' => 'Campo de Sobretaxa',
    'company_value' => 'Valor da Empresa',
    'credit_field' => 'Campo de Crédito',
    'payment_field' => 'Campo de Pagamento',
    'group_field' => 'Campo de Grupo',
    'number_counter' => 'Contador Numérico',
    'number_pattern' => 'Padrão de Numeração ',
    'custom_javascript' => 'JavaScript Personalizado',
    'portal_mode' => 'Modo Portal',
    'attach_pdf' => 'Anexar PDF',
    'attach_documents' => 'Anexar Documentos',
    'attach_ubl' => 'Anexar UBL',
    'email_style' => 'Estilo do E-mail',
    'processed' => 'Processado',
    'fee_amount' => 'Valor da Multa',
    'fee_percent' => 'Porcentagem da Multa',
    'fee_cap' => 'Taxa máxima',
    'limits_and_fees' => 'Limites/Multas',
    'credentials' => 'Credenciais',
    'require_billing_address_help' => 'Exigir que o cliente forneça seu endereço de cobrança',
    'require_shipping_address_help' => 'Exigir que o cliente forneça seu endereço de entrega',
    'deleted_tax_rate' => 'Taxa de imposto excluída com sucesso',
    'restored_tax_rate' => 'Taxa de imposto restaurada com sucesso',
    'provider' => 'Provedor',
    'company_gateway' => 'Gateway de Pagamento',
    'company_gateways' => 'Gateways de Pagamento',
    'new_company_gateway' => 'Novo Gateway',
    'edit_company_gateway' => 'Editar Gateway',
    'created_company_gateway' => 'Gateway criado com sucesso',
    'updated_company_gateway' => 'Gateway atualizado com sucesso',
    'archived_company_gateway' => 'Gateway arquivado com sucesso',
    'deleted_company_gateway' => 'Gateway excluído com sucesso',
    'restored_company_gateway' => 'Gateway restaurado com sucesso',
    'continue_editing' => 'Continuar Editando',
    'default_value' => 'Valor padrão',
    'currency_format' => 'Formato de Moeda',
    'first_day_of_the_week' => 'Primeiro dia da Semana',
    'first_month_of_the_year' => 'Primeiro Mês do Ano',
    'symbol' => 'Símbolo',
    'ocde' => 'Código',
    'date_format' => 'Formato de Data',
    'datetime_format' => 'Formato de Data/Hora',
    'send_reminders' => 'Enviar Lembretes',
    'timezone' => 'Fuso Horário',
    'filtered_by_group' => 'Filtrado por Grupo',
    'filtered_by_invoice' => 'Filtrado por Fatura',
    'filtered_by_client' => 'Filtrado por Cliente',
    'filtered_by_vendor' => 'Filtrado por Vendedor',
    'group_settings' => 'Configurações de Grupos',
    'groups' => 'Grupos',
    'new_group' => 'Novo Grupo',
    'edit_group' => 'Editar Grupo',
    'created_group' => 'Grupo criado com sucesso',
    'updated_group' => 'Grupo atualizado com sucesso',
    'archived_group' => 'Grupo arquivado com sucesso',
    'deleted_group' => 'Grupo removido com sucesso',
    'restored_group' => 'Grupo restaurado com sucesso',
    'upload_logo' => 'Carregar Logo',
    'uploaded_logo' => 'Logo carregado com sucesso',
    'saved_settings' => 'Configurações salvas com sucesso',
    'device_settings' => 'Configurações do Dispositivo',
    'credit_cards_and_banks' => 'Cartões de Crédito & Bancos',
    'price' => 'Preço ',
    'email_sign_up' => 'Inscrição de Email',
    'google_sign_up' => 'Inscrição no Google',
    'sign_up_with_google' => 'Inscreva-se com o Google',
    'long_press_multiselect' => 'Seleção múltipla de longa pressão',
    'migrate_to_next_version' => 'Migrar para a próxima versão do Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migração ',
    'welcome_to_the_new_version' => 'Bem-vindo a nova versão do Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Clique no botão abaixo para fazer o download dos dados.',
    'migration_import' => 'Sensacional! Agora você está pronto para importar sua migração. Acesse sua nova instalação para importar seus dados',
    'continue' => 'Continuar',
    'company1' => 'Companhia 1 Personalizada',
    'company2' => 'Companhia 2 Personalizada',
    'company3' => 'Companhia 3 Personalizada',
    'company4' => 'Companhia 4 Personalizada',
    'product1' => 'Produto 1 Personalizado',
    'product2' => 'Produto 2 Personalizado',
    'product3' => 'Produto 3 Personalizado',
    'product4' => 'Produto 4 Personalizado',
    'client1' => 'Cliente 1 Personalizado',
    'client2' => 'Cliente 2 Personalizado',
    'client3' => 'Cliente 3 Personalizado',
    'client4' => 'Cliente 4 Personalizado',
    'contact1' => 'Contato 1 Personalizado',
    'contact2' => 'Contato 2 Personalizado',
    'contact3' => 'Contato 3 Personalizado',
    'contact4' => 'Contato 4 Personalizado',
    'task1' => 'Tarefa 1 Personalizada',
    'task2' => 'Tarefa 2 Personalizada',
    'task3' => 'Tarefa 3 Personalizada',
    'task4' => 'Tarefa 4 Personalizada',
    'project1' => 'Projeto 1 Personalizado',
    'project2' => 'Projeto 2 Personalizado',
    'project3' => 'Projeto 3 Personalizado',
    'project4' => 'Projeto 4 Personalizado',
    'expense1' => 'Despesa 1 Personalizada',
    'expense2' => 'Despesa 2 Personalizada',
    'expense3' => 'Despesa 3 Personalizada',
    'expense4' => 'Despesa 4 Personalizada',
    'vendor1' => 'Vendedor 1 Personalizado',
    'vendor2' => 'Vendedor 2 Personalizado',
    'vendor3' => 'Vendedor 3 Personalizado',
    'vendor4' => 'Vendedor 4 Personalizado',
    'invoice1' => 'Fatura 1 Personalizada',
    'invoice2' => 'Fatura 2 Personalizada',
    'invoice3' => 'Fatura 3 Personalizada',
    'invoice4' => 'Fatura 4 Personalizada',
    'payment1' => 'Pagamento 1 Personalizado',
    'payment2' => 'Pagamento 2 Personalizado',
    'payment3' => 'Pagamento 3 Personalizado',
    'payment4' => 'Pagamento 4 Personalizado',
    'surcharge1' => 'Sobretaxa Personalizada 1',
    'surcharge2' => 'Sobretaxa Personalizada 2',
    'surcharge3' => 'Sobretaxa Personalizada 3',
    'surcharge4' => 'Sobretaxa Personalizada 4',
    'group1' => 'Grupo 1 Personalizado',
    'group2' => 'Grupo 2 Personalizado',
    'group3' => 'Grupo 3 Personalizado',
    'group4' => 'Grupo 4 Personalizado',
    'number' => 'Número',
    'count' => 'Contagem',
    'is_active' => 'Ativo',
    'contact_last_login' => 'Último Login do Contato',
    'contact_full_name' => 'Nome Completo do Contato',
    'contact_custom_value1' => 'Valor personalizado do contato 1',
    'contact_custom_value2' => 'Valor personalizado do contato 2',
    'contact_custom_value3' => 'Valor personalizado do contato 3',
    'contact_custom_value4' => 'Valor personalizado do contato 4',
    'assigned_to_id' => 'Atribuído ao ID',
    'created_by_id' => 'Criado pelo ID',
    'add_column' => 'Adicionar Coluna',
    'edit_columns' => 'Editar Colunas',
    'to_learn_about_gogle_fonts' => 'para aprender mais sobre o Google Fonts',
    'refund_date' => 'Data de Reembolso',
    'multiselect' => 'Seleção múltipla',
    'verify_password' => 'Verificar Senha',
    'applied' => 'Aplicado',
    'include_recent_errors' => 'Inclui erros recentes dos logs',
    'your_message_has_been_received' => 'Recebemos sua mensagem e tentaremos responder rapidamente.',
    'show_product_details' => 'Mostrar Detalhes do Produto',
    'show_product_details_help' => 'Inclua a descrição e o custo na lista suspensa do produto',
    'pdf_min_requirements' => 'A renderização de PDF precisa da versão :version',
    'adjust_fee_percent' => 'Ajustar Porcentagem da Multa',
    'configure_settings' => 'Configurações Gerais',
    'about' => 'Sobre',
    'credit_email' => 'E-mail de Crédito',
    'domain_url' => 'URL do Domínio',
    'password_is_too_easy' => 'A senha deve conter um caractere maiúsculo e um número',
    'client_portal_tasks' => 'Tarefas do Portal do Cliente',
    'client_portal_dashboard' => 'Painel do Portal do Cliente',
    'please_enter_a_value' => 'Por favor digite um valor',
    'deleted_logo' => 'Logo removido com sucesso',
    'generate_number' => 'Gerar Número',
    'when_saved' => 'Quando Salvo',
    'when_sent' => 'Quando Enviado',
    'select_company' => 'Selecionar Empresa',
    'float' => 'Flutuante',
    'collapse' => 'Fechar',
    'show_or_hide' => 'Exibir/esconder',
    'menu_sidebar' => 'Menu da Barra Lateral',
    'history_sidebar' => 'Barra Lateral de Histórico',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Módulo',
    'first_custom' => 'Primeiro Personalizado',
    'second_custom' => 'Segundo Personalizado',
    'third_custom' => 'Terceiro Personalizado',
    'show_cost' => 'Mostrar Custo',
    'show_cost_help' => 'Exibir um campo de custo do produto para rastrear a marcação/lucro',
    'show_product_quantity' => 'Mostrar Quantidade do Produto',
    'show_product_quantity_help' => 'Mostrar um campo de quantidade de produto, caso contrário o padrão de um',
    'show_invoice_quantity' => 'Mostrar quantidade da fatura',
    'show_invoice_quantity_help' => 'Exibir um campo de quantidade de item de linha, caso contrário, o padrão é um',
    'default_quantity' => 'Quantidade Padrão',
    'default_quantity_help' => 'Defina automaticamente a quantidade do item de linha para um',
    'one_tax_rate' => 'Uma taxa de imposto',
    'two_tax_rates' => 'Duas taxas de impostos',
    'three_tax_rates' => 'Três taxas de impostos',
    'default_tax_rate' => 'Taxa de imposto padrão',
    'invoice_tax' => 'Imposto da Fatura',
    'line_item_tax' => 'Imposto da Linha do Item',
    'inclusive_taxes' => 'Impostos Inclusos',
    'invoice_tax_rates' => 'Tarifa do Imposto da Fatura',
    'item_tax_rates' => 'Tarifa do Imposto do Item',
    'configure_rates' => 'Configurar tarifas',
    'tax_settings_rates' => 'Tarifas de Impostos',
    'accent_color' => 'Cor de destaque',
    'comma_sparated_list' => 'Lista separada por vírgulas',
    'single_line_text' => 'Texto de linha única',
    'multi_line_text' => 'Texto multilinha',
    'dropdown' => 'Dropdown',
    'field_type' => 'Tipo de Campo',
    'recover_password_email_sent' => 'Foi enviado um e-mail de recuperação de senha',
    'removed_user' => 'Usuário removido com sucesso',
    'freq_three_years' => 'Três Anos',
    'military_time_help' => 'Formato de Hora 24h',
    'click_here_capital' => 'Clique aqui',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Faturas marcadas como enviadas com sucesso',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'O sistema falhou ao enviar a fatura :invoice',
    'custom_value3' => 'Valor Personalizado 3',
    'custom_value4' => 'Valor Personalizado 4',
    'email_style_custom' => 'Estilo de E-mail Personalizado',
    'custom_message_dashboard' => 'Mensagem de Painel Personalizada',
    'custom_message_unpaid_invoice' => 'Mensagem Personalizada de Fatura Atrasada',
    'custom_message_paid_invoice' => 'Mensagem Personalizada de Fatura Paga',
    'custom_message_unapproved_quote' => 'Mensagem Personalizada de Orçamento Não Aprovado',
    'lock_sent_invoices' => 'Travar Faturas Enviadas',
    'translations' => 'Traduções ',
    'task_number_pattern' => 'Padrão de Numeração de Tarefa',
    'task_number_counter' => 'Contador Numérico de Tarefas',
    'expense_number_pattern' => 'Padrão de Numeração de Despesa',
    'expense_number_counter' => 'Contador Numérico de Despesas',
    'vendor_number_pattern' => 'Padrão de Numeração de Vendedor',
    'vendor_number_counter' => 'Contador Numérico de Vendedores',
    'ticket_number_pattern' => 'Padrão de Numeração de Ticket',
    'ticket_number_counter' => 'Contador Numérico de Tickets',
    'payment_number_pattern' => 'Padrão de Numeração de Pagamento',
    'payment_number_counter' => 'Contador Numérico de Pagamentos',
    'invoice_number_pattern' => 'Padrão de Numeração de Fatura',
    'quote_number_pattern' => 'Padrão de Numeração de Orçamento ',
    'client_number_pattern' => 'Padrão de Numeração de Crédito',
    'client_number_counter' => 'Contador Numérico de Créditos',
    'credit_number_pattern' => 'Padrão de Numeração de Crédito',
    'credit_number_counter' => 'Contador Numérico de Créditos',
    'reset_counter_date' => 'Reiniciar Data do Contador',
    'counter_padding' => 'Padrão do Contador',
    'shared_invoice_quote_counter' => 'Contador de cotação de fatura compartilhada',
    'default_tax_name_1' => 'Nome fiscal padrão 1',
    'default_tax_rate_1' => 'Taxa de imposto padrão 1',
    'default_tax_name_2' => 'Nome fiscal padrão 2',
    'default_tax_rate_2' => 'Taxa de imposto padrão 2',
    'default_tax_name_3' => 'Nome fiscal padrão 3',
    'default_tax_rate_3' => 'Taxa de imposto padrão 3',
    'email_subject_invoice' => 'Assunto do E-mail de Fatura',
    'email_subject_quote' => 'Assunto do E-mail de Orçamento ',
    'email_subject_payment' => 'Assunto do E-mail de Pagamento',
    'switch_list_table' => 'Tabela de lista de mudança',
    'client_city' => 'Cidade do Cliente',
    'client_state' => 'Estado do Cliente',
    'client_country' => 'País do Cliente',
    'client_is_active' => 'Cliente Ativo',
    'client_balance' => 'Balanço do Cliente',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Taxa de imposto 1',
    'tax_rate2' => 'Taxa de imposto 2',
    'tax_rate3' => 'Taxa de imposto 3',
    'archived_at' => 'Arquivado em',
    'has_expenses' => 'Tem despesas',
    'custom_taxes1' => 'Impostos personalizados 1',
    'custom_taxes2' => 'Impostos personalizados 2',
    'custom_taxes3' => 'Impostos personalizados 3',
    'custom_taxes4' => 'Impostos personalizados 4',
    'custom_surcharge1' => 'Sobretaxa Personalizada 1',
    'custom_surcharge2' => 'Sobretaxa Personalizada 2',
    'custom_surcharge3' => 'Sobretaxa Personalizada 3',
    'custom_surcharge4' => 'Sobretaxa Personalizada 4',
    'is_deleted' => 'Excluído',
    'vendor_city' => 'Cidade do Vendedor',
    'vendor_state' => 'Estado do Vendedor',
    'vendor_country' => 'País do Vendedor',
    'credit_footer' => 'Rodapé do Crédito',
    'credit_terms' => 'Termos do Crédito',
    'untitled_company' => 'Empresa Sem Nome',
    'added_company' => 'Empresa adicionada com sucesso',
    'supported_events' => 'Eventos com Suporte',
    'custom3' => 'Terceiro Personalizado',
    'custom4' => 'Quarto Personalizado',
    'optional' => 'Opcional',
    'license' => 'Licença',
    'invoice_balance' => 'Saldo da fatura',
    'saved_design' => 'Design salvo com sucesso',
    'client_details' => 'Detalhes do cliente',
    'company_address' => 'Endereço da companhia',
    'quote_details' => 'Detalhes da cotação',
    'credit_details' => 'Detalhes de crédito',
    'product_columns' => 'Colunas de Produto',
    'task_columns' => 'Colunas de Tarefas',
    'add_field' => 'Adicionar campo',
    'all_events' => 'Todos os eventos',
    'owned' => 'Owned',
    'payment_success' => 'Pagamento realizado com sucesso',
    'payment_failure' => 'Falha de Pagamento',
    'quote_sent' => 'Cotação enviada',
    'credit_sent' => 'Crédito Enviado',
    'invoice_viewed' => 'Fatura visualizada',
    'quote_viewed' => 'Cotação visualizada',
    'credit_viewed' => 'Crédito visualizado',
    'quote_approved' => 'Cotação aprovada',
    'receive_all_notifications' => 'Receber todas as notificações',
    'purchase_license' => 'Comprar licença',
    'enable_modules' => 'Habilitar Módulos',
    'converted_quote' => 'Cotação convertida com sucesso',
    'credit_design' => 'Design de Crédito',
    'includes' => 'Inclui',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Designs personalizados',
    'designs' => 'Designs',
    'new_design' => 'Novo Design',
    'edit_design' => 'Editar Design',
    'created_design' => 'Design criado com sucesso',
    'updated_design' => 'Design atualizado com sucesso',
    'archived_design' => 'Design arquivado com sucesso',
    'deleted_design' => 'Design excluído com sucesso',
    'removed_design' => 'Design removido com sucesso',
    'restored_design' => 'Design restaurado com sucesso',
    'recurring_tasks' => 'Tarefas Recorrentes',
    'removed_credit' => 'Crédito removido com sucesso',
    'latest_version' => 'Última versão',
    'update_now' => 'Atualize agora',
    'a_new_version_is_available' => 'Uma nova versão do aplicativo da web está disponível',
    'update_available' => 'Atualização disponível',
    'app_updated' => 'Atualização completada com sucesso',
    'integrations' => 'Integrações',
    'tracking_id' => 'Id de rastreamento',
    'slack_webhook_url' => 'URL Webhook do Slack',
    'partial_payment' => 'Pagamento parcial',
    'partial_payment_email' => 'Email de pagamento parcial',
    'clone_to_credit' => 'Clone para crédito',
    'emailed_credit' => 'Crédito enviado com sucesso',
    'marked_credit_as_sent' => 'Crédito marcado com sucesso como enviado',
    'email_subject_payment_partial' => 'Assunto de pagamento parcial por email',
    'is_approved' => 'Está aprovado',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Crédito de Email',
    'client_email_not_set' => 'O cliente não tem um endereço de e-mail definido',
    'ledger' => 'Ledger',
    'view_pdf' => 'Ver PDF',
    'all_records' => 'Todos os registros',
    'owned_by_user' => 'Propriedade do usuário',
    'credit_remaining' => 'Crédito Restante',
    'use_default' => 'Use o padrão',
    'reminder_endless' => 'Lembrete contínuo',
    'number_of_days' => 'Número de dias',
    'configure_payment_terms' => 'Configurar as condições de pagamento',
    'payment_term' => 'Condição de Pagamento',
    'new_payment_term' => 'Novo Condição de Pagamento',
    'deleted_payment_term' => 'Condição de pagamento excluídas com sucesso',
    'removed_payment_term' => 'Condição de pagamento removida com sucesso',
    'restored_payment_term' => 'Condição de pagamento restaurado com sucesso',
    'full_width_editor' => 'Editor de largura total',
    'full_height_filter' => 'Filtro de altura total',
    'email_sign_in' => 'Entrar com email',
    'change' => 'Mudar',
    'change_to_mobile_layout' => 'Mudar para o layout móvel?',
    'change_to_desktop_layout' => 'Mudar para o layout da área de trabalho?',
    'send_from_gmail' => 'Enviar do Gmail',
    'reversed' => 'Invertido',
    'cancelled' => 'Cancelado',
    'quote_amount' => 'Valor da cotação',
    'hosted' => 'Hospedado',
    'selfhosted' => 'Auto-hospedado',
    'hide_menu' => 'Ocultar Menu',
    'show_menu' => 'Exibir Menu',
    'partially_refunded' => 'Parcialmente Reembolsado',
    'search_documents' => 'Pesquisar Documentos',
    'search_designs' => 'Pesquisar Designs',
    'search_invoices' => 'Pesquisar Faturas',
    'search_clients' => 'Pesquisar Clientes',
    'search_products' => 'Pesquisar Produtos',
    'search_quotes' => 'Pesquisar Cotações',
    'search_credits' => 'Pesquisar Créditos',
    'search_vendors' => 'Pesquisar Fornecedores',
    'search_users' => 'Pesquisar Usuários',
    'search_tax_rates' => 'Pesquisar taxas de impostos',
    'search_tasks' => 'Pesquisar Tarefas',
    'search_settings' => 'Pesquisar Configurações',
    'search_projects' => 'Pesquisar Projetos',
    'search_expenses' => 'Pesquisar Despesas',
    'search_payments' => 'Pesquisar Pagamentos',
    'search_groups' => 'Pesquisar Grupos',
    'search_company' => 'Pesquisar Empresa',
    'cancelled_invoice' => 'Fatura Cancelada com Sucesso',
    'cancelled_invoices' => 'Faturas Canceladas com Sucesso',
    'reversed_invoice' => 'Fatura Revertida com Sucesso',
    'reversed_invoices' => 'Faturas Revertidas com Sucesso',
    'reverse' => 'Reverter',
    'filtered_by_project' => 'Filtrado por Projeto',
    'google_sign_in' => 'Entrar com o Google',
    'activity_58' => ': fatura revertida pelo usuário: fatura',
    'activity_59' => ': fatura cancelada pelo usuário: fatura',
    'payment_reconciliation_failure' => 'Falha de reconciliação',
    'payment_reconciliation_success' => 'Sucesso de Reconciliação',
    'gateway_success' => 'Sucesso do Portal',
    'gateway_failure' => 'Falha do Portal',
    'gateway_error' => 'Erro do Portal',
    'email_send' => 'Email Enviado',
    'email_retry_queue' => 'Fila de Repetição de Email',
    'failure' => 'Falha',
    'quota_exceeded' => 'Cota excedida',
    'upstream_failure' => 'Falha Upstream',
    'system_logs' => 'Logs de Sistema',
    'copy_link' => 'Link de cópia',
    'welcome_to_invoice_ninja' => 'Bem-vindo ao Invoice Ninja',
    'optin' => 'Autorizar',
    'optout' => 'Desautorizar',
    'auto_convert' => 'Auto Conversão',
    'reminder1_sent' => 'Lembrete 1 Enviado',
    'reminder2_sent' => 'Lembrete 2 Enviado',
    'reminder3_sent' => 'Lembrete 3 Enviado',
    'reminder_last_sent' => 'Último Lembrete Enviado',
    'pdf_page_info' => 'Página: atual de: total',
    'emailed_credits' => 'Créditos enviados por e-mail com sucesso',
    'view_in_stripe' => 'Ver em Listra',
    'rows_per_page' => 'Linhas por Página',
    'apply_payment' => 'Aplicar Pagamento',
    'unapplied' => 'Não Aplicado',
    'custom_labels' => 'Etiquetas Personalizadas',
    'record_type' => 'Tipo de Registro',
    'record_name' => 'Nome do Registro',
    'file_type' => 'Tipo de Arquivo',
    'height' => 'Altura',
    'width' => 'Largura',
    'health_check' => 'Exame de saúde',
    'last_login_at' => 'Último login em',
    'company_key' => 'Chave da Empresa',
    'storefront' => 'Vitrine',
    'storefront_help' => 'Habilite aplicativos de terceiros para criar faturas',
    'count_records_selected' => ': registros de contagem selecionados',
    'count_record_selected' => ': registro de contagem selecionado',
    'client_created' => 'Cliente Criado',
    'online_payment_email' => 'Email de pagamento online',
    'manual_payment_email' => 'Email de pagamento manual',
    'completed' => 'Completado',
    'gross' => 'Bruto',
    'net_amount' => 'Valor líquido',
    'net_balance' => 'Saldo Líquido',
    'client_settings' => 'Configurações do cliente',
    'selected_invoices' => 'Faturas Selecionadas',
    'selected_payments' => 'Pagamentos Selecionados',
    'selected_quotes' => 'Cotações Selecionadas',
    'selected_tasks' => 'Tarefas Selecionadas',
    'selected_expenses' => 'Despesas Selecionadas',
    'past_due_invoices' => 'Faturas Vencidas',
    'create_payment' => 'Criar Pagamento',
    'update_quote' => 'Atualizar Cotação',
    'update_invoice' => 'Atualizar Fatura',
    'update_client' => 'Atualizar Cliente',
    'update_vendor' => 'Atualizar Fornecedor',
    'create_expense' => 'Criar Despesa',
    'update_expense' => 'Atualizar Despesa',
    'update_task' => 'Atualizar Tarefa',
    'approve_quote' => 'Aprovar Cotação',
    'when_paid' => 'Quando Pago',
    'expires_on' => 'Expira em',
    'show_sidebar' => 'Exibir Barra Lateral',
    'hide_sidebar' => 'Ocultar Barra Lateral',
    'event_type' => 'Tipo de Evento',
    'copy' => 'Cópia',
    'must_be_online' => 'Reinicie o aplicativo assim que estiver conectado à internet',
    'crons_not_enabled' => 'Os crons precisam ser habilitados',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Pesquisar: contar Webhooks',
    'search_webhook' => 'Pesquisar 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'Nova Webhook',
    'edit_webhook' => 'Editar Webhook',
    'created_webhook' => 'Webhook Criada com Sucesso',
    'updated_webhook' => 'Webhook Atualizada com Sucesso',
    'archived_webhook' => 'Webhook Arquivada com Sucesso',
    'deleted_webhook' => 'Webhook Excluída com Sucesso',
    'removed_webhook' => 'Webhook Removida com Sucesso',
    'restored_webhook' => 'Webhook Restaurada com Sucesso',
    'search_tokens' => 'Pesquisar: contar Tokens',
    'search_token' => 'Pesquisar 1 Token',
    'new_token' => 'Novo Token',
    'removed_token' => 'Token Removido com Sucesso',
    'restored_token' => 'Token Restaurado com Sucesso',
    'client_registration' => 'Registro de cliente',
    'client_registration_help' => 'Permitir que os clientes se auto-registrem no portal',
    'customize_and_preview' => 'Personalizar & Visualizar',
    'search_document' => 'Pesquisar 1 Documento',
    'search_design' => 'Pesquisar 1 Design',
    'search_invoice' => 'Pesquisar 1 Fatura',
    'search_client' => 'Pesquisar 1 Cliente',
    'search_product' => 'Pesquisar 1 Produto',
    'search_quote' => 'Pesquisar 1 Cotação',
    'search_credit' => 'Pesquisar 1 Crédito',
    'search_vendor' => 'Pesquisar 1 Fornecedor',
    'search_user' => 'Pesquisar 1 Usuário',
    'search_tax_rate' => 'Pesquisar 1 Taxa de Imposto',
    'search_task' => 'Pesquisar 1 Tarefa',
    'search_project' => 'Pesquisar 1 Projeto',
    'search_expense' => 'Pesquisar 1 Despesa',
    'search_payment' => 'Pesquisar 1 Pagamento',
    'search_group' => 'Pesquisar 1 Grupo',
    'created_on' => 'Criado em',
    'payment_status_-1' => 'Não Aplicado',
    'lock_invoices' => 'Bloquear Faturas',
    'show_table' => 'Exibir Tabelas',
    'show_list' => 'Exibir Lista',
    'view_changes' => 'Ver alterações',
    'force_update' => 'Forçar atualização',
    'force_update_help' => 'Você está executando a versão mais recente, mas pode haver correções pendentes disponíveis.',
    'mark_paid_help' => 'Acompanhe se a despesa foi paga',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
